DROP PACKAGE resdocs;
CREATE OR REPLACE PACKAGE resdocs AS

   ID                  NUMBER(10);
   cacr                res_cac%ROWTYPE;
   hpr                 res_hp%ROWTYPE;
   racr                rac_units_hc%ROWTYPE;
   gfurn               res_gas_furnaces%ROWTYPE;

   basehtml            VARCHAR2(60)    := 'http://mindy.infomall.org/';
   basewow             VARCHAR2(60)    := 'http://mindy.infomall.org/';
   wowhtml             VARCHAR2(70)    := basewow||'cgi-bin/ifc/';
   owihome             VARCHAR2(70)    := basehtml||'wp/';
   widthll             NUMBER(10)      := 162;


   TYPE fieldTblType    IS TABLE OF VARCHAR2(50)
                        INDEX BY BINARY_INTEGER;

   TYPE textTblType     IS TABLE OF VARCHAR2(50)
                        INDEX BY BINARY_INTEGER;

   CURSOR get_tables (gentype IN VARCHAR2) 
       IS
   SELECT distinct datatablename
     FROM residential_products_97
    WHERE upper(generaltype) = upper(gentype);

   itab                        NUMBER(5);
   tablenametab                textTblType;

   PROCEDURE write_air_cleaner(
             general_type          IN VARCHAR2);
   PROCEDURE write_boiler_steam(
             general_type          IN VARCHAR2);
   PROCEDURE write_boiler_water(
             general_type          IN VARCHAR2);
   PROCEDURE write_central_air_conditioners(
             general_type          IN VARCHAR2);
   PROCEDURE write_fancoil(
             general_type          IN VARCHAR2);
   PROCEDURE write_fancoil_efurnace(
             general_type          IN VARCHAR2);
   PROCEDURE write_gas_furnaces(
             general_type          IN VARCHAR2);
   PROCEDURE write_gas_furnaces_condensing(
             general_type          IN VARCHAR2);
   PROCEDURE write_heat_pump(
             general_type          IN VARCHAR2);
   PROCEDURE write_humidifier(
             general_type          IN VARCHAR2);
   PROCEDURE write_indoor_coil(
             general_type          IN VARCHAR2);
   PROCEDURE write_oil_furnaces(
             general_type          IN VARCHAR2);
   PROCEDURE write_ventilator(
             general_type          IN VARCHAR2);
   PROCEDURE write_zone_control(
             general_type          IN VARCHAR2);
   PROCEDURE write_zone_control_dampers(
             general_type          IN VARCHAR2);
   PROCEDURE write_zone_control_thermostats(
             general_type          IN VARCHAR2);
   PROCEDURE write_no_table_found(
             general_type          IN VARCHAR2);
   PROCEDURE write_room_air_conditioners(
             general_type          IN VARCHAR2);

END resdocs;
/
show errors;
/
/*======================================================*/

CREATE OR REPLACE PACKAGE BODY resdocs IS

/*======================================================*/
   PROCEDURE write_air_cleaner(
             general_type      IN VARCHAR2
             ) IS

   descriptiontab                textTblType;
   idesc                         number(10);
   acrec                         res_air_cleaners%ROWTYPE;
   eacrec                        res_elec_air_cleaners%ROWTYPE;

   rprec           residential_products_97%ROWTYPE;

   CURSOR get_info IS
   SELECT * 
     FROM residential_products_97
    WHERE upper(generaltype) = upper(general_type)
      AND datatablename = 'RES_AIR_CLEANERS'
      AND obsolete = '0'
    ORDER BY TO_NUMBER(xsequence);
   
   CURSOR get_elec_info IS
   SELECT * 
     FROM residential_products_97
    WHERE upper(generaltype) = upper(general_type)
      AND datatablename = 'RES_ELEC_AIR_CLEANERS'
      AND obsolete = '0'
    ORDER BY TO_NUMBER(xsequence);
   
   CURSOR get_air_cleaners (
          modelprefix    IN VARCHAR2 )
       IS
   SELECT *
     FROM res_air_cleaners
    WHERE upper(model) = upper(modelprefix);
   
   CURSOR get_elec_air_cleaners (
          modelprefix    IN VARCHAR2 )
       IS
   SELECT *
     FROM res_elec_air_cleaners
    WHERE upper(model) = upper(modelprefix);

   BEGIN

   htp.p('<A HREF="'||owihome||'res_hm1/index.html" TARGET="_parent">');
   htp.p('<IMG SRC="'||owihome||'res_media/res_header_back_button.gif" 
        ALIGN=MIDDLE WIDTH="430" HEIGHT="32" BORDER="0"></A>');

   htp.p('<P><BR>');
   htp.p('<CENTER><FONT SIZE=5>Air Cleaners</FONT></CENTER>');
   
   htp.p('<A HREF="#top"></A>'); 
--|--------------------------------------------------------
   htp.p('<CENTER>'); 
   htp.p('<TABLE CELLSPACING=15 WIDTH= 50%>');
   htp.p(' <TR>');
   htp.p('      <TD><IMG SRC="'||owihome||'res_media/31MF.jpg"
                 ALIGN="center" WIDTH="108" BORDER="0" ALT="31MF"></TD>');
   htp.p('      <TD><IMG SRC="'||owihome||'res_media/aira.jpg"
                 ALIGN="center" WIDTH="108" BORDER="0" ALT="AIRA"></TD>');
   htp.p('</TR>');
   htp.p(' <TR> ');
   htp.p('      <TD ALIGN="center"><A HREF="#31MF">31MF</A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#AIRA">AIRA</A></TD>');
   htp.p('</TR>');
   htp.p('</TABLE></CENTER>');
--|--------------------------------------------------------
--|--------------------------------------------------------
   htp.p('<UL>');
   RESTXT.RES_AIR_TREATMENT_TEXT;
   htp.p('</UL>');
--|--------------------------------------------------------
   htp.p('<P>');


   htp.p('<TABLE BORDER=3 WIDTH=90%>');
   RESHDRS.RES_AIR_CLEANERS_H;
   OPEN get_info;
   LOOP
      FETCH get_info INTO rprec;
      EXIT WHEN get_info%NOTFOUND;
      htp.p('<TR> <TD COLSPAN=4 ALIGN="center">');
      htp.p('        <A NAME="'||rprec.model||'"></A><NOBR>');
      htp.p('        <FONT SIZE="-1"><A HREF="#top">top of page</A>');
      htp.p('              </NOBR></FONT><BR>');
      htp.p('        <FONT SIZE=4>'||rprec.description||'</FONT>');
      htp.p('     </TD>');
      htp.p('</TR>');
      
      OPEN get_air_cleaners (rprec.model);
      LOOP
         FETCH get_air_cleaners INTO acrec;
         EXIT WHEN get_air_cleaners%NOTFOUND;
             
             htp.p('<TR> <TD ALIGN="left"> <B>'||acrec.model||'</B>'||acrec.model_size||'</TD>');
             htp.p('     <TD ALIGN="center">'||acrec.description||'</TD>');
             htp.p('     <TD ALIGN="center">'||acrec.height||' x '||acrec.width||' x '||acrec.depth||'</TD>');
             htp.p('     <TD ALIGN="center">'||acrec.weight||'</TD>');
             htp.p('</TR>');
      END LOOP;
      CLOSE get_air_cleaners;
   END LOOP;
   CLOSE get_info;
   htp.p('</TABLE>');
   htp.p('<P>');

   htp.p('<TABLE BORDER=3 WIDTH=90%>');
   RESHDRS.RES_ELEC_AIR_CLEANERS_H;
   OPEN get_elec_info;
   LOOP
      FETCH get_elec_info INTO rprec;
      EXIT WHEN get_elec_info%NOTFOUND;
      htp.p('<TR> <TD COLSPAN=5 ALIGN="center">');
      htp.p('        <A NAME="'||rprec.model||'"></A><NOBR>');
      htp.p('        <FONT SIZE="-1"><A HREF="#top">top of page</A>');
      htp.p('              </NOBR></FONT><BR>');
      htp.p('        <FONT SIZE=4>'||rprec.description||'</FONT>');
      htp.p('     </TD>');
      htp.p('</TR>');

      OPEN get_elec_air_cleaners (rprec.model);
      LOOP
         FETCH get_elec_air_cleaners INTO eacrec;
         EXIT WHEN get_elec_air_cleaners%NOTFOUND;
              htp.p('<TR> <TD ALIGN="left"> <B>'||eacrec.model||'</B>'||eacrec.model_size||'</TD>');
              htp.p('     <TD ALIGN="center">'||eacrec.description||'</TD>');
              htp.p('     <TD ALIGN="center">'||eacrec.volts_phase||'</TD>');
              htp.p('     <TD ALIGN="center">'||eacrec.height||' x '||eacrec.width||' x '||eacrec.depth||'</TD>');
              htp.p('     <TD ALIGN="center">'||eacrec.weight||'</TD>');
              htp.p('</TR>');
      END LOOP;
      CLOSE get_elec_air_cleaners;
   END LOOP;
   CLOSE get_elec_info;
   htp.p('</TABLE>');

   EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NULL;
    --  htp.p('<BR>No tables found for '||general_type||'<BR>');
   END write_air_cleaner;
/*======================================================*/
   PROCEDURE write_boiler_steam(
             general_type      IN VARCHAR2
             ) IS

   bsrec                      res_boilers%ROWTYPE;

   rprec           residential_products_97%ROWTYPE;
   CURSOR get_info IS
   SELECT * 
     FROM residential_products_97
    WHERE upper(generaltype) = upper(general_type)
    ORDER BY TO_NUMBER(xsequence);
   

   CURSOR get_boilers_steam 
          (modelprefix IN VARCHAR2)
       IS
   SELECT *
     FROM res_boilers
    WHERE upper(model) = upper(modelprefix)
    ORDER BY model_order;

   BEGIN

   htp.p('<A HREF="'||owihome||'res_hm1/index.html" TARGET="_parent">');
   htp.p('<IMG SRC="'||owihome||'res_media/res_header_back_button.gif" 
        ALIGN=MIDDLE WIDTH="430" HEIGHT="32" BORDER="0"></A>');

   htp.p('<P><BR><CENTER><H1>Boilers</H1></CENTER><P>');

   htp.p('<A HREF="#top"></A>'); 
--|-------------------------------------------------------------------
   htp.p('<P><CENTER>');
   htp.p('<TABLE >');
   htp.p(' <TR> <TD>');
   htp.p('<IMG SRC="'||owihome||'res_media/BS1_2.jpg"
           ALIGN="center" WIDTH="108" BORDER="0" ALT="BS1/BS2">');
   htp.p(' <P><A HREF="#BS1AAN">BS1</A> / <A HREF="#BS2AAN">BS2</A></TD>');
   htp.p('<TD>'); 
--|-------------------------------------------------------------------
   RESTXT.RES_BOILERS_STEAM_TEXT;
--|-------------------------------------------------------------------
   htp.p('</TD></TR>');
   htp.p('</TABLE>');
   htp.p('</CENTER><P>');
--|-------------------------------------------------------------------

   htp.p('<CENTER>');
   htp.p('<TABLE BORDER=3 WIDTH=90%>');
   RESHDRS.RES_BOILERS_STEAM_H;
   OPEN get_info;
   LOOP
      FETCH get_info INTO rprec;
      EXIT WHEN get_info%NOTFOUND;
      htp.p('<TR ROWSPAN=2>');
      htp.p('     <TD COLSPAN=6 ALIGN="center">');
      htp.p('        <A NAME="'||rprec.model||'"></A><NOBR>');
      htp.p('        <FONT SIZE="-1"><A HREF="#top">top of page</A>');
      htp.p('              </NOBR></FONT><BR>');
      htp.p('        <FONT SIZE=4>'||rprec.description||'</FONT>');
      htp.p('     </TD>');
      htp.p('</TR>');
      OPEN get_boilers_steam (rprec.model);
      LOOP
         FETCH get_boilers_steam INTO bsrec;
         EXIT WHEN get_boilers_steam%NOTFOUND;
         htp.p('<TR><TD ALIGN="left"><B>'||bsrec.model||'</B>'||bsrec.model_size||'</TD>');
         htp.p('      <TD ALIGN="center">'||bsrec.input||'</TD>');
         htp.p('      <TD ALIGN="center">'||bsrec.cap||'</TD>');
         htp.p('      <TD ALIGN="center">'||bsrec.weight||'</TD>');
         IF (TO_NUMBER(bsrec.w_o) = 0) THEN
            htp.p('   <TD ALIGN="center"> - </TD>');
         ELSE
            htp.p('   <TD ALIGN="center">'||bsrec.w_o||'</TD>');
         END IF;
         htp.p('      <TD ALIGN="center">'||bsrec.damper||'</TD>');
         htp.p('</TR>');
      END LOOP;
      CLOSE get_boilers_steam;
   END LOOP;
   CLOSE get_info;
   htp.p('</TABLE>');
   htp.p('</CENTER>');

   EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NULL;
      --htp.p('<BR>No tables found for '||general_type||'<BR>');
   END write_boiler_steam;
/*======================================================*/
   PROCEDURE write_boiler_water(
             general_type      IN VARCHAR2
             ) IS

   bwrec                      res_boilers%ROWTYPE;

   rprec           residential_products_97%ROWTYPE;
   CURSOR get_info IS
   SELECT * 
     FROM residential_products_97
    WHERE upper(generaltype) = upper(general_type)
    ORDER BY TO_NUMBER(xsequence);
   

   CURSOR get_boilers_water
         (modelprefix    IN VARCHAR2)
       IS
   SELECT *
     FROM res_boilers
    WHERE upper(model) = upper(modelprefix)
    ORDER BY model_order;

   BEGIN

   htp.p('<A HREF="'||owihome||'res_hm1/index.html" TARGET="_parent">');
   htp.p('<IMG SRC="'||owihome||'res_media/res_header_back_button.gif" 
        ALIGN=MIDDLE WIDTH="430" HEIGHT="32" BORDER="0"></A>');

   htp.p('<P><BR><CENTER><H1>Boilers</H1></CENTER><P>');

--|-------------------------------------------------------------------
   htp.p('<P><CENTER>');
   htp.p('<TABLE  WIDTH=70%>');
   htp.p(' <TR> ');
   htp.p('      <TD> <IMG SRC="'||owihome||'res_media/BW1_2.jpg"
                 ALIGN="center" HEIGHT="130" BORDER="0" ALT="BW1/BW2"></TD>');
   htp.p('      <TD> <IMG SRC="'||owihome||'res_media/BW3.jpg"
                 ALIGN="center" HEIGHT="130" BORDER="0" ALT="BW3"></TD>');
   htp.p('      <TD> <IMG SRC="'||owihome||'res_media/BW4_5.jpg"
                 ALIGN="center" HEIGHT="120" BORDER="0" ALT="BW4/BW5"></TD>');
   htp.p('</TR>'); 
   htp.p(' <TR> <TD ALIGN="center"><A HREF="#BW1AAN">BW1 </A> 
                                   <A HREF="#BW1AAP"></A>/');
   htp.p('                         <A HREF="#BW2AAN">BW2</A> 
                                   <A HREF="#BW2AAP"></A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#BW3AAN">BW3</A> 
                                   <A HREF="#BW3AAP"></A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#BW4AAH">BW4</A>/
                                   <A HREF="#BW5AAH">BW5</A></TD>');
   htp.p('</TR>'); 
   htp.p('</TABLE >');
   htp.p('</CENTER><P>');
--|-------------------------------------------------------------------
   htp.p('<UL>');
   RESTXT.RES_BOILERS_WATER_TEXT;
   htp.p('</UL><P>');
--|-------------------------------------------------------------------
   htp.p('<CENTER>');
   htp.p('<TABLE BORDER=3 WIDTH=90%>');
   RESHDRS.RES_BOILERS_WATER_H;
   OPEN get_info;
   LOOP
      FETCH get_info INTO rprec;
      EXIT WHEN get_info%NOTFOUND;
      htp.p('<TR ROWSPAN=2>');
      htp.p('     <TD COLSPAN=6 ALIGN="center">');
      htp.p('        <A NAME="'||rprec.model||'"></A><NOBR>');
      htp.p('        <FONT SIZE="-1"><A HREF="#top">top of page</A>');
      htp.p('              </NOBR></FONT><BR>');
      htp.p('        <FONT SIZE=4>'||rprec.description||'</FONT>');
      htp.p('     </TD>');
      htp.p('</TR>');
      OPEN get_boilers_water (rprec.model);
      LOOP
            FETCH get_BOILERS_WATER INTO bwrec;
            EXIT WHEN get_BOILERS_WATER%NOTFOUND;
            htp.p(' <TR><TD ALIGN="left">
                           <B>'||bwrec.model||'</B>'||bwrec.model_size||'</TD>');
            htp.p('      <TD ALIGN="center">'||bwrec.input||'</TD>');
            htp.p('      <TD ALIGN="center">'||bwrec.cap||'</TD>');
            htp.p('      <TD ALIGN="center">'||bwrec.weight||'</TD>');
/*
            IF (TO_NUMBER(bwrec.w_o) = 0) THEN
               htp.p('   <TD ALIGN="center"> - </TD>');
            ELSE
               htp.p('   <TD ALIGN="center">'||bwrec.w_o||'</TD>'); 
            END IF;
*/
            htp.p('   <TD ALIGN="center">'||bwrec.w_o||'</TD>'); 
            htp.p('      <TD ALIGN="center">'||bwrec.damper||'</TD>');
            htp.p('</TR>');
         END LOOP;
         CLOSE get_BOILERS_WATER;
   END LOOP;
   CLOSE get_info;
         htp.p('</TABLE>');
         htp.p('</CENTER>');

   EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NULL;
     -- htp.p('<BR>No tables found for '||general_type||'<BR>');
   END write_boiler_water;
/*======================================================*/
   PROCEDURE write_fancoil(
             general_type      IN VARCHAR2
             ) IS

   tnrec           res_FANCOILS%ROWTYPE;
   rprec           residential_products_97%ROWTYPE;

   rpmodel         VARCHAR2(50);

   CURSOR get_info IS
   SELECT * 
     FROM residential_products_97
    WHERE upper(generaltype) = upper(general_type)
    ORDER BY TO_NUMBER(xsequence);

   CURSOR get_FANCOILS (
          modelprefix        IN VARCHAR2 )
       IS
   SELECT *
     FROM res_FANCOILS
    WHERE upper(model) LIKE upper(modelprefix)
    ORDER BY  TO_NUMBER(model_size);

   BEGIN

   CCUTIL.chtml_header;

   htp.p('<A HREF="'||owihome||'res_hm1/index.html" TARGET="_parent">');
   htp.p('<IMG SRC="'||owihome||'res_media/res_header_back_button.gif" 
        ALIGN=MIDDLE WIDTH="430" HEIGHT="32" BORDER="0"></A>');

   htp.p('<P><BR><CENTER><H2>Fan Coils</H2></CENTER><P>');

   htp.p('<A HREF="#top"></A>'); 

   htp.p('<P><CENTER>');
   htp.p('<TABLE WIDTH=80% CELLSPACING=10>');
   htp.p(' <TR> <TD> <IMG SRC="'||owihome||'res_media/FB_C_H_K4.jpg"
                 ALIGN="center" HEIGHT="130" BORDER="0" ALT="FB_FC_FH_FK_4"></TD>');
   htp.p('      <TD> <IMG SRC="'||owihome||'res_media/FF1.jpg"
                 ALIGN="center" HEIGHT="130" BORDER="0" ALT="FF1C"></TD>');
   htp.p('      <TD> <IMG SRC="'||owihome||'res_media/FD3.jpg"
                 ALIGN="center" WIDTH="108" BORDER="0" ALT="FD3A"></TD>');
   htp.p('      <TD> <IMG SRC="'||owihome||'res_media/FG3A.jpg"
                 ALIGN="center" WIDTH="108" BORDER="0" ALT="FG3A"></TD>');
   htp.p('</TR>'); 

   htp.p(' <TR> <TD ALIGN="center"><A HREF="#FB4AN">FB4</A><NOBR> ');
   htp.p('                         <A HREF="#FC4BNF">FC4</A><NOBR> <BR>');
   htp.p('                         <A HREF="#FA4AN">FA4</A><NOBR> ');
   htp.p('                         <A HREF="#FK4CNF">FK4</A><NOBR></TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#FF1">FF1B FF1C</A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#FD3ANA">FD3A</A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#FG3ANA">FG3A</A></TD>');
   htp.p('</TR>');
   htp.p('</TABLE >');
   htp.p('</CENTER><P>');

--|End of Product Photo Table
--|Start of Product Description and Data Tables

   htp.p('<TABLE COLSPEC="35% 65%" CELLSPACING=6>');

   htp.p('<TR><TD  VALIGN="top">');
   RESTXT.RES_FANCOILS_TEXT_1;
   htp.p('     </TD>');
   htp.p('      <TD VALIGN="top">');
   OPEN get_info;
   LOOP
      FETCH get_info INTO rprec;
      EXIT WHEN get_info%NOTFOUND;
      htp.p('<TABLE BORDER=4 CELLSPACING=2 WIDTH="100%">');
      htp.p(' <TR> <TD COLSPAN=8 ALIGN="center">');
      htp.p('         <A NAME="'||rprec.model||'"></A><NOBR>');
      htp.p('         <FONT SIZE="-1"><A HREF="#top">top of page</A></NOBR><BR>');
      htp.p('         <FONT SIZE=4>'||rprec.description||'</FONT>');
      htp.p('    </TD>');
      htp.p('</TR>');

      rpmodel     :=  upper(rprec.model)||'%';
      OPEN get_FANCOILS (rpmodel);
      RESHDRS.RES_FANCOILS_H;
      LOOP
         FETCH get_FANCOILS INTO tnrec;
         EXIT WHEN get_FANCOILS%NOTFOUND;
         htp.p(' <TR> <TD ALIGN="left"><B>'||tnrec.model||'</B>'||tnrec.model_size||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.height||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.width||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.depth||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.weight||'</TD>');
         htp.p('</TR>');
      END LOOP;
      CLOSE get_FANCOILS;
      htp.p('</TABLE>');
      htp.p('<! before if statement' || rprec.model || '-->');
      IF( rprec.model = 'FB4AN' ) THEN
         htp.p('</TD></TR>');
         htp.p('<TR><TD COLSPAN=2 ROWSPAN=1><BR></TD></TR>');
         htp.p(' <TR> <TD VALIGN="top">');
         RESTXT.RES_FANCOILS_TEXT_2;
         htp.p('      </TD>');
         htp.p('       <TD VALIGN="top">');
      ELSIF ( rprec.model ='FA4ANF') THEN
         htp.p('</TD></TR>');
         htp.p('<TR><TD COLSPAN=2 ROWSPAN=1><BR></TD</TR>');
         htp.p(' <TR> <TD VALIGN="top">');
         RESTXT.RES_FANCOILS_TEXT_3;
         htp.p('      </TD>');
         htp.p('       <TD VALIGN="top">');
      ELSE
         NULL;
      END IF;
   END LOOP;
   htp.p('</TD></TR>');
   htp.p('</TABLE>');


   CLOSE get_info;
   htp.p('</TD>');
   htp.p('</TR>');
   htp.p('</TABLE>');

   CCUTIL.chtml_footer;

   EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NULL;
   END write_fancoil;
/*======================================================*/
   PROCEDURE write_fancoil_efurnace(
             general_type      IN VARCHAR2
             ) IS

   tnrec                        res_FANCOILS_ELECFURNACE%ROWTYPE;
   CURSOR get_FANCOILS_ELECFURNACE
       IS
   SELECT *
     FROM res_FANCOILS_ELECFURNACE;

   fnrec                        res_FANCOILS%ROWTYPE;
   CURSOR get_FANCOILS_EF_UNITS
       IS
   SELECT *
     FROM RES_FANCOILS
    WHERE model = 'FH4ANF'
    ORDER BY TO_NUMBER(SUBSTR(model_size,1,3) );

   BEGIN

   CCUTIL.chtml_header;

   htp.p('<A HREF="'||owihome||'res_hm1/index.html" TARGET="_parent">');
   htp.p('<IMG SRC="'||owihome||'res_media/res_header_back_button.gif" 
        ALIGN=MIDDLE WIDTH="430" HEIGHT="32" BORDER="0"></A>');

   htp.p('<CENTER><H2>Electric Furnace Fan Coils</H2></CENTER>');

   htp.p('<A HREF="#top"></A>'); 

   htp.p('<UL>');
   htp.p('<TABLE  COLSPEC=" 30% 60%">');
   htp.p(' <TR> <TD ALIGN="center"><IMG SRC="'||owihome||'res_media/FB_C_H_K4.jpg"
                 ALIGN="center" WIDTH="108" BORDER="0" ALT="FH4A">');
   htp.p('       <P>FH4A</TD>');

   htp.p('       <TD>');
      RESTXT.RES_FANCOILS_ELECFURN_TEXT;
   htp.p('      </TD>');
   htp.p('</TR></TABLE>');
   htp.p('</UL>');

   htp.p('<CENTER>');
   htp.p('<TABLE BORDER=3 WIDTH=90%>');
   RESHDRS.res_FANCOILS_H;
      htp.p(' <TR> <TD COLSPAN=5 ALIGN="center">');
      htp.p('         <FONT SIZE="-1"><A HREF="#top">top of page</A></NOBR><BR>');
      htp.p('         <FONT SIZE=4>FH4A ELECTRIC FURNACE</FONT>');
      htp.p('    </TD>');
      htp.p('</TR>');
   OPEN get_FANCOILS_EF_UNITS;
   LOOP
      FETCH get_FANCOILS_EF_UNITS INTO fnrec;
      EXIT WHEN get_FANCOILS_EF_UNITS%NOTFOUND;
      htp.p(' <TR> <TD ALIGN="left"><B>'||fnrec.model||'</B>'||fnrec.model_size||'</TD>');
      htp.p('      <TD ALIGN="center">'||fnrec.height||'</TD>');
      htp.p('      <TD ALIGN="center">'||fnrec.width||'</TD>');
      htp.p('      <TD ALIGN="center">'||fnrec.depth||'</TD>');
      htp.p('      <TD ALIGN="center">'||fnrec.weight||'</TD>');
      htp.p('</TR>');
   END LOOP;
   CLOSE get_FANCOILS_EF_UNITS;
   htp.p('</TABLE>');
   htp.p('</CENTER>');


   htp.p('<P><P>');
   htp.p('<CENTER>');
   htp.p('<TABLE BORDER=3 WIDTH=90%>');
   RESHDRS.res_FANCOILS_ELECFURNACE_H;
      htp.p(' <TR> <TD COLSPAN=5 ALIGN="center">');
      htp.p('         <FONT SIZE="-1"><A HREF="#top">top of page</A></NOBR><BR>');
      htp.p('         <FONT SIZE=4>FH4A FAN ELECTRIC FURNACE</FONT>');
      htp.p('    </TD>');
   OPEN get_FANCOILS_ELECFURNACE;
   LOOP
      FETCH get_FANCOILS_ELECFURNACE INTO tnrec;
      EXIT WHEN get_FANCOILS_ELECFURNACE%NOTFOUND;
      htp.p(' <TR> <TD ALIGN="left"><B> '||tnrec.model||'</B>'||tnrec.model_size||'</TD>');
      htp.p('      <TD ALIGN="left">'||tnrec.application||'</TD>');
      htp.p('      <TD ALIGN="left">'||tnrec.acc_coil_kit||'</TD>');
      htp.p('</TR>');
   END LOOP;
   CLOSE get_FANCOILS_ELECFURNACE;
   htp.p('</TABLE>');
   htp.p('</CENTER>');

   EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NULL;
    --  htp.p('<BR>No tables found for '||general_type||'<BR>');
   END write_fancoil_efurnace;
/*======================================================*/
   PROCEDURE write_gas_furnaces(
             general_type      IN VARCHAR2
             ) IS

   tnrec                        res_GAS_FURNACES%ROWTYPE;
   rprec           residential_products_97%ROWTYPE;

   CURSOR get_info IS
   SELECT * 
     FROM residential_products_97
    WHERE upper(generaltype) = upper(general_type)
    ORDER BY TO_NUMBER(xsequence);
   
   CURSOR get_GAS_FURNACES (
          modelprefix         IN VARCHAR2)
       IS
   SELECT *
     FROM res_GAS_FURNACES
    WHERE upper(model) = upper(modelprefix)
    ORDER BY model_order;

   BEGIN

   CCUTIL.chtml_header;

   htp.p('<A HREF="'||owihome||'res_hm1/index.html" TARGET="_parent">');
   htp.p('<IMG SRC="'||owihome||'res_media/res_header_back_button.gif" 
        ALIGN=MIDDLE WIDTH="430" HEIGHT="32" BORDER="0"></A>');

   htp.p('<P><BR><CENTER><H2>Gas-Fired Furnaces</H2></CENTER><P>');

   htp.p('<A HREF="#top"></A>'); 

--|htp.p('<BR>write_gas_furnaces, general_type is '||general_type||'<BR>');
--|htp.p('<P><FONT SIZE=4>Product Photos and links go here </FONT><P>');

   htp.p('<UL>');
   htp.p('<TABLE WIDTH=90% >');
   htp.p(' <TR> <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/58TMA_TUA.jpg"');
   htp.p('         ALIGN="center" HEIGHT="130" BORDER="0" ALT="58TMA/58TUA"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/58UHV_DNV.jpg"');
   htp.p('         ALIGN="center" HEIGHT="130" BORDER="0" ALT="58UHV/58DNV"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/58PAV_RAV.jpg"');
   htp.p('         ALIGN="center" HEIGHT="130" BORDER="0" ALT="58PAV/58RAV"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/58WAV_ZAV.jpg"');
   htp.p('         ALIGN="center" HEIGHT="130" BORDER="0" ALT="58WAV/58ZAV"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/58GFA.jpg"');
   htp.p('         ALIGN="center" HEIGHT="130" BORDER="0" ALT="58GFA"></TD>');
   htp.p('</TR> ');
   htp.p(' <TR> <TD ALIGN="center"><A HREF="#58TUA">58TUA</A>');
   htp.p('      <BR><A HREF="#58UXT">58UXT</A>');
   htp.p('      <BR><A HREF="#58DXT">58DXT</A>');
   htp.p('      <BR><A HREF="#58TMA">58TMA</A>');
   htp.p('      </TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#58UHV">58UHV</A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#58PAV">58PAV</A>');
   htp.p('      <BR><A HREF="#58RAV">58RAV</A>');
   htp.p('      </TD>');
   htp.p('      <TD ALIGN="center"><a HREF="#58WAV">58WAV</A>/<A HREF="#58ZAV">58ZAV</A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#58GFA">58GFA</A></TD>');
   htp.p('</TR>');
   htp.p('</TABLE>');

/* Images: p17 58TMA_TUA.jpg  58UHV_DNV.jpg
           p18 58PAV_RAV.jpg  58WAV_ZAV.jpg
           p19 58EFA.jpg  58GFA.jpg
*/

--|htp.p('<FONT SIZE=4>Product Descriptive Text goes here </FONT><P>');

   RESTXT.RES_GAS_FURNACES_TEXT_1;
   htp.p('<HR><BR>');
   RESTXT.RES_GAS_FURNACES_TEXT_2;
   htp.p('<HR><BR>');
   RESTXT.RES_GAS_FURNACES_TEXT_3;
   htp.p('<HR><BR>');
   RESTXT.RES_GAS_FURNACES_TEXT_4;
   htp.p('<hr><br>'); 
   RESTXT97.res_58yav_txt; 
   htp.p('</UL>');

   htp.p('<P>');

--|htp.p('<P><FONT SIZE=4>Table(s) Here </FONT><P>');
--|htp.p('<FONT SIZE=4>Table Format Can be Refined   :-) </FONT><P>');

   htp.p('<TABLE BORDER=4 CELLSPACING=2 WIDTH=90%>');
   RESHDRS.RES_GAS_FURNACES_H;

   OPEN get_info;
   LOOP
      FETCH get_info INTO rprec;
      EXIT WHEN get_info%NOTFOUND;
      htp.p('<TR><TD COLSPAN=6 ALIGN="center">');
      htp.p('        <A NAME="'||rprec.model||'"></A><NOBR>');
      htp.p('        <FONT SIZE="-1"><A HREF="#top">top of page</A>');
      htp.p('              </NOBR></FONT><BR>');
      htp.p('        <FONT SIZE=4>'||rprec.description||'</FONT>');
      htp.p('     </TD>');
      htp.p('</TR>');

      OPEN get_GAS_FURNACES (rprec.model);
      LOOP
         FETCH get_GAS_FURNACES INTO tnrec;
         EXIT WHEN get_GAS_FURNACES%NOTFOUND;
         htp.p(' <TR> <TD ALIGN="left"><B> '||tnrec.model||'</B>'||tnrec.model_size||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.AFUE||'</TD>');
         htp.p('      <TD ALIGN="left">'||tnrec.input||'</TD>');
         htp.p('      <TD ALIGN="left">'||tnrec.output||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.dimensions||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.cooling||'</TD>');
         htp.p('</TR>');
      END LOOP;
      CLOSE get_GAS_FURNACES;
   END LOOP;
   CLOSE get_info;
   htp.p('</TABLE>');

   EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NULL;
   --   htp.p('<BR>No tables found for '||general_type||'<BR>');
   END write_gas_furnaces;
/*======================================================*/
   PROCEDURE write_gas_furnaces_condensing(
             general_type      IN VARCHAR2
             ) IS

   gfdvrec         res_GAS_FURNACE_DEL_VAR%ROWTYPE;
   rprec           residential_products_97%ROWTYPE;
   gfdsrec         res_GAS_FURNACE_DEL_SINGLE%ROWTYPE;

   CURSOR get_info 
          (tablename    IN VARCHAR2) IS
   SELECT * 
     FROM residential_products_97
    WHERE upper(generaltype) = upper(general_type)
      AND upper(datatablename) = upper(tablename)
    ORDER BY TO_NUMBER(xsequence);
   

   CURSOR get_GAS_FURNACE_DEL_VAR 
          (modelprefix       IN VARCHAR2) IS
   SELECT *
     FROM res_GAS_FURNACE_DEL_VAR
    WHERE upper(model) = upper(modelprefix);


   CURSOR get_GAS_FURNACE_DEL_SINGLE 
          (modelprefix       IN VARCHAR2) IS
   SELECT *
     FROM res_GAS_FURNACE_DEL_SINGLE
    WHERE upper(model) = upper(modelprefix);

   BEGIN

   CCUTIL.chtml_header;

   htp.p('<A HREF="'||owihome||'res_hm1/index.html" TARGET="_parent">');
   htp.p('<IMG SRC="'||owihome||'res_media/res_header_back_button.gif" 
        ALIGN=MIDDLE WIDTH="430" HEIGHT="32" BORDER="0"></A>');

   htp.p('<P><BR><CENTER><H2> Gas-Fired Condensing Furnaces</H2></CENTER><P>');

   htp.p('<A HREF="#top"></A>'); 

--|htp.p('<BR>write_gas_furnaces_condensing, general_type is '||general_type||'<BR>');
--|htp.p('<P><FONT SIZE=4>Product Photos and links go here </FONT><P>');

   htp.p('<TABLE WIDTH=90% >');
   htp.p(' <TR>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/58MVP.jpg"');
   htp.p('         ALIGN="center" HEIGHT="130" BORDER="0" ALT="58MVP"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/58MCA.jpg"');
   htp.p('         ALIGN="center" HEIGHT="130" BORDER="0" ALT="58MCA"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/58MXA.jpg"');
   htp.p('         ALIGN="center" HEIGHT="130" BORDER="0" ALT="58MXA"></TD>');
   htp.p('</TR>');
   htp.p(' <TR> <TD ALIGN="center"><A HREF="#58MVP">58MVP</A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#58MCA">58MCA</A>/<a href="#58MSA">58MSA</a></TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#58MXA">58MXA</A></TD>');
   htp.p('</TR>');
   htp.p('</TABLE>');
   htp.p('<P><P>');

   htp.p('<UL>');
   RESTXT.RES_GAS_FURNACES_C_TEXT;
   htp.p('</UL>');
   
   htp.p('<CENTER>');
   htp.p('<TABLE BORDER=3 WIDTH=90%>');
--|htp.p(' <TR><TD ALIGN="center" 
--|               COLSPAN=9><B>VARIABLE CAPACITY CONDENSING FURNACE</B></TD></TR>');

   RESHDRS.RES_GAS_FURNACE_DEL_VAR_H;

   OPEN get_info ('RES_GAS_FURNACE_DEL_VAR');
   LOOP
      FETCH get_info INTO rprec;
      EXIT WHEN get_info%NOTFOUND;
      htp.p('<TR><TD COLSPAN=9 ALIGN="center">');
      htp.p('        <A NAME="'||rprec.model||'"></A><NOBR>');
      htp.p('        <FONT SIZE="-1"><A HREF="#top">top of page</A>');
      htp.p('              </NOBR></FONT><BR>');
      htp.p('        <FONT SIZE=4>'||rprec.description||'</FONT>');
      htp.p('     </TD>');
      htp.p('</TR>');
      OPEN get_GAS_FURNACE_DEL_VAR (rprec.model);
      LOOP
         FETCH get_GAS_FURNACE_DEL_VAR INTO gfdvrec;
         EXIT WHEN get_GAS_FURNACE_DEL_VAR%NOTFOUND;
         htp.p(' <TR> <TD ALIGN="left">
                      <B>'||gfdvrec.model||'</B>'||gfdvrec.model_size||'</TD>');
         htp.p('      <TD ALIGN="center">'||gfdvrec.afue||'</TD>');
         htp.p('      <TD ALIGN="center">'||gfdvrec.input||'</TD>');
         htp.p('      <TD ALIGN="center">'||gfdvrec.output||'</TD>');
         htp.p('      <TD ALIGN="center">'||gfdvrec.casing_width||'</TD>');
         htp.p('      <TD ALIGN="center">'||gfdvrec.heat_cfm||'</TD>');
         htp.p('      <TD ALIGN="center">'||gfdvrec.cool_cfm||'</TD>');
         htp.p('      <TD ALIGN="left">'||gfdvrec.motor_hp_type||'</TD>');
         htp.p('      <TD ALIGN="center">'||gfdvrec.approx_ship_wt||'</TD>');
         htp.p('</TR>');
      END LOOP;
      CLOSE get_GAS_FURNACE_DEL_VAR;
   END LOOP;
   CLOSE get_info;
   htp.p('</TABLE>');
   htp.p('</CENTER>');


   htp.p('<CENTER>');
   htp.p('<P>');
   htp.p('<TABLE BORDER=3 WIDTH=90%>');
--|htp.p(' <TR> <TD ALIGN="center" 
--|              COLSPAN=9><B>SINGLE CAPACITY CONDENSING FURNACE</B></TD></TR>');

   RESHDRS.RES_GAS_FURNACE_DEL_SINGLE_H;

   OPEN get_info('RES_GAS_FURNACE_DEL_SINGLE');
   LOOP
      FETCH get_info INTO rprec;
      EXIT WHEN get_info%NOTFOUND;
      htp.p('<TR><TD COLSPAN=8 ALIGN="center">');
      htp.p('        <A NAME="'||rprec.model||'"></A><NOBR>');
      htp.p('        <FONT SIZE="-1"><A HREF="#top">top of page</A>');
      htp.p('              </NOBR></FONT><BR>');
      htp.p('        <FONT SIZE=4>'||rprec.description||'</FONT>');
      htp.p('     </TD>');
      htp.p('</TR>');
      OPEN get_GAS_FURNACE_DEL_SINGLE (rprec.model);
      LOOP
         FETCH get_GAS_FURNACE_DEL_SINGLE INTO gfdsrec;
         EXIT WHEN get_GAS_FURNACE_DEL_SINGLE%NOTFOUND;
         htp.p(' <TR> <TD ALIGN="left">
                         <B>'||gfdsrec.model||'</B>'||gfdsrec.model_size||'</TD>');
         htp.p('      <TD ALIGN="center">'||gfdsrec.afue||'</TD>');
         htp.p('      <TD ALIGN="center">'||gfdsrec.output||'</TD>');
         htp.p('      <TD ALIGN="center">'||gfdsrec.width||'</TD>');
         htp.p('      <TD ALIGN="center">'||gfdsrec.heating||'</TD>');
         htp.p('      <TD ALIGN="center">'||gfdsrec.cooling||'</TD>');
         htp.p('      <TD ALIGN="center">'||gfdsrec.motor||'</TD>');
         htp.p('      <TD ALIGN="center">'||gfdsrec.weight||'</TD>');
         htp.p('</TR>');
      END LOOP;
      CLOSE get_GAS_FURNACE_DEL_SINGLE;
   END LOOP;
   CLOSE get_info;
   htp.p('</TABLE>');
   htp.p('</CENTER>');

   EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NULL;
     -- htp.p('<BR>No tables found for '||general_type||'<BR>');
   END write_gas_furnaces_condensing;
/*======================================================*/
   PROCEDURE write_heat_pump(
             general_type      IN VARCHAR2
             ) IS

   tnrec                        res_HP%ROWTYPE;
   
   rprec                        residential_products_97%ROWTYPE;
   CURSOR get_info IS
   SELECT * 
     FROM residential_products_97
    WHERE upper(generaltype) = upper(general_type)
    ORDER BY TO_NUMBER(xsequence);
   
   CURSOR get_data 
          (modelprefix IN VARCHAR2,
           mdlphase    IN VARCHAR2)
       IS
   SELECT *
     FROM RES_HP
    WHERE upper(model) = upper(modelprefix)
      AND TO_NUMBER(phase) = TO_NUMBER(mdlphase)
    ORDER BY model_order;

   BEGIN

   CCUTIL.chtml_header('Res Heat Pump Product Page');

   htp.p('<A HREF="'||owihome||'res_hm1/index.html" TARGET="_parent">');
   htp.p('<IMG SRC="'||owihome||'res_media/res_header_back_button.gif" 
        ALIGN=MIDDLE WIDTH="430" HEIGHT="32" BORDER="0"></A>');

   htp.p('<P><BR><CENTER><H2>Heat Pumps</H2></CENTER><P>');

   htp.p('<A HREF="#top"></A>'); 

--|htp.p('<BR>write_heat_pump, general_type is '||general_type||'<BR>');
--|htp.p('<P><FONT SIZE=4>Product Photos and links go here </FONT><P>');
--|htp.p('<FONT SIZE=4>Product Descriptive Text goes here </FONT><P>');

   htp.p('<TABLE WIDTH=90% >');
   htp.p(' <TR> <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/38YDA.jpg"');
   htp.p('         ALIGN="center" HEIGHT="130" BORDER="0" ALT="38YDA"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/38YS_YMA_YKC.jpg"');
   htp.p('         ALIGN="center" HEIGHT="130" BORDER="0" ALT="38YSA"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/38YRA.jpg"');
   htp.p('         ALIGN="center" HEIGHT="130" BORDER="0" ALT="38YRA"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/Cobra_HP.jpg"');
   htp.p('         ALIGN="center" HEIGHT="130" BORDER="0" ALT="Cobra HP"></TD>');
   htp.p('</TR>');
   htp.p(' <TR> <TD ALIGN="center"><A HREF="#38YDA">38YDA</A></TD>');
   htp.p('      <TD ALIGN="center">
                                   <A HREF="#38YKC">38YKC</A>/
                                   <A HREF="#38YMA">38YMA</A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#38YRA">38YRA</A><BR>');
   htp.p('			   <A HREF="#38YSA">38YSA</A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#38YCB">38YCB</A>/
                                   <A HREF="#38AYB">38AYB</A><BR>
                                   <A HREF="#38BYB">38BYB</A></TD>');
   htp.p('</TR>');
   htp.p('</TABLE>');
   htp.p('<P>');
   htp.p('<I>Click on the model number above to jump to its performance
             table</I>');
   htp.p('<P>');

   htp.p('<UL>');
   RESTXT.RES_HP_TEXT;
   htp.p('<P>');
   RESTXT.RES_SPLIT_SYSTEM_HP_TEXT;
   htp.p('</UL>');
   htp.p('<P><P>');

   htp.p('<CENTER>');
   htp.p('<TABLE BORDER=4 WIDTH=90%>');
   RESHDRS.RES_HP_H;
   OPEN get_info;
   LOOP
      FETCH get_info INTO rprec;
      EXIT WHEN get_info%NOTFOUND;
      htp.p(' <TR> <TD COLSPAN=10 ALIGN="center">');
      htp.p('        <A NAME="'||rprec.model||'"></A><NOBR>');
      htp.p('        <FONT SIZE="-1"><A HREF="#top">top of page</A>');
      htp.p('              </NOBR></FONT><BR>');
      htp.p('        <FONT SIZE=4>'||rprec.description||'</FONT>');
      htp.p('     </TD>');
      htp.p('</TR>');
      OPEN get_data (rprec.model, rprec.phase);
      LOOP
         FETCH get_data INTO tnrec;
         EXIT WHEN get_data%NOTFOUND;
         htp.p(' <TR> <TD ALIGN="left"><B> '||tnrec.model||'</B>'||tnrec.model_size||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.phase||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.nom_capacity_tons||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.seer||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.hspf||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.elec_v_ph_hz||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.width||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.length||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.height||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.approx_oper_wt_lbs||'</TD>');
         htp.p('</TR>');
      END LOOP;
      CLOSE get_data;
   END LOOP;
   CLOSE get_info;
   htp.p('</TABLE>');
   htp.p('</CENTER>');

   EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NULL;
    --  htp.p('<BR>No tables found for '||general_type||'<BR>');
   END write_heat_pump;
/*======================================================*/
   PROCEDURE write_humidifier(
             general_type      IN VARCHAR2
             ) IS

   tnrec                        res_HUMIDIFIERS%ROWTYPE;
   CURSOR get_HUMIDIFIERS
       IS
   SELECT *
     FROM res_HUMIDIFIERS;

   BEGIN

   CCUTIL.chtml_header;

   htp.p('<A HREF="'||owihome||'res_hm1/index.html" TARGET="_parent">');
   htp.p('<IMG SRC="'||owihome||'res_media/res_header_back_button.gif" 
        ALIGN=MIDDLE WIDTH="430" HEIGHT="32" BORDER="0"></A>');

   htp.p('<P><BR><CENTER><H2>Air Treatment -- Humidifiers</H2></CENTER><P>');

   htp.p('<A HREF="#top"></A>'); 

--|htp.p('<BR>write_humidifier, general_type is '||general_type||'<BR>');
--|htp.p('<P><FONT SIZE=4>Product Photos and links go here </FONT><P>');
--|htp.p('<FONT SIZE=4>Product Descriptive Text goes here </FONT><P>');

   htp.p('<TABLE WIDTH=90% >');
   htp.p(' <TR> <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/49BF.jpg"');
   htp.p('         ALIGN="center" HEIGHT="130" BORDER="0" ALT="49BF"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/49BG.jpg"');
   htp.p('         ALIGN="center" HEIGHT="130" BORDER="0" ALT="49BG"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/49FH.jpg"');
   htp.p('         ALIGN="center" HEIGHT="130" BORDER="0" ALT="49FH"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/49FP.jpg"');
   htp.p('         ALIGN="center" HEIGHT="130" BORDER="0" ALT="49FP"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/49WS.jpg"');
   htp.p('         ALIGN="center" HEIGHT="130" BORDER="0" ALT="49WS"></TD>');
   htp.p('</TR>');
   htp.p(' <TR> <TD ALIGN="center">49BF</TD>');
   htp.p('      <TD ALIGN="center">49BG</TD>');
   htp.p('      <TD ALIGN="center">49FH</TD>');
   htp.p('      <TD ALIGN="center">49FP</TD>');
   htp.p('      <TD ALIGN="center">49WS</TD>');
   htp.p('</TR>');
   htp.p('</TABLE>');

   htp.p('<P><P><UL>');
   RESTXT.RES_HUMIDIFIERS_TEXT;
   htp.p('</UL><P><P>');

   htp.p('<CENTER>');
   htp.p('<TABLE BORDER=3 WIDTH=90%>');
   RESHDRS.RES_HUMIDIFIERS_H;
   OPEN get_HUMIDIFIERS;
   LOOP
      FETCH get_HUMIDIFIERS INTO TNrec;
      EXIT WHEN get_HUMIDIFIERS%NOTFOUND;
      htp.p(' <TR> <TD ALIGN="left"><B> '||tnrec.model||'</B>'||tnrec.model_size||'</TD>');
      htp.p('      <TD ALIGN="center">'||tnrec.cap_140_deg||'</TD>');
      htp.p('      <TD ALIGN="center">'||tnrec.cap_120_deg||'</TD>');
      htp.p('      <TD ALIGN="center">'||tnrec.weight||'</TD>');
      htp.p('      <TD ALIGN="left">'||tnrec.width||'</TD>');
      htp.p('      <TD ALIGN="left">'||tnrec.depth||'</TD>');
      htp.p('      <TD ALIGN="left">'||tnrec.height||'</TD>');
      htp.p('      <TD ALIGN="center">'||tnrec.flow_rate||'</TD>');
      htp.p('</TR>');
   END LOOP;
   CLOSE get_HUMIDIFIERS;
   htp.p('</TABLE>');
   htp.p('</CENTER>');

   EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NULL;
     -- htp.p('<BR>No tables found for '||general_type||'<BR>');
   END write_humidifier;
/*======================================================*/
   PROCEDURE write_indoor_coil(
             general_type      IN VARCHAR2
             ) IS

   tnrec                        res_INDOOR_COILS%ROWTYPE;
   rprec                        residential_products_97%ROWTYPE;

   CURSOR get_info IS
   SELECT * 
     FROM residential_products_97
    WHERE upper(generaltype) = upper(general_type)
    ORDER BY TO_NUMBER(xsequence);
   
   CURSOR get_INDOOR_COIL
          (modelprefix    IN VARCHAR2)
       IS
   SELECT *
     FROM res_INDOOR_COILS
    WHERE upper(model) LIKE upper(modelprefix)||'%';

   BEGIN

   CCUTIL.chtml_header;

   htp.p('<A HREF="'||owihome||'res_hm1/index.html" TARGET="_parent">');
   htp.p('<IMG SRC="'||owihome||'res_media/res_header_back_button.gif" 
        ALIGN=MIDDLE WIDTH="430" HEIGHT="32" BORDER="0"></A>');

   htp.p('<P><BR><CENTER><H2>Indoor Evaporator Coils</H2></CENTER><P>');

   htp.p('<A HREF="#top"></A>'); 

--|htp.p('<BR>write_indoor_coil, general_type is '||general_type||'<BR>');
--|htp.p('<P><FONT SIZE=4>Product Photos and links go here </FONT><P>');
--|htp.p('<FONT SIZE=4>Product Descriptive Text goes here </FONT><P>');

   htp.p('<TABLE WIDTH=95% >');
   htp.p(' <TR> <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/ce3a.jpg"');
   htp.p('         ALIGN="center" HEIGHT="100" BORDER="0" ALT="CE3"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/cj5.jpg"');
   htp.p('         ALIGN="center" HEIGHT="100" BORDER="0" ALT="CE3"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/ck3.jpg"');
   htp.p('         ALIGN="center" HEIGHT="100" BORDER="0" ALT="CD3"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/ck5.jpg"');
   htp.p('         ALIGN="center" HEIGHT="100" BORDER="0" ALT="CD5"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/cm5.jpg"');
   htp.p('         ALIGN="center" HEIGHT="100" BORDER="0" ALT="CF5"></TD>');
   htp.p('</TR>');
   htp.p(' <TR> <TD ALIGN="center"><A HREF="#CE3AXA">CE3A</A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#CJ5AX">CJ5</A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#CK3AAA">CK3</A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#CK5AXA">CK5</A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#CM5AXA">CM5</A></TD>');
   htp.p('</TR>');
   htp.p('</TABLE>');

   htp.p('<UL>');
   RESTXT.RES_INDOOR_COILS_TEXT_1;
   htp.p('<HR><BR>');
   RESTXT.RES_INDOOR_COILS_TEXT_2;
   htp.p('</UL>');

   htp.p('<CENTER>');
   htp.p('<TABLE BORDER=3 WIDTH=90%>');
   RESHDRS.RES_INDOOR_COILS_H;
   OPEN get_info;
   LOOP
      FETCH get_info INTO rprec;
      EXIT WHEN get_info%NOTFOUND;
      htp.p(' <TR> <TD COLSPAN=5 ALIGN="center">');
      htp.p('        <A NAME="'||rprec.model||'"></A><NOBR>');
      htp.p('        <FONT SIZE="-1"><A HREF="#top">top of page</A>');
      htp.p('              </NOBR></FONT><BR>');
      htp.p('        <FONT SIZE=4>'||rprec.description||'</FONT>');
      htp.p('     </TD>');
      htp.p('</TR>');
      OPEN get_INDOOR_COIL (rprec.model);
      LOOP
         FETCH get_INDOOR_COIL INTO tnrec;
         EXIT WHEN get_INDOOR_COIL%NOTFOUND;
         htp.p(' <TR> <TD ALIGN="left">
                         <B>'||tnrec.model||'</B>'||tnrec.model_size||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.width||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.height||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.depth||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.weight||'</TD>');
         htp.p('</TR>');
      END LOOP;
      CLOSE get_INDOOR_COIL;
   END LOOP;
   CLOSE get_info;
   htp.p('</TABLE>');
   htp.p('</CENTER>');

   EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NULL;
     -- htp.p('<BR>No tables found for '||general_type||'<BR>');
   END write_indoor_coil;
/*======================================================*/
   PROCEDURE write_oil_furnaces(
             general_type      IN VARCHAR2
             ) IS

   tnrec                        res_OIL_FURNACES%ROWTYPE;
   tn2rec                       res_OIL_CLA%ROWTYPE;
   rprec                        residential_products_97%ROWTYPE;

   CURSOR get_info IS
   SELECT * 
     FROM residential_products_97
    WHERE upper(generaltype) = upper(general_type)
      AND model != '58CLA'
    ORDER BY TO_NUMBER(xsequence);

   CURSOR get_cla_info IS
   SELECT * 
     FROM residential_products_97
    WHERE upper(generaltype) = upper(general_type)
      AND model = '58CLA'
    ORDER BY TO_NUMBER(xsequence);
   
   CURSOR get_OIL_FURNACES
          (modelprefix    IN VARCHAR2)
       IS
   SELECT *
     FROM res_OIL_FURNACES
    WHERE upper(model) LIKE upper(modelprefix)||'%';
   
   CURSOR get_OIL_FURNACES_CLA
          (modelprefix    IN VARCHAR2)
       IS
   SELECT *
     FROM res_OIL_CLA
    WHERE upper(model) LIKE upper(modelprefix)||'%';

   BEGIN

   CCUTIL.chtml_header;

   htp.p('<A HREF="'||owihome||'res_hm1/index.html" TARGET="_parent">');
   htp.p('<IMG SRC="'||owihome||'res_media/res_header_back_button.gif" 
        ALIGN=MIDDLE WIDTH="430" HEIGHT="32" BORDER="0"></A>');

   htp.p('<P><BR><CENTER><H2>Oil Furnaces</H2></CENTER><P>');

   htp.p('<A HREF="#top"></A>'); 

   htp.p('<CENTER>');
   htp.p('<TABLE WIDTH=70% >');
   htp.p(' <TR>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/58BMA.jpg"');
   htp.p('         ALIGN="center" HEIGHT="130" BORDER="0" ALT="58BMA"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/58BLA.jpg"');
   htp.p('         ALIGN="center" HEIGHT="130" BORDER="0" ALT="58BLA"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/58BTA.jpg"');
   htp.p('         ALIGN="center" HEIGHT="130" BORDER="0" ALT="58BTA"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'res_media/58_cla.jpg"');
   htp.p('         ALIGN="center" HEIGHT="130" BORDER="0" ALT="58CLA"></TD>');
   htp.p('</TR>');
   htp.p(' <TR>');
   htp.p('      <TD ALIGN="center"><A HREF=#58BMA>58BMA</A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF=#58BLA>58BLA</A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF=#58BTA>58BTA</A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF=#58CLA>58CLA</A></TD>');
   htp.p('</TR>');
   htp.p('</TABLE>');
   htp.p('</CENTER>');

   htp.p('<P><P><UL>');
   RESTXT.RES_OIL_FURNACES_TEXT;
   htp.p('</UL><P><P>');

   htp.p('<TABLE BORDER=3 WIDTH=90%>');
   RESHDRS.RES_OIL_FURNACES_H;
   OPEN get_info;
   LOOP
      FETCH get_info INTO rprec;
      EXIT WHEN get_info%NOTFOUND;
      htp.p('<TR ROWSPAN=2>');
      htp.p('     <TD COLSPAN=10 ALIGN="center">');
      htp.p('        <A NAME="'||rprec.model||'"></A><NOBR>');
      htp.p('        <FONT SIZE="-1"><A HREF="#top">top of page</A>');
      htp.p('              </NOBR></FONT><BR>');
      htp.p('        <FONT SIZE=4>'||rprec.description||'</FONT><BR>');
      htp.p('     </TD>');
      htp.p('</TR>');
      OPEN get_OIL_FURNACES (rprec.model);
      LOOP
         FETCH get_OIL_FURNACES INTO tnrec;
         EXIT WHEN get_OIL_FURNACES%NOTFOUND;
--IF (tnrec.status = 'obsolete')
         htp.p(' <TR> <TD ALIGN="center"><B>'||tnrec.model||'</B>'||tnrec.model_size||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.output||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.hp||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.speed||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.heating||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.cooling||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.weight||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.length||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.width||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.height||'</TD>');
         htp.p('</TR>');
      END LOOP;
      CLOSE get_OIL_FURNACES;
   END LOOP;
   CLOSE get_info;
   htp.p('</TABLE>');

   htp.p('<P>');

   htp.p('<TABLE BORDER=3 WIDTH=90%>');
   RESHDRS.RES_OIL_FURNACES_CLA_H;
   OPEN get_cla_info;
   LOOP
      FETCH get_cla_info INTO rprec;
      EXIT WHEN get_cla_info%NOTFOUND;
      htp.p('<TR ROWSPAN=2>');
      htp.p('     <TD COLSPAN=12 ALIGN="center">');
      htp.p('        <A NAME="'||rprec.model||'"></A><NOBR>');
      htp.p('        <FONT SIZE="-1"><A HREF="#top">top of page</A>');
      htp.p('              </NOBR></FONT><BR>');
      htp.p('        <FONT SIZE=4>'||rprec.description||'</FONT><BR>');
      htp.p('     </TD>');
      htp.p('</TR>');
      OPEN get_OIL_FURNACES_CLA (rprec.model);
      LOOP
         FETCH get_OIL_FURNACES_CLA INTO tn2rec;
         EXIT WHEN get_OIL_FURNACES_CLA%NOTFOUND;
         htp.p(' <TR> <TD ALIGN="left"><B>'||tn2rec.model||'</B>'||tn2rec.model_size||'</TD>');
         htp.p('      <TD ALIGN="center">'||tn2rec.Noz||'</TD>');
         htp.p('      <TD ALIGN="center">'||tn2rec.input||'</TD>');
         htp.p('      <TD ALIGN="center">'||tn2rec.output||'</TD>');
         htp.p('      <TD ALIGN="center">'||tn2rec.hp||'</TD>');
         htp.p('      <TD ALIGN="center">'||tn2rec.speed||'</TD>');
         htp.p('      <TD ALIGN="center">'||tn2rec.heating||'</TD>');
         htp.p('      <TD ALIGN="center">'||tn2rec.cooling||'</TD>');
         htp.p('      <TD ALIGN="center">'||tn2rec.weight||'</TD>');
         htp.p('      <TD ALIGN="center">'||tn2rec.length||'</TD>');
         htp.p('      <TD ALIGN="center">'||tn2rec.width||'</TD>');
         htp.p('      <TD ALIGN="center">'||tn2rec.height||'</TD>');
         htp.p('</TR>');
      END LOOP;
      CLOSE get_OIL_FURNACES_CLA;
   END LOOP;
   CLOSE get_cla_info;
   htp.p('</TABLE>');

   EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NULL;
     -- htp.p('<BR>No tables found for '||general_type||'<BR>');
   END write_oil_furnaces;
/*======================================================*/
   PROCEDURE write_central_air_conditioners(
             general_type          IN VARCHAR2
             ) IS

   rprec                residential_products_97%ROWTYPE;

   CURSOR get_info IS
   SELECT *
     FROM residential_products_97
    WHERE upper(generaltype) = upper(general_type)
    ORDER BY TO_NUMBER(xsequence);

   CURSOR get_cac_data (
          modelprefix     IN VARCHAR2,
          mdlphase        IN VARCHAR2   
          ) IS
   SELECT * 
     FROM RES_CAC
    WHERE upper(model) = upper(modelprefix)
      AND TO_NUMBER(phase) = TO_NUMBER(mdlphase)
    ORDER  BY model_size;

   BEGIN

   CCUTIL.chtml_header;

   htp.p('<A HREF="'||owihome||'res_hm1/index.html" TARGET="_parent">');
   htp.p('<IMG SRC="'||owihome||'res_media/res_header_back_button.gif" 
        ALIGN=MIDDLE WIDTH="430" HEIGHT="32" BORDER="0"></A>');

   IF ( upper(general_type) = 'CENTRAL AIR CONDITIONERS') THEN
   htp.p('<P><BR>');

--|DOC: RES_CAC photos and links to data tables |--
---------------------------------------------------
      htp.p('<CENTER>');
      htp.p('<A HREF="#top"></A>');
      htp.p('<TABLE WIDTH=430>');

      htp.p(' <TR>');
      htp.p('         <H2>Central Air Conditioning</H2>');
	  htp.p('     <TD><IMG SRC="'||owihome||'res_media/38TDA.jpg" ALT="38TDA" 
                       ALIGN=BOTTOM HEIGHT="130" BORDER="0">');
	  htp.p('    </TD>');
	  htp.p('     <TD><IMG SRC="'||owihome||'res_media/38TKB.jpg" ALT="38TKB" 
                       ALIGN=LEFT HEIGHT="130" BORDER="0">');
	  htp.p('    </TD>');
	  htp.p('     <TD><IMG SRC="'||owihome||'res_media/38TRA_TUA.jpg" ALT="38TRA/38TUA" 
                       ALIGN=LEFT HEIGHT="130" BORDER="0"></TD>');
	  htp.p('     <TD><IMG SRC="'||owihome||'res_media/Cobra_AC.jpg" ALT="38BRB/38CMB/38CKB" ALigN=left height=130 border=0></td>'); 
	  htp.p('     <TD><IMG SRC="'||owihome||'res_media/38TXA.JPG" ALT="38TXA" ALIGN=LEFT HEIGHT="130" BORDER="0"></TD>');
	  htp.p('</TR>');
      htp.p(' <TR><TD ALIGN=CENTER>');
	  htp.p('           <A HREF="#38TDA">38TDA</A></TD>');
	  htp.p('     <TD ALIGN=CENTER>');
	  htp.p('          <A HREF="#38TKB">38TKB</A> </TD>');
	  htp.p('     <TD ALIGN=CENTER>');
	  htp.p('          <A HREF="#38TRA">38TRA</A><BR><A HREF="#38TUA">38TUA</A></TD>');
          htp.p('     <TD ALIGN=CENTER><A HREF="#38BRB">38BRB</A>/ ');
          htp.p('                      <A HREF="#38CMB">38CMB</A><BR>');
          htp.p('                      <A HREF="#38CKB">38CKB</A></TD>');
	  htp.p('     <TD ALIGN=CENTER>');
	  htp.p('          <A HREF="#38TXA">38TXA</A></TD>');
      htp.p('</TR>');
      htp.p('</TABLE>');
      htp.p('<P>');
      htp.p('<I>Click on the model number above to jump to its performance table</I>');
      htp.p('</P>');
      htp.p('</CENTER>');

      htp.p('<P><UL>');
      RESTXT.RES_CAC_TEXT;
      htp.p('</UL><P>');

      OPEN get_info;
      LOOP
--|DOC: RES_CAC description header |--
--------------------------------------
         FETCH get_info INTO rprec;
         EXIT WHEN get_info%NOTFOUND;
         htp.p('<TABLE BORDER=4 CELLSPACING=2 WIDTH="90%">');
         htp.p(' <TR ROWSPAN=2>');
         htp.p('     <TD COLSPAN=8 ALIGN="center">');
         htp.p('         <A NAME="'||rprec.model||'"></A><NOBR>');
         htp.p('         <FONT SIZE="-1"><A HREF="#top">top of page</A></NOBR><BR>');
         htp.p('         <FONT SIZE=4>'||rprec.description||'</FONT>');
         htp.p('    </TD>');
         htp.p('</TR>');
    
--|DOC: RES_CAC table header |--
--------------------------------------
         RESHDRS.RES_CAC_H;

         OPEN get_cac_data(rprec.model, rprec.phase);
         LOOP
--|DOC: RES_CAC product data  |--
--------------------------------------
            FETCH get_cac_data INTO  cacr;
            EXIT WHEN get_cac_data%NOTFOUND;
            htp.p(' <TR><TD><B>'||cacr.model||'</B>'||cacr.model_size||'</TD>');
            htp.p('     <TD ALIGN="center">'||cacr.NomCap||'</TD>');
            htp.p('     <TD ALIGN="center">'||cacr.seer||'</TD>');
            htp.p('     <TD>'||cacr.electrical||'</TD>');
            htp.p('     <TD ALIGN="center">'||cacr.width||'</TD>');
            htp.p('     <TD ALIGN="center">'||cacr.length||'</TD>');
            htp.p('     <TD ALIGN="center">'||cacr.height||'</TD>');
            htp.p('     <TD ALIGN="center">'||cacr.weight||'</TD>');
            htp.p('</TR>');
         END LOOP;
         CLOSE get_cac_data;
         htp.p('</TABLE>');
         htp.p('<P>');
      END LOOP;
      CLOSE get_info;
   END IF;

   EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NULL;
    --  htp.p('<BR>No tables found for '||general_type||'<BR>');
   END write_central_air_conditioners;
/*======================================================*/
   PROCEDURE write_ventilator(
             general_type      IN VARCHAR2
             ) IS

   tnrec                        res_VENTILATORS%ROWTYPE;
   tnerec                       res_ventilators_energy%ROWTYPE;
   rprec                residential_products_97%ROWTYPE;

   CURSOR get_info IS
   SELECT *
     FROM residential_products_97
    WHERE upper(generaltype) = upper(general_type)
    ORDER BY TO_NUMBER(xsequence);


   CURSOR get_VENTILATORS 
           (modelprefix IN VARCHAR2)
       IS
   SELECT *
     FROM res_VENTILATORS
    WHERE UPPER(model) = UPPER(modelprefix);

   CURSOR get_ventilators_energy
       IS 
   SELECT *
     FROM res_VENTILATORS_energy;

   BEGIN

   CCUTIL.chtml_header;

   htp.p('<A HREF="'||owihome||'res_hm1/index.html" TARGET="_parent">');
   htp.p('<IMG SRC="'||owihome||'res_media/res_header_back_button.gif" 
        ALIGN=MIDDLE WIDTH="430" HEIGHT="32" BORDER="0"></A>');

   htp.p('<P><BR><CENTER><H2>Ventilators</H2></CENTER><P>');

   htp.p('<A HREF="#top"></A>'); 

--|htp.p('<BR>write_ventilator, general_type is '||general_type||'<BR>');

--|htp.p('<P><FONT SIZE=4>Product Photos and links go here <BR>');
--|htp.p(' No photos found in current collection of res media</FONT><P>');

      htp.p('<CENTER>');
      htp.p('<TABLE WIDTH=430>');
      htp.p(' <TR>'); 
	  htp.p('     <TD><IMG SRC="'||owihome||'res_media/ERV.jpg" ALT="ERV" 
                    ALIGN=LEFT HEIGHT="130" BORDER="0">');
	  htp.p('    </TD>');
	  htp.p('     <TD><IMG SRC="'||owihome||'res_media/HRV.jpg" ALT="HRV" 
                       ALIGN=LEFT HEIGHT="130" BORDER="0"></TD>');
	  htp.p('</TR>');
      htp.p(' <TR>'); 
      htp.p('     <TD ALIGN=LEFT><A HREF="#vent">Energy Recovery<BR>Ventilators</A></TD>');
      htp.p('     <TD ALIGN=LEFT><A HREF="#vent">Heat Recovery<BR>Ventilators</A></TD>');
	  htp.p('</TR>');
      htp.p('</TABLE>');
      htp.p('</CENTER>');

   htp.p('<UL>');
   RESTXT.RES_VENTILATORS_TEXT;
   htp.p('</UL><P>');

-- htp.p(' <TR ROWSPAN=1>');
-- htp.p('     <TD COLSPAN=8 ALIGN="center">');
-- htp.p('         <A NAME="vent"></A><NOBR>');
-- htp.p('         <FONT SIZE="-1"><A HREF="#top">top of page</A></FONT></NOBR><BR>');
-- htp.p('    </TD>');
-- htp.p('</TR>');


   OPEN get_info;
   LOOP
--|DOC: VENTILATOR description header |--
--------------------------------------
      FETCH get_info INTO rprec;
      EXIT WHEN get_info%NOTFOUND;
      htp.p('<TABLE BORDER=4 CELLSPACING=2 WIDTH="90%">');
      htp.p(' <TR ROWSPAN=2>');
      htp.p('     <TD COLSPAN=9 ALIGN="center">');
      htp.p('         <A NAME="'||rprec.model||'"></A><NOBR>');
      htp.p('         <FONT SIZE="-1"><A HREF="#top">top of page</A></NOBR><BR>');
      htp.p('         <FONT SIZE=4>'||rprec.description||'</FONT>');
      htp.p('    </TD>');
      htp.p('</TR>');

      RESHDRS.RES_VENTILATORS_H;
      OPEN get_VENTILATORS(rprec.model);
      LOOP
         FETCH get_VENTILATORS INTO TNREC;
         EXIT WHEN get_VENTILATORS%NOTFOUND;
         htp.p(' <TR> <TD ALIGN="center"><B> '||tnrec.model||'</B>'||tnrec.model_size||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.CFM||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.I_BY_S||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.efficiency||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.electrical||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.width||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.depth||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.height||'</TD>');
         htp.p('      <TD ALIGN="center">'||tnrec.weight||'</TD>');
         htp.p('</TR>');
      END LOOP;
      CLOSE get_VENTILATORS;

--    OPEN get_ventilators_energy;
--    LOOP
--       FETCH get_ventilators_energy INTO tnerec;
--       EXIT WHEN get_VENTILATORS_energy%NOTFOUND;
--       htp.p(' <TR> <TD ALIGN="center"><B> '||tnerec.model||'</B>'||tnerec.model_size||'</TD>');
--       htp.p('      <TD ALIGN="center">'||tnerec.capacity_CFM||'</TD>');
--       htp.p('      <TD ALIGN="center">'||tnerec.efficiency||'</TD>');
--       htp.p('      <TD ALIGN="center">'||tnerec.elec_v_ph_hz||'</TD>');
--       htp.p('      <TD ALIGN="center">'||tnerec.cabinet_width||'</TD>');
--       htp.p('      <TD ALIGN="center">'||tnerec.cabinet_depth||'</TD>');
--       htp.p('      <TD ALIGN="center">'||tnerec.cabinet_height||'</TD>');
--       htp.p('      <TD ALIGN="center">'||tnerec.approx_ship_wt||'</TD>');
--       htp.p('</TR>');
--    END LOOP;

      htp.p('</TABLE>');
      htp.p('</CENTER>');

   END LOOP;
   CLOSE get_info;

   EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NULL;
   --   htp.p('<BR>No tables found for '||general_type||'<BR>');
   END write_ventilator;
/*======================================================*/
   PROCEDURE write_zone_control(
             general_type      IN VARCHAR2
             ) IS

   zcrec                        res_ZONEKIT%ROWTYPE;
   CURSOR get_ZONE_CONTROLS
       IS
   SELECT *
     FROM res_ZONEKIT;

   acrec                        res_ACCESSORY_CONTROLS%ROWTYPE;

   CURSOR get_ACCESSORY_CONTROLS (
          acc_category         IN VARCHAR2)
       IS
   SELECT *
     FROM res_ACCESSORY_CONTROLS
    WHERE upper(CATEGORY) LIKE acc_category;
--  ORDER BY??

   acrec2                       res_ACCESSORY_CONTROLS_2%ROWTYPE;

   CURSOR get_ACCESSORY_CONTROLS_2 (
          acc_category         IN VARCHAR2)
       IS
   SELECT *
     FROM res_ACCESSORY_CONTROLS_2
    WHERE upper(CATEGORY) LIKE acc_category;
--  ORDER BY??

   BEGIN

   CCUTIL.chtml_header;

   htp.p('<A HREF="'||owihome||'res_hm1/index.html" TARGET="_parent">');
   htp.p('<IMG SRC="'||owihome||'res_media/res_header_back_button.gif" 
        ALIGN=MIDDLE WIDTH="430" HEIGHT="32" BORDER="0"></A>');

   htp.p('<P>');
   htp.p('<A HREF="'||owihome||'res_iwc1/res_iwcd1.html" TARGET="bodyText">');
   htp.p('Indoor Weather Center Software</A>');


   htp.p('<P><BR><CENTER><H2>Zone Controls</H2></CENTER><P>');

   htp.p('<A HREF="#top"></A>'); 

--|htp.p('<BR>write_zone_control, general_type is '||general_type||'<BR>');
--|htp.p('<P><FONT SIZE=4>Product Photos and links go here </FONT><P>');

   htp.p('<CENTER>');   
--|htp.p('<IMG SRC="'||owihome||'res_media/Comfort_Zone_Two_Zone.jpg"></TD></NOBR>');
   htp.p('<IMG SRC="'||owihome||'res_media/zoning_products.jpg"></TD></NOBR>');
   htp.p('</CENTER>');   
   htp.p('<P>');

--|htp.p('<FONT SIZE=4>Product Descriptive Text goes here </FONT><P>');

   htp.p('<UL>');
   RESTXT.RES_ZONE_CONTROLS_TEXT;
   htp.p('</UL><P>');

   htp.p('<UL>');
   htp.p('<TABLE BORDER=3 WIDTH=90%>');
   htp.p(' <TR> <TH ALIGN="center" COLSPAN=7>COMFORT ZONE </TH></TR>');
   
   RESHDRS.RES_ZONE_CONTROLS_H;
   OPEN get_ZONE_CONTROLS;
   LOOP
      FETCH get_ZONE_CONTROLS INTO zcrec;
      EXIT WHEN get_ZONE_CONTROLS%NOTFOUND;
      IF ( upper(zcrec.model) LIKE 'ZONEKIT4%') THEN
         htp.p(' <TR> <TD ALIGN="left">'||zcrec.model||zcrec.model_size||'</TD>');
         htp.p('      <TD ALIGN="center">'||zcrec.operating_range_F_C||'</TD>');
         htp.p('      <TD ALIGN="center">*</TD>');
         htp.p('      <TD ALIGN="center">'||zcrec.length||'</TD>');
         htp.p('      <TD ALIGN="center">'||zcrec.width||'</TD>');
         htp.p('      <TD ALIGN="center">'||zcrec.height||'</TD>');
         htp.p('      <TD ALIGN="center"> ----- </TD>');
         htp.p('</TR>');
      ELSE
         NULL;
      END IF;
   END LOOP;
   CLOSE get_ZONE_CONTROLS;

   htp.p(' <TR> <TH ALIGN="center" COLSPAN=7>ACCESSORIES</TH></TR>');
   OPEN get_ACCESSORY_CONTROLS ( '%ACCESSORIES%');
   LOOP
      FETCH get_ACCESSORY_CONTROLS INTO acrec;
      EXIT WHEN get_ACCESSORY_CONTROLS%NOTFOUND;
      htp.p(' <TR> <TD ALIGN="left" COLSPAN=1>'||acrec.model||acrec.model_size||'</TD>');
      htp.p('      <TD ALIGN="left" COLSPAN=6>'||acrec.description||'</TD>');
      htp.p('</TR>');
   END LOOP;
   CLOSE get_ACCESSORY_CONTROLS;

--|htp.p(' <TR> <TH ALIGN="center" COLSPAN=7>MISCELLANEOUS</TH></TR>');
   OPEN get_ACCESSORY_CONTROLS ( '%MISCELLANEOUS%');
   LOOP
      FETCH get_ACCESSORY_CONTROLS INTO acrec;
      EXIT WHEN get_ACCESSORY_CONTROLS%NOTFOUND;
      htp.p(' <TR> <TD ALIGN="left" COLSPAN=1>'||acrec.model||'</TD>');
      htp.p('      <TD ALIGN="left" COLSPAN=6>'||acrec.description||'</TD>');
      htp.p('</TR>');
   END LOOP;
   CLOSE get_ACCESSORY_CONTROLS;

--|htp.p(' <TR> <TH ALIGN="center" COLSPAN=7>SOFTWARE</TH></TR>');
   OPEN get_ACCESSORY_CONTROLS ( '%SOFTWARE%');
   LOOP
      FETCH get_ACCESSORY_CONTROLS INTO acrec;
      EXIT WHEN get_ACCESSORY_CONTROLS%NOTFOUND;
      htp.p(' <TR> <TD ALIGN="left" COLSPAN=1>'||acrec.model||acrec.model_size||'</TD>');
      htp.p('      <TD ALIGN="left" COLSPAN=6>'||acrec.description||'</TD>');
      htp.p('</TR>');
   END LOOP;
   CLOSE get_ACCESSORY_CONTROLS;

   htp.p(' <TR> <TH ALIGN="center" COLSPAN=7>DAMPER-ACTUATOR</TH></TR>');
   OPEN get_ACCESSORY_CONTROLS ( '%DAMPER%ACT%');
   LOOP
      FETCH get_ACCESSORY_CONTROLS INTO acrec;
      EXIT WHEN get_ACCESSORY_CONTROLS%NOTFOUND;
      htp.p(' <TR> <TD ALIGN="left" COLSPAN=1>'||acrec.model||acrec.model_size||'</TD>');
      htp.p('      <TD ALIGN="left" COLSPAN=6>'||acrec.description||'</TD>');
      htp.p('</TR>');
   END LOOP;
   CLOSE get_ACCESSORY_CONTROLS;
   htp.p('</TABLE>');

   htp.p('<P>');
   htp.p('<TABLE BORDER=3 WIDTH=90%>');
   htp.p(' <TR> <TH ALIGN="center" COLSPAN=7>WEATHERMAKER TWO-ZONE </TH></TR>');
   RESHDRS.RES_ZONE_CONTROLS_H;
   OPEN get_ZONE_CONTROLS;
   LOOP
      FETCH get_ZONE_CONTROLS INTO zcrec;
      EXIT WHEN get_ZONE_CONTROLS%NOTFOUND;
      IF ( upper(zcrec.model) LIKE 'ZONEKIT2%') THEN
         htp.p(' <TR> <TD ALIGN="left">'||zcrec.model||zcrec.model_size||'</TD>');
         htp.p('      <TD ALIGN="center">'||zcrec.operating_range_F_C||'</TD>');
         htp.p('      <TD ALIGN="center">*</TD>');
         htp.p('      <TD ALIGN="center">'||zcrec.length||'</TD>');
         htp.p('      <TD ALIGN="center">'||zcrec.width||'</TD>');
         htp.p('      <TD ALIGN="center">'||zcrec.height||'</TD>');
         htp.p('      <TD ALIGN="center"> ------ </TD>');
         htp.p('</TR>');
      ELSE
         NULL;
      END IF;
   END LOOP;
   CLOSE get_ZONE_CONTROLS;

   htp.p(' <TR> <TH ALIGN="center" COLSPAN=7>ACCESSORIES</TH></TR>');
   OPEN get_ACCESSORY_CONTROLS_2 ( '%ACCESSORIES%');
   LOOP
      FETCH get_ACCESSORY_CONTROLS_2 INTO acrec2;
      EXIT WHEN get_ACCESSORY_CONTROLS_2%NOTFOUND;
      htp.p(' <TR> <TD ALIGN="left" COLSPAN=1>'||acrec2.model||acrec2.model_size||'</TD>');
      htp.p('      <TD ALIGN="left" COLSPAN=6>'||acrec2.description||'</TD>');
      htp.p('</TR>');
   END LOOP;
   CLOSE get_ACCESSORY_CONTROLS_2;

   htp.p(' <TR> <TH ALIGN="center" COLSPAN=7>DAMPER-ACTUATOR</TH></TR>');
   OPEN get_ACCESSORY_CONTROLS_2 ( '%DAMPER%ACT%');
   LOOP
      FETCH get_ACCESSORY_CONTROLS_2 INTO acrec2;
      EXIT WHEN get_ACCESSORY_CONTROLS_2%NOTFOUND;
      htp.p(' <TR> <TD ALIGN="left" COLSPAN=1>'||acrec2.model||acrec2.model_size||'</TD>');
      htp.p('      <TD ALIGN="left" COLSPAN=6>'||acrec2.description||'</TD>');
      htp.p('</TR>');
   END LOOP;
   CLOSE get_ACCESSORY_CONTROLS_2;

   htp.p('</TABLE>');
   htp.p('</UL>');

--|RESDOCS.write_zone_control_thermostats(general_type);

   EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NULL;
   --   htp.p('<BR>No tables found for '||general_type||'<BR>');
   END write_zone_control;
/*======================================================*/
   PROCEDURE write_zone_control_dampers(
             general_type      IN VARCHAR2
             ) IS

   rndrec               res_ROUND_DAMPERS%ROWTYPE;

   CURSOR get_ROUND_DAMPERS
       IS
   SELECT *
     FROM res_ROUND_DAMPERS;

   rctdrec              res_RECTANGULAR_DAMPERS%ROWTYPE;

   CURSOR get_RECTANGULAR_DAMPERS (
           modelprefix    IN VARCHAR2)
       IS
   SELECT *
     FROM res_RECTANGULAR_DAMPERS
    WHERE upper(model) = upper(modelprefix);

   slpdrec              res_SLIP_DAMPERS%ROWTYPE;

   CURSOR get_SLIP_DAMPERS
       IS
   SELECT *
     FROM res_SLIP_DAMPERS
     ORDER BY model_order;


   BEGIN

   CCUTIL.chtml_header;

   htp.p('<A HREF="'||owihome||'res_hm1/index.html" TARGET="_parent">');
   htp.p('<IMG SRC="'||owihome||'res_media/res_header_back_button.gif" 
        ALIGN=MIDDLE WIDTH="430" HEIGHT="32" BORDER="0"></A>');

   htp.p('<P><BR><CENTER><H2>Zone Controls -- Dampers</H2></CENTER><P>');

   htp.p('<A HREF="#top"></A>'); 

--|htp.p('<BR>write_zone_control_dampers, general_type is '||general_type||'<BR>');
--|htp.p('<P><FONT SIZE=4>No Product Photos? </FONT><P>');
--|htp.p('<FONT SIZE=4>Product Descriptive Text goes here </FONT><P>');
--|--------------------------------------------------------
   htp.p('<UL>');
   RESTXT.RES_DAMPERS_TEXT;
   htp.p('</UL><P>');
--|-------------------------------------------------------

   htp.p('<UL>');
-- itab  := 0;
-- OPEN get_tables(general_type);
-- LOOP
--    itab   := itab +1;
--    FETCH get_tables INTO tablenametab(itab); 
--    IF (upper(tablenametab(itab)) = 'RES_ROUND_DAMPERS' ) THEN
         htp.p('<TABLE BORDER=3 WIDTH=90%>');
         RESHDRS.RES_ROUND_DAMPERS_H;
         htp.p('<TR><TD COLSPAN=7 
                        ALIGN="center"><B>DAMPERS -- ROUND</B></TD></TR>');
         OPEN get_ROUND_DAMPERS;
         LOOP
            FETCH get_ROUND_DAMPERS INTO rndrec;
            EXIT WHEN get_ROUND_DAMPERS%NOTFOUND;
            htp.p(' <TR> <TD ALIGN="left">'||rndrec.model||rndrec.model_size||'</TD>');
            htp.p('      <TD ALIGN="left">'||rndrec.operating_range||'</TD>');
            htp.p('      <TD ALIGN="left">'||rndrec.wiring||'</TD>');
            htp.p('      <TD ALIGN="left">'||rndrec.depth||'</TD>');
            htp.p('      <TD ALIGN="left">'||rndrec.length||'</TD>');
            htp.p('      <TD ALIGN="left">'||rndrec.design_airflow||'</TD>');
            htp.p('      <TD ALIGN="left">'||rndrec.max_airflow||'</TD>');
            htp.p('</TR>');
         END LOOP;
         CLOSE get_ROUND_DAMPERS;
         htp.p('</TABLE><P>');
--    EXIT WHEN get_tables%NOTFOUND;
-- END LOOP;
-- CLOSE get_tables;

-- itab  := 0;
-- OPEN get_tables(general_type);
-- LOOP
--    itab   := itab +1;
--    FETCH get_tables INTO tablenametab(itab); 
--    IF (upper(tablenametab(itab)) = 'RES_RECTANGULAR_DAMPERS' ) THEN
         htp.p('<TABLE BORDER=3 WIDTH=90%>');
         RESHDRS.RES_RECTANGULAR_DAMPERS_H;
         OPEN get_RECTANGULAR_DAMPERS ('DAMPREC');
         htp.p('<TR><TD COLSPAN=6 
                       ALIGN="center"><B>DAMPERS -- RECTANGULAR</B></TD></TR>');
         LOOP
            FETCH get_RECTANGULAR_DAMPERS INTO rctdrec;
            EXIT WHEN get_RECTANGULAR_DAMPERS%NOTFOUND;
            htp.p(' <TR> <TD ALIGN="left">'||rctdrec.model||rctdrec.model_size||'</TD>');
            htp.p('      <TD ALIGN="left">'||rctdrec.operating_range||'</TD>');
            htp.p('      <TD ALIGN="left">'||rctdrec.wiring||'</TD>');
            htp.p('      <TD ALIGN="left">'||rctdrec.hgtwdthlgth||'</TD>');
            htp.p('      <TD ALIGN="left">'||rctdrec.design_airflow||'</TD>');
            htp.p('      <TD ALIGN="left">'||rctdrec.max_airflow||'</TD>');
            htp.p('</TR>');
         END LOOP;
         CLOSE get_RECTANGULAR_DAMPERS;

         OPEN get_RECTANGULAR_DAMPERS ('DAMPBAR');
         htp.p('<TR><TD COLSPAN=6 
                       ALIGN="center"><B>BAROMETRIC BYPASS</B></TD></TR>');
         LOOP
            FETCH get_RECTANGULAR_DAMPERS INTO rctdrec;
            EXIT WHEN get_RECTANGULAR_DAMPERS%NOTFOUND;
            htp.p(' <TR> <TD ALIGN="left">'||rctdrec.model||rctdrec.model_size||'</TD>');
            htp.p('      <TD ALIGN="left">'||rctdrec.operating_range||'</TD>');
            htp.p('      <TD ALIGN="left">'||rctdrec.wiring||'</TD>');
            htp.p('      <TD ALIGN="left">'||rctdrec.hgtwdthlgth||'</TD>');
            htp.p('      <TD ALIGN="left">'||rctdrec.design_airflow||'</TD>');
            htp.p('      <TD ALIGN="left">'||rctdrec.max_airflow||'</TD>');
            htp.p('</TR>');
         END LOOP;
         CLOSE get_RECTANGULAR_DAMPERS;

         htp.p('</TABLE><P>');
--    ELSE
--       NULL;
--    END IF;
--    EXIT WHEN get_tables%NOTFOUND;
-- END LOOP;
-- CLOSE get_tables;

-- itab  := 0;
-- OPEN get_tables(general_type);
-- LOOP
--    itab   := itab +1;
--    FETCH get_tables INTO tablenametab(itab); 
--    IF (upper(tablenametab(itab)) = 'RES_SLIP_DAMPERS' ) THEN
         htp.p('<TABLE BORDER=3 WIDTH=90%>');
         htp.p(' <TR> <TH ALIGN="center"> Model </TH>');
         htp.p('      <TH ALIGN="center"> Description </TH>');
         htp.p('</TR>');
         htp.p('<TR><TD COLSPAN=2 
                        ALIGN="center"><B>DAMPERS -- SLIP-IN</B></TD></TR>');
         OPEN get_SLIP_DAMPERS;
         LOOP
            FETCH get_SLIP_DAMPERS INTO slpdrec;
            EXIT WHEN get_SLIP_DAMPERS%NOTFOUND;
            htp.p(' <TR> <TD ALIGN="left">'||slpdrec.model||slpdrec.model_size||'</TD>');
            htp.p('      <TD ALIGN="left">'||slpdrec.description||'</TD>');
            htp.p('</TR>');
         END LOOP;
         CLOSE get_SLIP_DAMPERS;
         htp.p('</TABLE><P>');
--    ELSE
--       NULL;
--    END IF;
--    EXIT WHEN get_tables%NOTFOUND;
-- END LOOP;
-- CLOSE get_tables;
  
--|   htp.p('tablename('||itab||') is '||tablenametab(itab)||'<BR>');
   htp.p('</UL>');

   EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NULL;
   --   htp.p('<BR>No tables found for '||general_type||'<BR>');
   END write_zone_control_dampers;
/*======================================================*/
   PROCEDURE write_zone_control_thermostats(
             general_type      IN VARCHAR2
             ) IS

   acrec                        res_ACCESSORY_CONTROLS%ROWTYPE;

   CURSOR get_ACCESSORY_CONTROLS (
          acc_category         IN VARCHAR2)
       IS
   SELECT *
     FROM res_ACCESSORY_CONTROLS
    WHERE upper(CATEGORY) LIKE acc_category;

   BEGIN

   CCUTIL.chtml_header;

   htp.p('<A HREF="'||owihome||'res_hm1/index.html" TARGET="_parent">');
   htp.p('<IMG SRC="'||owihome||'res_media/res_header_back_button.gif" 
        ALIGN=MIDDLE WIDTH="430" HEIGHT="32" BORDER="0"></A>');

--|htp.p('<BR>write_zone_control_thermostats, general_type is '||general_type||'<BR>');
--|htp.p('<P><FONT SIZE=4>Product Photos and links go here </FONT><P>');

   htp.p('<P><BR><CENTER>');
   htp.p('<H2>Thermostats</H2><P>');

   htp.p('<A HREF="#top"></A>'); 

   htp.p('<CENTER>');
   htp.p('<IMG SRC="'||owihome||'res_media/Thermostats.jpg">');
   htp.p('</CENTER>');
   htp.p('<P>');
   htp.p('<table border=0> <tr><td align=left width=300><P>');
   RESTXT97.THERM_TXT;
   htp.p('</td></tr></table>');

   htp.p('<TABLE BORDER=3 WIDTH=90%>');
   htp.p(' <TR> <TH ALIGN="center" COLSPAN=2> THERMOSTATS </TH>');
   htp.p('</TR>');
   OPEN get_ACCESSORY_CONTROLS ('%THERMOSTAT%');
   LOOP
      FETCH get_ACCESSORY_CONTROLS INTO acrec;
      EXIT WHEN get_ACCESSORY_CONTROLS%NOTFOUND;
      htp.p(' <TR> <TD ALIGN="left" COLSPAN=1>'||acrec.model||acrec.model_size||'</TD>');
      htp.p('      <TD ALIGN="left" COLSPAN=1>'||acrec.description||'</TD>');
      htp.p('</TR>');
   END LOOP;
   CLOSE get_ACCESSORY_CONTROLS;
   htp.p('</TABLE>');

   EXCEPTION
      WHEN NO_DATA_FOUND THEN
        NULL;
     -- htp.p('<BR>No tables found for '||general_type||'<BR>');
   END write_zone_control_thermostats;
/*======================================================*/
   PROCEDURE write_no_table_found(
             general_type          IN VARCHAR2
             ) IS

   BEGIN

   CCUTIL.chtml_header;

   htp.p('<A HREF="'||owihome||'res_hm1/index.html" TARGET="_parent">');
   htp.p('<IMG SRC="'||owihome||'res_media/res_header_back_button.gif" 
        ALIGN=MIDDLE WIDTH="430" HEIGHT="32" BORDER="0"></A>');

   htp.p('<P>write_no_table_found, general_type is '||general_type||'<BR>');

   EXCEPTION
      WHEN NO_DATA_FOUND THEN
        htp.p('<BR>No tables found for '||general_type||'<BR>');
   END write_no_table_found;
/*======================================================*/
   PROCEDURE write_room_air_conditioners (
             general_type      IN VARCHAR2
             ) IS

   value_error             EXCEPTION;
   PRAGMA    EXCEPTION_INIT (value_error, -06502);

   str_line_num            EXCEPTION;
   PRAGMA    EXCEPTION_INIT (str_line_num, -06512);

   sptype               VARCHAR2(50);
   smin                 number(10);
   smax                 number(10);
   xseq                 NUMBER(10);
   mname                VARCHAR2(50);
   htmlmo               VARCHAR2(50);
   msize                VARCHAR2(20);
   cap                  VARCHAR2(20);
   modelsize            VARCHAR2(100);

   rprec                residential_products_97%ROWTYPE;

   CURSOR get_info IS
   SELECT distinct specifictype
     FROM residential_products
    WHERE upper(generaltype) = upper(general_type)
    ORDER BY specifictype;

   CURSOR get_rac_data (
          seq_min in number,
          seq_max in number )
          IS
   SELECT * 
     FROM RAC_UNITS_HC
    WHERE TO_NUMBER(xsequence) >= seq_min
      AND TO_NUMBER(xsequence) <= seq_max
     ORDER BY TO_NUMBER(xsequence), TO_NUMBER(cool_capacity);

--| WHERE model IN 
--|      (SELECT model from residential_products
--|       WHERE generaltype  = 'Room Air Conditioners'
--|         AND upper(specifictype) =  upper(stype) )

   BEGIN

   CCUTIL.chtml_header;

   htp.p('<A HREF="'||owihome||'res_hm1/index.html" TARGET="_parent">');
   htp.p('<IMG SRC="'||owihome||'res_media/res_header_back_button.gif" 
        ALIGN=MIDDLE WIDTH="430" HEIGHT="32" BORDER="0"></A><BR>');

   htp.p('<FONT SIZE=2><A HREF="#Heat Cool Units">Down to Heat/Cool Units</A><BR>');
   htp.p('<A HREF="#Heat Pump Units">Down to Heat Pumps</A></NOBR><BR>');

   htp.p('<P>');
   htp.p('<A HREF="#top"></A>'); 

   OPEN get_info;
   LOOP
      FETCH get_info INTO sptype;
      EXIT WHEN get_info%NOTFOUND;
      htp.p('<CENTER><FONT SIZE=5>Room Air Conditioning Units </FONT><BR>');
      htp.p('<FONT SIZE=4>'||sptype||'</FONT></CENTER><P>');

      IF ( sptype = 'Cool Only' ) THEN
         htp.p('<P><CENTER>');
         htp.p('<TABLE  WIDTH=90%>');
         htp.p(' <TR> ');
         htp.p('      <TD> <IMG SRC="'||owihome||'rac_media/TCA081D.jpg"
                       ALIGN="center" HEIGHT="110" BORDER="0" ALT="TCA"></TD>');
         htp.p('      <TD> <IMG SRC="'||owihome||'rac_media/ECB121D_2.jpg"
                       ALIGN="center" HEIGHT="110" BORDER="0" ALT="ECB"></TD>');
         htp.p('      <TD> <IMG SRC="'||owihome||'rac_media/LCA061P_1.jpg"
                       ALIGN="center" HEIGHT="110" BORDER="0" ALT="LCA"></TD>');
         htp.p('</TR>'); 
         htp.p(' <TR>'); 
         htp.p('      <TD ALIGN="center"><A HREF="#Cool Only">TCA081D </A></TD>');
         htp.p('      <TD ALIGN="center"><A HREF="#Cool Only">ECB121D </A></TD>'); 
         htp.p('      <TD ALIGN="center"><A HREF="#Cool Only">LCA061P </A></TD>'); 
         htp.p('</TR>'); 
         htp.p(' <TR> ');
         htp.p('      <TD> <IMG SRC="'||owihome||'rac_media/UCB061B_1.jpg"
                       ALIGN="center" HEIGHT="110" BORDER="0" ALT="TCA"></TD>');
         htp.p('      <TD> <IMG SRC="'||owihome||'rac_media/XCB_183d_1.jpg"
                       ALIGN="center" HEIGHT="110" BORDER="0" ALT="TCA"></TD>');
         htp.p('      <TD> <IMG SRC="'||owihome||'rac_media/HCA313D.jpg"
                       ALIGN="center" HEIGHT="110" BORDER="0" ALT="HCA"></TD>');
         htp.p('</TR>'); 
         htp.p(' <TR>'); 
         htp.p('      <TD ALIGN="center"><A HREF="#Cool Only">UCB061B </A></TD>'); 
         htp.p('      <TD ALIGN="center"><A HREF="#Cool Only">XCB183D </A></TD>');
         htp.p('      <TD ALIGN="center"><A HREF="#Cool Only">HCA313D </A></TD>');
         htp.p('</TR>'); 
         htp.p('</TABLE >');
         htp.p('</CENTER><P>');
         RESTXT.RAC_COOL_UNITS_TEXT;
         smin := 1;
         smax := 24;
         OPEN get_rac_data(smin, smax);
         htp.p('<A NAME="Cool Only"></A>');
      ELSIF ( sptype = 'Heat Cool Units') THEN
         htp.p('<A NAME="Heat Cool Units"></A>');
         htp.p('<P><CENTER>');
         htp.p('<TABLE  WIDTH=90%>');
         htp.p(' <TR> <TD> <IMG SRC="'||owihome||'rac_media/xh_wh.jpg"
                       ALIGN="center" HEIGHT="130" BORDER="0" ALT="XH series">');
         htp.p('      <P  ALIGN="center"><A HREF="#Heat Cool">XH/YH Series</A></TD>');
         htp.p('      <TD VALIGN="top">');
         RESTXT.RAC_HEAT_COOL_UNITS_TEXT;
         htp.p('      </TD></TR>');
         htp.p('</TABLE>');
         htp.p('</CENTER>');
         smin := 25;
         smax := 29;
         OPEN get_rac_data(smin, smax);
         htp.p('<FONT SIZE="-1"><A HREF="#top">top of page</A></FONT><BR>');
         htp.p('<A NAME="Heat Cool"></A>');
      ELSIF ( sptype = 'Heat Pump Units') THEN
         htp.p('<A NAME="Heat Pump Units"></A>');
         htp.p('<P><CENTER>');
         htp.p('<TABLE  WIDTH=90%>');
         htp.p(' <TR> <TD> <IMG SRC="'||owihome||'rac_media/xq.jpg"
                       ALIGN="center" HEIGHT="130" BORDER="0" ALT="XQ series">');
         htp.p('      <P  ALIGN="center"><A HREF="#Heat Pumps">XQ Series</A></TD>');
         htp.p('      <TD VALIGN="top">');
         RESTXT.RAC_HEAT_PUMPS_TEXT;
         htp.p('      </TD></TR>');
         htp.p('</TABLE>');
         htp.p('</CENTER>');
         smin := 30;
         smax := 33;
         OPEN get_rac_data(smin, smax);
         htp.p('<FONT SIZE="-1"><A HREF="#top">top of page</A></FONT><BR>');
         htp.p('<A NAME="Heat Pumps"></A>');
      END IF;

      htp.p('<CENTER>');
      htp.p('<TABLE BORDER=3 CELLPADDING=2 WIDTH=90%>');
      htp.p(' <TR><TD ALIGN="center">Model</TD>');
      htp.p('     <TD ALIGN="center">Nominal<BR>Capacity</TD>');
      htp.p('     <TD ALIGN="center">Voltage</TD>');
      htp.p('     <TD ALIGN="center">EER</TD>');
      htp.p('     <TD ALIGN="center">Airflow<BR>(CFM)</TD>');
      htp.p('     <TD ALIGN="center">Height<BR>(In)</TD>');
      htp.p('     <TD ALIGN="center">Width<BR>(In)</TD>');
      htp.p('     <TD ALIGN="center">Depth<BR>(In)</TD>');
      htp.p('     <TD ALIGN="center">Shipping<BR>Weight</TD></TR>');

      LOOP
         FETCH get_rac_data INTO racr;
         EXIT WHEN get_rac_data%NOTFOUND;
         msize        := racr.model_size;
         htmlmo       := REPLACE(racr.model,' ','+');
         htmlmo       := REPLACE(htmlmo,'-','%2D');
         cap          := TO_NUMBER(racr.cool_capacity);
         modelsize    := htmlmo||'$'||msize||'$'||cap;
         mname        := racr.model||racr.model_size;
         htp.p(' <TR><TD>'||mname||'<A NAME="'||mname||'"></A></TD>');
         htp.p('     <TD ALIGN="center"><A  METHOD="GET"  TARGET="_top"
                         HREF="'||wowhtml||'RACDOCS.load_rac_page2_res?modelsize='||modelsize||'">');
         htp.p(      ''||TO_NUMBER(racr.cool_capacity)||'</A></TD>');
         htp.p('     <TD ALIGN="center">'||TO_NUMBER(racr.volts)||'</TD>');
         htp.p('     <TD ALIGN="center">'||NVL(racr.EER,'-')||'</TD>');
         htp.p('     <TD ALIGN="center">'||TO_NUMBER(racr.CFM)||'</TD>');
         htp.p('     <TD ALIGN="center">'||racr.Height||'</TD>');
         htp.p('     <TD ALIGN="center">'||racr.Width||'</TD>');
         htp.p('     <TD ALIGN="center">'||racr.Depth||'</TD>');
         htp.p('     <TD ALIGN="center">'||TO_NUMBER(racr.Weight_Ship)||'</TD>');
         htp.p('</TR>');
      END LOOP;
      CLOSE get_rac_data; 
      htp.p('</TABLE>');
      htp.p('<P><P>');
   END LOOP;
   CLOSE get_info;

   CCUTIL.chtml_footer;

   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         htp.p('<BR>No data found in write_room_air_conditioners<BR>');
   END write_room_air_conditioners;
/*======================================================*/
END resdocs;
/
show errors;
/
