/*
 * Claim.java	
 *
 * implementation for IDL ::Flexi::Claim
 * 
 */

/**
 * The <code>Claim</code> class implements the 
 * <code>::Flexi::Claim</code> interface. 
 *
 * @author  Jawahar Malhotra
 * @version 1.0, 05/01/97
 * @see     Admin
 * @see     Account
 */

public class Claim extends Flexi._sk_Claim {

  public static final int CLMS_OPEN = 0;
  public static final int CLMS_CLOSED = 1;

  public static final int CLMR_UNKNOWN = 0;
  public static final int CLMR_ACCEPT = 1;
  public static final int CLMR_REJECT = 2;

  public static int _nextId = 1;

  Claim(Account account, float amount, String serviceDate, String providerName,
	String details) 
  {
    _account = account;
    _amount = amount;
    _serviceDate = serviceDate;
    _providerName = providerName;
    _description = details;
    _status = CLMS_OPEN;
    _resolution = CLMR_UNKNOWN;
    _claimId = _nextId++;
  }
  
  public void accept() throws Flexi.ClaimException {
    if (_status == CLMS_CLOSED) {
      throw new Flexi.ClaimException("Cannot accept an already closed claim.");
    }
    _status = CLMS_CLOSED;
    _resolution = CLMR_ACCEPT;
				// send payment to claimant
    _account.remitPayment(_amount);
  }

  public void reject() throws Flexi.ClaimException {
    if (_status == CLMS_CLOSED) {
      throw new Flexi.ClaimException("Cannot reject an already closed claim");
    }
    _status = CLMS_CLOSED;
    _resolution = CLMR_REJECT;
  }

  public void remove() throws Flexi.ClaimException {
    _account.clearCurrentClaim();
  }

  public String getStatus() {
    return ("Status of claim: " + _claimId 
	    + ", status = " + statusAsString()
	    + ", resolution = " + resolutionAsString()
	    + ".");
  }

  protected String statusAsString() {
    switch (_status) {
    case CLMS_OPEN:
      return "OPEN";
    case CLMS_CLOSED:
      return "CLOSED";
    }
    return "UNKNOWN";
  }

  protected String resolutionAsString() {
    switch (_resolution) {
    case CLMR_UNKNOWN:
      return "PENDING";
    case CLMR_ACCEPT:
      return "ACCEPTED";
    case CLMR_REJECT:
      return "REJECTED";
    }
    return "UNKNOWN";
  }

  Account _account;
  float _amount;
  String _serviceDate;
  String _providerName;
  String _description;
  int _status;
  int _resolution;
  int _claimId;
}
  
  
