DROP PACKAGE resdocsltc;
CREATE OR REPLACE PACKAGE resdocsltc AS

/*
   basehtml            VARCHAR2(60)    := 'http://mindy.infomall.org/';
   basewow             VARCHAR2(60)    := 'http://mindy.infomall.org:6380/';
   wowhtml             VARCHAR2(70)    := basewow||'cgi-bin/ifc/';
   owihome             VARCHAR2(70)    := basehtml||'wpstg/';
   widthll             NUMBER(10)   := 162;
*/
   basehtml            VARCHAR2(60)    := 'http://mindy.infomall.org:7080/';
   basewow             VARCHAR2(60)    := 'http://mindy.infomall.org:7080/';
   wowhtml             VARCHAR2(70)    := basewow||'cgi-bin/ifc/';
   owihome             VARCHAR2(70)    := basehtml;
   widthll             NUMBER(10)      := 162;


   TYPE fieldTblType    IS TABLE OF VARCHAR2(50)
                        INDEX BY BINARY_INTEGER;

   TYPE textTblType     IS TABLE OF VARCHAR2(50)
                        INDEX BY BINARY_INTEGER;

   CURSOR get_tables (gentype IN VARCHAR2) 
       IS
   SELECT distinct datatablename
     FROM residential_products_97
    WHERE upper(generaltype) = upper(gentype);

   itab                        NUMBER(5);
   tablenametab                textTblType;


   PROCEDURE write_light_commercial_units(
             general_type          IN VARCHAR2);

   PROCEDURE write_water_source_heat_pumps(
             general_type          IN VARCHAR2);

   PROCEDURE ltcomm_gas_header;

   PROCEDURE ltcomm_elec_header;

   PROCEDURE ltcomm_hp_header;

   PROCEDURE ltcomm_ws_hp_header;

   PROCEDURE ltcomm_dual_fuel_header;

   PROCEDURE ltcomm_pack_hp_stdeff_header;

   PROCEDURE ltcomm_pack_hp_hieff_header;

END resdocsltc;
/
show errors;
/
/*======================================================*/

CREATE OR REPLACE PACKAGE BODY resdocsltc IS

/*======================================================*/
   PROCEDURE write_light_commercial_units(
             general_type          IN VARCHAR2
             ) IS

   rprec           residential_products_97%ROWTYPE;

   CURSOR get_info (tablename IN VARCHAR2) IS
   SELECT * 
     FROM residential_products_97
    WHERE upper(generaltype) = upper(general_type)
      AND upper(datatablename) = tablename
    ORDER BY TO_NUMBER(xsequence);
   
   CURSOR get_ltcomm_gas (
          modelprefix    IN VARCHAR2 )
       IS
   SELECT *
     FROM ltcomm_pack_gas_heat_elec_cool
    WHERE upper(model) = upper(modelprefix)
    ORDER BY TO_NUMBER(model_order);
   
   CURSOR get_ltcomm_elec (
          modelprefix    IN VARCHAR2 )
       IS
   SELECT *
     FROM ltcomm_pack_elec_cool
    WHERE upper(model) = upper(modelprefix)
      AND upper(model) LIKE '50S%'
    ORDER BY TO_NUMBER(modelsize);
   
   CURSOR get_ltcomm_elec_zp (
          modelprefix    IN VARCHAR2 )
       IS
   SELECT *
     FROM ltcomm_pack_elec_cool
    WHERE upper(model) = upper(modelprefix)
      AND upper(model) LIKE '50Z%'
    ORDER BY TO_NUMBER(modelsize);

   CURSOR get_ltcomm_hp (
          modelprefix    IN VARCHAR2 )
       IS
   SELECT *
     FROM ltcomm_pack_heatpump
    WHERE upper(model) = upper(modelprefix)
    ORDER BY TO_NUMBER(modelsize);

   CURSOR get_ltcomm_dual_fuel (
          modelprefix    IN VARCHAR2 )
       IS
   SELECT *
     FROM ltcomm_dual_fuel_heat_pump
    WHERE upper(model) = upper(modelprefix)
    ORDER BY TO_NUMBER(modelsize);

   ltcg                get_ltcomm_gas%ROWTYPE;
   ltce                get_ltcomm_elec%ROWTYPE;
   ltchp               get_ltcomm_hp%ROWTYPE;
   ltdfhp              get_ltcomm_dual_fuel%ROWTYPE;
   
   BEGIN

   CCUTIL.chtml_header('light commercial units product page');

   htp.p('<A HREF="'||owihome||'res_hm1/index.html" TARGET="_parent">');
   htp.p('<IMG SRC="'||owihome||'res_media/res_header_back_button.gif" 
        ALIGN=MIDDLE WIDTH="430" HEIGHT="32" BORDER="0"></A>');

   htp.p('<P><BR>');
   htp.p('<CENTER><FONT SIZE=5>Light Commercial Units</FONT></CENTER>');
   htp.p('<P><P>');
   htp.p('<CENTER><FONT SIZE=4>High Efficiency Gas Heating/Electric Cooling </FONT></CENTER>');
   htp.p('<P>');
   
   htp.p('<A HREF="#top"></A>'); 

--|DOC: photos, text and tables for models 48SS and 48SX

   htp.p('<CENTER>');
   htp.p('<TABLE WIDTH=80% >');
   htp.p(' <TR> <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'com_media/48SS.jpg"');
   htp.p('         ALIGN="center" HEIGHT="110" BORDER="0" ALT="48SS"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'com_media/48_sx_hx.jpg"');
   htp.p('         ALIGN="center" HEIGHT="110" BORDER="0" ALT="48SX"></TD>');
   htp.p('</TR>');
   htp.p(' <TR> <TD ALIGN="center"><A HREF="#48SSA">48SS</A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#48SXA">48SX</A></TD>');
   htp.p('</TR>');
   htp.p('</TABLE>');
   htp.p('<P>');
   htp.p('<I>Click on the model number above to jump to its performance
             table</I>');
   htp.p('<P>');
   htp.p('</CENTER>');


   htp.p('<TABLE COLSPEC="35% 65%" CELLSPACING = 4>');

   htp.p('<TR><TD ALIGN="LEFT" VALIGN="TOP">');
   RESTXT97.res_48sx_txt;

   htp.p('</TD><TD VALIGN="TOP">');

   htp.p('<TABLE BORDER =3>');
   RESDOCSLTC.ltcomm_gas_header;
   OPEN get_info ('LTCOMM_PACK_GAS_HEAT_ELEC_COOL');
   LOOP
      FETCH get_info INTO rprec;
      EXIT WHEN get_info%NOTFOUND;
      htp.p('<TR> <TD COLSPAN=12 ALIGN="center">');
      htp.p('        <A NAME="'||rprec.model||'"></A><NOBR>');
      htp.p('        <FONT SIZE="-1"><A HREF="#top">top of page</A>');
      htp.p('              </NOBR></FONT><BR>');
      htp.p('        <FONT SIZE=4>'||rprec.description||'</FONT>');
      htp.p('     </TD>');
      htp.p('</TR>');
      OPEN get_ltcomm_gas (rprec.model);
      LOOP
         FETCH get_ltcomm_gas INTO ltcg;
         EXIT WHEN get_ltcomm_gas%NOTFOUND;
         htp.p('<TR> <TD ALIGN="left"> <B>'||ltcg.model||'</B>'||ltcg.modelsize||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltcg.nomcap||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltcg.netclgcap||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltcg.seer||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltcg.heatinput||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltcg.nomairflow||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltcg.wgt||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltcg.soundrating||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltcg.width||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltcg.height||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltcg.length||'</TD>');
         htp.p('</TR>');
      END LOOP;
      CLOSE get_ltcomm_gas;
   END LOOP;
   CLOSE get_info;
   htp.p('</TABLE>');
   
   htp.p('</TR>');
   htp.p('</TABLE>');

--|-----------------------------------------------------

   htp.p('<P><HR><P>');
   htp.p('<CENTER><FONT SIZE=4>Packaged Electric Cooling </FONT></CENTER>');
   htp.p('<P><P>');

   htp.p('<CENTER>');
   htp.p('<TABLE WIDTH=90% >');
   htp.p(' <TR>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'com_media/50_ZP.jpg"');
   htp.p('         ALIGN="center" HEIGHT="110" BORDER="0" ALT="50ZP"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'com_media/50_sx.jpg"');
   htp.p('         ALIGN="center" HEIGHT="110" BORDER="0" ALT="50SX"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'com_media/50_SS.jpg"');
   htp.p('         ALIGN="center" HEIGHT="110" BORDER="0" ALT="50SS"></TD>');
   htp.p('</TR>');
   htp.p(' <TR> <TD ALIGN="center"><A HREF="#50ZP">50ZP</A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#50SXA">50SX</A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#50SSA">50SS</A></TD>');
   htp.p('</TR>');
   htp.p('</TABLE>');
   htp.p('<P>');
   htp.p('<I>Click on the model number above to jump to its performance
             table</I>');
   htp.p('<P>');

   htp.p('<P><HR><P>');
   htp.p('<CENTER><FONT SIZE=4>High Efficiency Packaged Electric Cooling </FONT></CENTER>');
   htp.p('<P><P>');
   htp.p('</CENTER>');

-- htp.p('<TABLE COLSPEC="40% 60%" CELLSPACING = 4>');

-- htp.p('<TR><TD ALIGN="LEFT" VALIGN="TOP">');
   RESTXT97.res_50sx_txt;

-- htp.p('</TD><TD VALIGN="TOP">');

   htp.p('<TABLE BORDER =3>');
   RESDOCSLTC.ltcomm_elec_header;
   OPEN get_info ('LTCOMM_PACK_ELEC_COOL');
   LOOP
      FETCH get_info INTO rprec;
      EXIT WHEN get_info%NOTFOUND;
      htp.p('<!-- model starts with ['||SUBSTR(rprec.model,0, 3)||'] -->');
      IF ( SUBSTR(rprec.model, 0, 3) = '50S') THEN
         htp.p('<TR> <TD COLSPAN=16 ALIGN="center">');
         htp.p('        <A NAME="'||rprec.model||'"></A><NOBR>');
         htp.p('        <FONT SIZE="-1"><A HREF="#top">top of page</A>');
         htp.p('              </NOBR></FONT><BR>');
         htp.p('        <FONT SIZE=4>'||rprec.description||'</FONT>');
         htp.p('     </TD>');
         htp.p('</TR>');
      END IF;
      OPEN get_ltcomm_elec (rprec.model);
      LOOP
         FETCH get_ltcomm_elec INTO ltce;
         EXIT WHEN get_ltcomm_elec%NOTFOUND;
         htp.p('<TR> <TD ALIGN="left"> <B>'||ltce.model||'</B>'||ltce.modelsize||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltce.nomcap||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltce.netclgcap||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltce.seer||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltce.nomairflow||'</TD>');
         htp.p('     <TD ALIGN="center">'||NVL(ltce.MCA_230_1, '--')||'</TD>');
         htp.p('     <TD ALIGN="center">'||NVL(ltce.MOCP_230_1, '--')||'</TD>');
         htp.p('     <TD ALIGN="center">'||NVL(ltce.MCA_230_3, '--')||'</TD>');
         htp.p('     <TD ALIGN="center">'||NVL(ltce.MOCP_230_3, '--')||'</TD>');
         htp.p('     <TD ALIGN="center">'||NVL(ltce.MCA_460_3, '--')||'</TD>');
         htp.p('     <TD ALIGN="center">'||NVL(ltce.MOCP_460_3, '--')||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltce.approxoperweight||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltce.soundrating||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltce.width||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltce.height||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltce.length||'</TD>');
         htp.p('</TR>');
      END LOOP;
      CLOSE get_ltcomm_elec;
   END LOOP;
   CLOSE get_info;
   htp.p('</TABLE>');

-- htp.p('</TD></TR></TABLE>');

--==========================

   htp.p('<P><HR><P>');
   htp.p('<CENTER><FONT SIZE=4>Standard Efficiency Packaged Electric Cooling </FONT></CENTER>');
   htp.p('<P><P>');


   htp.p('<TABLE BORDER =3>');
   RESDOCSLTC.ltcomm_elec_header;
   OPEN get_info ('LTCOMM_PACK_ELEC_COOL');
   LOOP
      FETCH get_info INTO rprec;
      EXIT WHEN get_info%NOTFOUND;
      htp.p('<!-- model starts with ['||SUBSTR(rprec.model,0, 3)||'] -->');
      IF ( SUBSTR(rprec.model, 0, 3) = '50Z') THEN
         htp.p('<TR> <TD COLSPAN=16 ALIGN="center">');
         htp.p('        <A NAME="'||rprec.model||'"></A><NOBR>');
         htp.p('        <FONT SIZE="-1"><A HREF="#top">top of page</A>');
         htp.p('              </NOBR></FONT><BR>');
         htp.p('        <FONT SIZE=4>'||rprec.description||'</FONT>');
         htp.p('     </TD>');
         htp.p('</TR>');
      END IF;
      OPEN get_ltcomm_elec_zp (rprec.model);
      LOOP
         FETCH get_ltcomm_elec_zp INTO ltce;
         EXIT WHEN get_ltcomm_elec_zp%NOTFOUND;
         htp.p('<TR> <TD ALIGN="left"> <B>'||ltce.model||'</B>'||ltce.modelsize||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltce.nomcap||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltce.netclgcap||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltce.seer||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltce.nomairflow||'</TD>');
         htp.p('     <TD ALIGN="center">'||NVL(ltce.MCA_230_1, '--')||'</TD>');
         htp.p('     <TD ALIGN="center">'||NVL(ltce.MOCP_230_1, '--')||'</TD>');
         htp.p('     <TD ALIGN="center">'||NVL(ltce.MCA_230_3, '--')||'</TD>');
         htp.p('     <TD ALIGN="center">'||NVL(ltce.MOCP_230_3, '--')||'</TD>');
         htp.p('     <TD ALIGN="center">'||NVL(ltce.MCA_460_3, '--')||'</TD>');
         htp.p('     <TD ALIGN="center">'||NVL(ltce.MOCP_460_3, '--')||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltce.approxoperweight||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltce.soundrating||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltce.width||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltce.height||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltce.length||'</TD>');
         htp.p('</TR>');
      END LOOP;
      CLOSE get_ltcomm_elec_zp;
   END LOOP;
   CLOSE get_info;
   htp.p('</TABLE>');

--==========================

   htp.p('<P><BR>');
   htp.p('<CENTER><FONT SIZE=5>Packaged Heat Pumps</FONT></CENTER>');
   htp.p('<P><P>');
   
   htp.p('<A HREF="#top"></A>'); 

   htp.p('<CENTER>');
   htp.p('<TABLE WIDTH=80% >');
   htp.p(' <TR>');

   htp.p('<TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'com_media/50_HS.jpg"');
   htp.p('         ALIGN="center" HEIGHT="110" BORDER="0" ALT="50HS"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'com_media/50_sx_hx.jpg"');
   htp.p('         ALIGN="center" HEIGHT="110" BORDER="0" ALT="50SX"></TD>');
   htp.p('<TD ALIGN="center">');
   htp.p('<IMG SRC="http://mindy.infomall.org:6377/wpdv/com_media/50_ZP.jpg"');
   htp.p('ALIGN="center" HEIGHT="110" BORDER="0" ALT="50ZH"></TD>');
   htp.p('</TR>');
   htp.p(' <TR> <TD ALIGN="center"><A HREF="#50HSA">50HS</A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#50HXA">50HX</A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#50ZH">50ZH</A></TD>');
   htp.p('</TR>');
   htp.p('</TABLE>');
   htp.p('<P>');
   htp.p('<I>Click on the model number above to jump to its performance
             table</I>');
   htp.p('<P>');

--===============================================

   RESTXT97.res_50hx_txt;


   OPEN get_info ('LTCOMM_PACK_HEATPUMP');
   LOOP
      FETCH get_info INTO rprec;
      htp.p('<!-- 1st 4 letters of ltcomm heatpump model are '||SUBSTR(rprec.model, 0, 4)||' -->'); 
      EXIT WHEN get_info%NOTFOUND;
      IF ( SUBSTR(rprec.model, 0, 4) = '50HX') THEN

         htp.p('<P><BR>');
         htp.p('<CENTER><FONT SIZE=5>High Efficiency Packaged Heat Pumps (2-5 Tons)</FONT></CENTER>');
         htp.p('<P><P>');

         htp.p('<TABLE BORDER =3>');
         RESDOCSLTC.ltcomm_pack_hp_hieff_header;
         htp.p('<TR> <TD COLSPAN=14 ALIGN="center">');
         htp.p('        <A NAME="'||rprec.model||'"></A><NOBR>');
         htp.p('        <FONT SIZE="-1"><A HREF="#top">top of page</A>');
         htp.p('              </NOBR></FONT><BR>');
         htp.p('        <FONT SIZE=4>'||rprec.description||'</FONT>');
         htp.p('     </TD>');
         htp.p('</TR>');
         OPEN get_ltcomm_hp (rprec.model);
         LOOP
            FETCH get_ltcomm_hp INTO ltchp;
            EXIT WHEN get_ltcomm_hp%NOTFOUND;
            htp.p('<TR> <TD ALIGN="left"> <B>'||ltchp.model||'</B>'||ltchp.modelsize||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.nomcap||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.netclgcap||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.seer||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.nethtgcap||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.hspf||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.nomairflow||'</TD>');
            htp.p('     <TD ALIGN="center">'||NVL(ltchp.MCA_230_1, '--')||'</TD>');
            htp.p('     <TD ALIGN="center">'||NVL(ltchp.MOCP_230_1, '--')||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.approxoperweight||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.soundrating||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.width||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.height||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.length||'</TD>');
            htp.p('</TR>');
         END LOOP;
         CLOSE get_ltcomm_hp;
         htp.p('</TABLE>');

      ELSIF ( SUBSTR(rprec.model, 0, 4) = '50HS') THEN

         htp.p('<P><BR>');
         htp.p('<CENTER><FONT SIZE=5>Standard Efficiency Packaged Heat Pumps (1.5-5 Tons)</FONT></CENTER>');
         htp.p('<P><P>');

         htp.p('<TABLE BORDER =3>');
         RESDOCSLTC.ltcomm_pack_hp_stdeff_header;
         htp.p('<TR> <TD COLSPAN=18 ALIGN="center">');
         htp.p('        <A NAME="'||rprec.model||'"></A><NOBR>');
         htp.p('        <FONT SIZE="-1"><A HREF="#top">top of page</A>');
         htp.p('              </NOBR></FONT><BR>');
         htp.p('        <FONT SIZE=4>'||rprec.description||'</FONT>');
         htp.p('     </TD>');
         htp.p('</TR>');
         OPEN get_ltcomm_hp (rprec.model);
         LOOP
            FETCH get_ltcomm_hp INTO ltchp;
            EXIT WHEN get_ltcomm_hp%NOTFOUND;
            htp.p('<TR> <TD ALIGN="left"> <B>'||ltchp.model||'</B>'||ltchp.modelsize||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.nomcap||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.netclgcap||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.seer||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.nethtgcap||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.hspf||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.nomairflow||'</TD>');
            htp.p('     <TD ALIGN="center">'||NVL(ltce.MCA_230_1, '--')||'</TD>');
            htp.p('     <TD ALIGN="center">'||NVL(ltce.MOCP_230_1, '--')||'</TD>');
            htp.p('     <TD ALIGN="center">'||NVL(ltce.MCA_230_3, '--')||'</TD>');
            htp.p('     <TD ALIGN="center">'||NVL(ltce.MOCP_230_3, '--')||'</TD>');
            htp.p('     <TD ALIGN="center">'||NVL(ltce.MCA_460_3, '--')||'</TD>');
            htp.p('     <TD ALIGN="center">'||NVL(ltce.MOCP_460_3, '--')||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.approxoperweight||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.soundrating||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.width||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.height||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.length||'</TD>');
            htp.p('</TR>');
         END LOOP;
         CLOSE get_ltcomm_hp;
         htp.p('</TABLE>');

      ELSIF ( SUBSTR(rprec.model, 0, 4) = '50ZH') THEN
         htp.p('<P><BR>');
         htp.p('<CENTER><FONT SIZE=5>Standard Efficiency Packaged Heat Pumps (2-5 Tons)</FONT></CENTER>');
         htp.p('<P><P>');

         htp.p('<TABLE BORDER =3>');
         RESDOCSLTC.ltcomm_pack_hp_stdeff_header;
         htp.p('<TR> <TD COLSPAN=18 ALIGN="center">');
         htp.p('        <A NAME="'||rprec.model||'"></A><NOBR>');
         htp.p('        <FONT SIZE="-1"><A HREF="#top">top of page</A>');
         htp.p('              </NOBR></FONT><BR>');
         htp.p('        <FONT SIZE=4>'||rprec.description||'</FONT>');
         htp.p('     </TD>');
         htp.p('</TR>');
         OPEN get_ltcomm_hp (rprec.model);
         LOOP
            FETCH get_ltcomm_hp INTO ltchp;
            EXIT WHEN get_ltcomm_hp%NOTFOUND;
            htp.p('<TR> <TD ALIGN="left"> <B>'||ltchp.model||'</B>'||ltchp.modelsize||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.nomcap||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.netclgcap||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.seer||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.nethtgcap||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.hspf||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.nomairflow||'</TD>');
            htp.p('     <TD ALIGN="center">'||NVL(ltce.MCA_230_1, '--')||'</TD>');
            htp.p('     <TD ALIGN="center">'||NVL(ltce.MOCP_230_1, '--')||'</TD>');
            htp.p('     <TD ALIGN="center">'||NVL(ltce.MCA_230_3, '--')||'</TD>');
            htp.p('     <TD ALIGN="center">'||NVL(ltce.MOCP_230_3, '--')||'</TD>');
            htp.p('     <TD ALIGN="center">'||NVL(ltce.MCA_460_3, '--')||'</TD>');
            htp.p('     <TD ALIGN="center">'||NVL(ltce.MOCP_460_3, '--')||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.approxoperweight||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.soundrating||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.width||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.height||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltchp.length||'</TD>');
            htp.p('</TR>');
         END LOOP;
         CLOSE get_ltcomm_hp;
         htp.p('</TABLE>');

      END IF;
   END LOOP;
   CLOSE get_info;

  OPEN get_info ('ltcomm_dual_fuel_heat_pump');
  LOOP
     FETCH get_info INTO rprec;
     htp.p('<!-- 1st 4 letters of ltcomm heatpump model are '||SUBSTR(rprec.model, 0, 4)||' -->'); 
     EXIT WHEN get_info%NOTFOUND;
	 htp.p('<P><BR>');
         htp.p('<CENTER><FONT SIZE=5>High Efficiency Packaged Dual Fuel (2.5-5 Tons)</FONT></CENTER>');
         htp.p('<P><P>');

         htp.p('<TABLE BORDER =3>');
         
	 RESDOCSLTC.ltcomm_dual_fuel_header;
         htp.p('<TR> <TD COLSPAN=14 ALIGN="center">');
         htp.p('        <A NAME="'||rprec.model||'"></A><NOBR>');
         htp.p('        <FONT SIZE="-1"><A HREF="#top">top of page</A>');
         htp.p('              </NOBR></FONT><BR>');
         htp.p('        <FONT SIZE=4>'||rprec.description||'</FONT>');
         htp.p('     </TD>');
         htp.p('</TR>');		
         OPEN get_ltcomm_dual_fuel (rprec.model);
         LOOP
            FETCH get_ltcomm_dual_fuel INTO ltdfhp;
            EXIT WHEN get_ltcomm_dual_fuel%NOTFOUND;
	    htp.p('<TR> <TD ALIGN="center"> <B>'||ltdfhp.model||'</B>'||ltdfhp.modelsize||'</TD>');
	    htp.p('     <TD ALIGN="center">'||ltdfhp.nomcap||'</TD>');
	    htp.p('     <TD ALIGN="center">'||ltdfhp.NETCLGCAPAT95F||'</TD>');
	    htp.p('     <TD ALIGN="center">'||ltdfhp.SEER||'</TD>');
	    htp.p('     <TD ALIGN="center">'||ltdfhp.HeatInp||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltdfhp.HSPF||'</TD>');
	    htp.p('     <TD ALIGN="center">'||ltdfhp.NOMAIRFLOW||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltdfhp.MCA_230_1||'</TD>');
	    htp.p('     <TD ALIGN="center">'||ltdfhp.MOCP_230_1||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltdfhp.MCA_230_3||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltdfhp.MOCP_230_3||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltdfhp.MCA_460_3||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltdfhp.MOCP_460_3||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltdfhp.APPROXOPERWEIGHT||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltdfhp.SOUNDRATING||'</TD>');
	    htp.p('     <TD ALIGN="center">'||ltdfhp.width||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltdfhp.height||'</TD>');
            htp.p('     <TD ALIGN="center">'||ltdfhp.length||'</TD>');
            htp.p('</TR>');
         END LOOP;
         CLOSE get_ltcomm_dual_fuel;
      END LOOP;
      CLOSE get_info;
      htp.p('</TABLE>');

--===============================================



   CCUTIL.chtml_footer;

   END write_light_commercial_units;
/*======================================================*/
   PROCEDURE write_water_source_heat_pumps(
             general_type          IN VARCHAR2
             ) IS

   rprec           residential_products_97%ROWTYPE;

   CURSOR get_info (tablename IN VARCHAR2) IS
   SELECT * 
     FROM residential_products_97
    WHERE upper(generaltype) = upper(general_type)
      AND upper(datatablename) = upper(tablename)
    ORDER BY TO_NUMBER(xsequence);
   
   CURSOR get_water_source_hp (
          modelprefix    IN VARCHAR2 )
       IS
   SELECT *
     FROM ltcomm_water_source_heatpump
    WHERE upper(model) = upper(modelprefix)
    ORDER BY TO_NUMBER(modelsize);

   ltwshp               get_water_source_hp%ROWTYPE;
   
   BEGIN

   CCUTIL.chtml_header('water source heat pumps product page');

   htp.p('<A HREF="'||owihome||'res_hm1/index.html" TARGET="_parent">');
   htp.p('<IMG SRC="'||owihome||'res_media/res_header_back_button.gif" 
        ALIGN=MIDDLE WIDTH="430" HEIGHT="32" BORDER="0"></A>');

   htp.p('<P><BR>');
   htp.p('<CENTER><FONT SIZE=5>Water Source Heat Pumps</FONT></CENTER>');
   htp.p('<P><P>');
   
   htp.p('<A HREF="#top"></A>'); 


/*
   htp.p('<CENTER>');
   htp.p('<TABLE WIDTH=60% >');
   htp.p(' <TR> <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'com_media/50_HS.jpg"');
   htp.p('         ALIGN="center" HEIGHT="110" BORDER="0" ALT="50HS"></TD>');
   htp.p('      <TD ALIGN="center">');
   htp.p('         <IMG SRC="'||owihome||'com_media/50_sx_hx.jpg"');
   htp.p('         ALIGN="center" HEIGHT="110" BORDER="0" ALT="50SX"></TD>');
   htp.p('</TR>');
   htp.p(' <TR> <TD ALIGN="center"><A HREF="#50HS">50HQA</A></TD>');
   htp.p('      <TD ALIGN="center"><A HREF="#50SX">50VQA</A></TD>');
   htp.p('</TR>');
   htp.p('</TABLE>');
   htp.p('<P>');
   htp.p('<I>Click on the model number above to jump to its performance
             table</I>');
   htp.p('<P>');
*/


-- htp.p('<UL>');
-- RESDOCSLTC.LT_COMM_WS_HP_TEXT;
-- htp.p('</UL>');
-- htp.p('<P><P>');

   htp.p('<!-- general_type is '||general_type||' input parameter -->');

   htp.p('<CENTER>');
   htp.p('<TABLE BORDER =3>');
   RESDOCSLTC.ltcomm_ws_hp_header;
   OPEN get_info ('LTCOMM_WATER_SOURCE_HEATPUMP');
   LOOP
      FETCH get_info INTO rprec;
      EXIT WHEN get_info%NOTFOUND;
      htp.p('<TR> <TD COLSPAN=12 ALIGN="center">');
      htp.p('        <A NAME="'||rprec.model||'"></A><NOBR>');
      htp.p('        <FONT SIZE="-1"><A HREF="#top">top of page</A>');
      htp.p('              </NOBR></FONT><BR>');
      htp.p('        <FONT SIZE=4>'||rprec.description||'</FONT>');
      htp.p('     </TD>');
      htp.p('</TR>');
      OPEN get_water_source_hp (rprec.model);
      LOOP
         FETCH get_water_source_hp INTO ltwshp;
         EXIT WHEN get_water_source_hp%NOTFOUND;
         htp.p('<TR> <TD ALIGN="left"> <B>'||ltwshp.model||'</B>'||ltwshp.modelsize||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltwshp.nomcap||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltwshp.nomclgcap||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltwshp.eer||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltwshp.nomhtgcap||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltwshp.cop||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltwshp.approxoperweight||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltwshp.width||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltwshp.height||'</TD>');
         htp.p('     <TD ALIGN="center">'||ltwshp.length||'</TD>');
         htp.p('</TR>');
      END LOOP;
      CLOSE get_water_source_hp;
   END LOOP;
   CLOSE get_info;
   htp.p('</TABLE>');
   htp.p('</CENTER>');
   
   
   CCUTIL.chtml_footer;

   END write_water_source_heat_pumps;
/*======================================================*/
   PROCEDURE ltcomm_gas_header IS

   BEGIN

   htp.p('<TR>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1 ROWSPAN=2>Model</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1 ROWSPAN=2>Nom.<BR>Tons</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=2>ARI<BR>Cooling Performance</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1 ROWSPAN=2>Heat<BR>Input<BR>(mbh)</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1 ROWSPAN=2>Std.<BR>CFM</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1 ROWSPAN=2>Approx.<BR>OperWt<BR>(lbs)</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1 ROWSPAN=2>Sound<BR>(bels)</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=3 ROWSPAN=1>Dimensions (in)</TH>');
   htp.p('</TR>');
   htp.p('<TR>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>Btuh</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>SEER</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>Width</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>Height</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>Length</TH>');
   htp.p('</TR>');

   END ltcomm_gas_header;
/*======================================================*/
   PROCEDURE ltcomm_elec_header IS

   BEGIN

--| For Units 50SX, 50SS and 50 ZP, ltcomm_pack_elec_cool

   htp.p('<TR>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1 ROWSPAN=4>Model</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1 ROWSPAN=4>Nom.<BR>Tons</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=2 ROWSPAN=3>ARI<BR>Cooling <BR>Performance</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1 ROWSPAN=4>Nom.<BR>CFM</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=6 ROWSPAN=1>Electrical Data</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1 ROWSPAN=4>Approx.<BR>Ship.<BR>Weight<BR>(lbs)</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1 ROWSPAN=4>Sound<BR>(bels)</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=3 ROWSPAN=3>Dimensions<BR> (in)</TH>');
   htp.p('</TR>');
   htp.p('<TR>');
   htp.p('    	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=1>V-PH-HZ</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=1>V-PH-HZ</TH>');
   htp.p('  	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=1>V-PH-HZ</TH>');
   htp.p('</TR>');
   htp.p('<TR>');
   htp.p('     	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=1>208/230-1-60</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=1>208/230-3-60</TH>');
   htp.p('  	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=1>460-3-60</TH>');
   htp.p('</TR>');
   htp.p('<TR>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>Btuh</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>SEER</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>MCA</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>MOCP</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>MCA</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>MOCP</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>MCA</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>MOCP</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>Width</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>Height</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>Depth</TH>');
   htp.p('</TR>');

   END ltcomm_elec_header;
/*======================================================*/
   PROCEDURE ltcomm_hp_header IS

   BEGIN

   htp.p('<TR>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1 ROWSPAN=2>Model</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1 ROWSPAN=2>Nom.<BR>Tons</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=2>ARI<BR>Cooling Performance</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=2>Heating Performance</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1 ROWSPAN=2>Std.<BR>CFM</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1 ROWSPAN=2>Approx.<BR>OperWt(lbs)</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1 ROWSPAN=2>Sound<BR>(bels)</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=3 ROWSPAN=1>Dimensions (in)</TH>');
   htp.p('</TR>');
   htp.p('<TR>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>Btuh</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>SEER</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>Btuh</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>HSPF</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>Width</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>Height</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>Length</TH>');
   htp.p('</TR>');

   END ltcomm_hp_header;
/*======================================================*/
   PROCEDURE ltcomm_ws_hp_header IS

   BEGIN

   htp.p('<TR>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1 ROWSPAN=2>Model</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1 ROWSPAN=2>Nom.<BR>Tons</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=2>ARI<BR>Cooling Performance</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=2>Heating Performance</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1 ROWSPAN=2>Approx.<BR>OperWt(lbs)</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=3 ROWSPAN=1>Dimensions (in)</TH>');
   htp.p('</TR>');
   htp.p('<TR>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>Btuh</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>EER</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>Btuh</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>COP</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>Width</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>Height</TH>');
   htp.p('    <TH ALIGN=CENTER COLSPAN=1>Length</TH>');
   htp.p('</TR>');

   END ltcomm_ws_hp_header;
/*======================================================*/
   PROCEDURE ltcomm_dual_fuel_header IS

   BEGIN

--| For the 48HX unit, ltcomm_dual_fuel_heat_pump

   htp.p('<TR>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=4>Model</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=4>Nom.<BR>Tons</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=3 >ARI<BR>Cooling Performance</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=4>Nom.<BR>CFM</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=3>Heating<BR>Input</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=3>Heating<BR>Perf.</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=6 ROWSPAN=1>Electrical Data</TH>'); 
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=4>Approx.<BR>OperWt(lbs)</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=4>Sound<BR>(bels)</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=3 ROWSPAN=3>Dimensions (in)</TH>');
   htp.p('</TR>');
   htp.p('<TR>');
   htp.p('       	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=1>V-PH-HZ</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=1>V-PH-HZ</TH>');
   htp.p('  	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=1>V-PH-HZ</TH>');
   htp.p('</TR>');
   htp.p('<TR>');
   htp.p('       	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=1>208/230-1-60</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=1>208/230-3-60</TH>');
   htp.p('  	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=1>460-3-60</TH>');
   htp.p('</TR>');
   htp.p('<TR>'); 
   htp.p('    	<TH ALIGN=CENTER COLSPAN=1>Btuh</TH>');
   htp.p('    	<TH ALIGN=CENTER COLSPAN=1>SEER</TH>');
   htp.p('    	<TH ALIGN=CENTER COLSPAN=1>MBH</TH>');
   htp.p('    	<TH ALIGN=CENTER COLSPAN=1>HSPF</TH>');
   htp.p('        <TH ALIGN=CENTER COLSPAN=1 ROWSPAN=1>MCA</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=1>MOCP</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=1>MCA</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=1>MOCP</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=1>MCA</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=1>MOCP</TH>');
   htp.p('    	<TH ALIGN=CENTER COLSPAN=1>Width</TH>');
   htp.p('    	<TH ALIGN=CENTER COLSPAN=1>Height</TH>');
   htp.p('    	<TH ALIGN=CENTER COLSPAN=1>Depth</TH>');
   htp.p('</TR>');

   END ltcomm_dual_fuel_header;
/*======================================================*/
   PROCEDURE ltcomm_pack_hp_stdeff_header IS

   BEGIN

--| For the 50HS and 50ZH units, ltcomm_pack_heatpump

   htp.p('<TR>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=4>Model</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=4>Nom.<BR>Tons</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=3 >ARI<BR>Cooling Performance</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=4>Nom.<BR>CFM</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=3>Heating<BR>Performance</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=6 ROWSPAN=1>Electrical Data</TH>'); 
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=4>Approx.<BR>OperWt(lbs)</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=4>Sound<BR>(bels)</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=3 ROWSPAN=3>Dimensions (in)</TH>');
   htp.p('</TR>');
   htp.p('<TR>');
   htp.p('       	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=1>V-PH-HZ</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=1>V-PH-HZ</TH>');
   htp.p('  	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=1>V-PH-HZ</TH>');
   htp.p('</TR>');
   htp.p('<TR>');
   htp.p('       	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=1>208/230-1-60</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=1>208/230-3-60</TH>');
   htp.p('  	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=1>460-3-60</TH>');
   htp.p('</TR>');
   htp.p('<TR>'); 
   htp.p('    	<TH ALIGN=CENTER COLSPAN=1>BTUH</TH>');
   htp.p('    	<TH ALIGN=CENTER COLSPAN=1>SEER</TH>');
   htp.p('    	<TH ALIGN=CENTER COLSPAN=1>BTUH</TH>');
   htp.p('    	<TH ALIGN=CENTER COLSPAN=1>HSPF</TH>');
   htp.p('        <TH ALIGN=CENTER COLSPAN=1 ROWSPAN=1>MCA</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=1>MOCP</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=1>MCA</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=1>MOCP</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=1>MCA</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=1>MOCP</TH>');
   htp.p('    	<TH ALIGN=CENTER COLSPAN=1>Width</TH>');
   htp.p('    	<TH ALIGN=CENTER COLSPAN=1>Height</TH>');
   htp.p('    	<TH ALIGN=CENTER COLSPAN=1>Depth</TH>');
   htp.p('</TR>');


   END ltcomm_pack_hp_stdeff_header;
/*======================================================*/
   PROCEDURE ltcomm_pack_hp_hieff_header IS

   BEGIN

--| This is for the 50HX unit, ltcomm_pack_heatpump

   htp.p('<TR>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=4>Model</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=4>Nom.<BR>Tons</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=3 >ARI<BR>Cooling <BR>Performance</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=3 >Heating<BR> Performance</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=4>Nom.<BR>CFM</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=1>Electrical Data</TH>'); 
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=4>Approx.<BR>OperWt(lbs)</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=4>Sound<BR>(bels)</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=3 ROWSPAN=3>Dimensions (in)</TH>');
   htp.p('</TR>');
   htp.p('<TR>');
   htp.p('  	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=1>V-PH-HZ</TH>');
   htp.p('</TR>');
   htp.p('<TR>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=2 ROWSPAN=1>208/230-1-60</TH>');
   htp.p('</TR>');
   htp.p('<TR>'); 
   htp.p('    	<TH ALIGN=CENTER COLSPAN=1>BTUH</TH>');
   htp.p('    	<TH ALIGN=CENTER COLSPAN=1>SEER</TH>');
   htp.p('    	<TH ALIGN=CENTER COLSPAN=1>BTUH</TH>');
   htp.p('    	<TH ALIGN=CENTER COLSPAN=1>HSPF</TH>');
   htp.p('      <TH ALIGN=CENTER COLSPAN=1 ROWSPAN=1>MCA</TH>');
   htp.p('	<TH ALIGN=CENTER COLSPAN=1 ROWSPAN=1>MOCP</TH>');
   htp.p('    	<TH ALIGN=CENTER COLSPAN=1>Width</TH>');
   htp.p('    	<TH ALIGN=CENTER COLSPAN=1>Height</TH>');
   htp.p('    	<TH ALIGN=CENTER COLSPAN=1>Depth</TH>');
   htp.p('</TR>');

   END ltcomm_pack_hp_hieff_header;
/*======================================================*/
-- RESDOCSLTC.LT_COMM_GAS_TEXT;
/*======================================================*/
-- RESDOCSLTC.LT_COMM_ELEC_TEXT;
/*======================================================*/
-- RESDOCSLTC.LT_COMM_HP_TEXT;
/*======================================================*/
END resdocsltc;
/
show errors;
/
