/*
 * What is this file?
 * This is an example program that demonstrates the use of the Netscape
 * Enterprise Server Agents API
 * The intention is to illustrate how a server plugin developer can use the
 * API to write custom agent applications. Major features of the API are
 * illustrated with simple examples.
 * 
 * The example code here uses the Netscape WAI (Web Application Interface)
 * to implement a server plugin.
 * This example is menu driven and is invoked from a client 
 * (Netscape Navigator).
 * The URL to access (once the WAI plugin and the rest are installed) is
 * /<server-name>/iiop/AgentWAI
 * This will display a HTML based interface from which you can select various
 * options to test the API
 *
 * WARNING: This example plugin is very powerful. It is not subject to any
 * kind of access control. It can access anything in the server without
 * any control because it is run as part of the server process.
 * Please ensure that access to this example plugin is restricted through ACLs.
 * DO NOT EXPOSE THIS EXAMPLE TO ALL CLIENTS. IT IS MEANT TO BE AN EXAMPLE
 * FOR PLUGIN DEVELOPERS ONLY. 
 *
 * ************** How to enable this WAI plugin *******************
 *
 * 1. First, using the Netscape Admin server, enable WAI
   2. Ensure the osagent is running
 * 3. Next, add the following lines to your obj.conf. Put these lines
      after all the other Init directives, just before NameTrans
      Init funcs="agentwai_init" fn="load-modules" shlib="d:/netscape/suitespot/plugins/agents/examples/agentswai.dll"
Init LateInit="yes" fn="agentwai_init"

      Here, the name of the dll (shared lib, .so on UNIX) is agentswai and it
      is built by the makefile supplied. The initialization function is
      agentwai_init. This function is seen later in this file. If you change
      any of these, modify the entries in obj.conf appropriately. The path
	 to the agentswai.dll is what is require here. You can place the .dll
	  anywhere you like but ensure that the path in the Init directive reflects
	  that correctly.

      After this, restart your server. Now to access this example plugin
	  enter the URL under any browser
      http://servername/iiop/AgentWAI
      
 */
// DO NOT CHANGE THE ORDER OF THESE INCLUDE FILES
#include <agents/agent_c_api.h>
#include <ONESrvPI.hpp>
#include <reqstrm.hpp>
#include <agents/message.h>
#include <base/util.h>

#ifdef WIN32
#include <windows.h>
#else
#include <unistd.h>
extern "C" {
int gethostname(char *name, int namelen);
}
#endif



/*
 * These are various default constants used in the examples. Change them
 * as you need. In particular, you would want to change company name and
 * email addresses that are used in these examples
 * PLEASE SET THESE PATHS AS APPROPRIATE TO YOUR SERVER
 */
const char* DOCUMENT_URL = "/index.html";
const char* DIRECTORY_URL = "/"; // root of the server

/* THESE MUST BE MODIFIED TO REFLECT YOUR SERVER CONFIGURATION */
#ifdef WIN32
const char* DOCUMENT_PATH = "D:/Netscape/SuiteSpot/docs/index.html";
const char* DIRECTORY_PATH = "D:/Netscape/SuiteSpot/docs/";
#else
const char* DOCUMENT_PATH = "/Netscape/SuiteSpot/docs/index.html";
const char* DIRECTORY_PATH = "/Netscape/SuiteSpot/docs/";
#endif

const char *instanceName="WASP";

// Max number of atrribute-values in a query from client
const short MAX_AV_PAIR_SIZE = 100;

const char* REPLY_TO = "admin@ACME.COM"; // some dummy address
const char* MAIL_MESSAGE = 
			" THIS IS A TEST MAIL MESSAGE FROM THE AGENT API TEST"; 

const char* DEFAULT_USER = "user";

const char* DEFAULT_NEWSGROUP = "mcom.test";

const char* DEFAULT_NEWSSUBJECT = "Test News Post from Netscape Agent API test";

const char* DEFAULT_NEWSMESSAGE = 
		"THIS IS A TEST NEWS MESSAGE FROM THE AGENT API TEST";

const char* DEFAULT_ORGANIZATION = "ACME, Inc.";
const char* URL_TO_GET = 0;

/*
 * The  POST action will cause the execution of this application itself. But,
 * instead of executing other tests, it runs the test case 0 below. 
 * All it does is to create a file  and fill it with the
 * POST data and some other information. The name of the file is specified
 * in the POST message

 * You can POST to any URL you like. This can execute a CGI program and pass
 * data to it. It is limited only by your imagination!
 * Replace <servername> with the correct name of your server
 */
char URL_TO_POST[256] = "http://";
char URI[256];  // this will be set when this plugin is invoked
char SERVER_NAME[256];  // this will be set when this plugin is invoked

// This is the default message that is sent in the POST
// Change this based on your needs
const char* POST_MESSAGE = 
	"agentname=ExamplePostAgent&whichtest=0&filename=POSTMYDATA.DOC";

// The POST action writes to this file. Change this path as you like.
const char* DEFAULT_FILE="/tmp/POSTDATA.DOC";

// These are the functions used for testing

const char* CreateMailAgentTest(const char* user,  // for whom agent is created
					const char* agentName, // what you want to call it
					const char* mailAddress); // when triggered send mail to

const char* CreateNNTPAgentTest(const char* user, 
								const char* agentName,
								const char* mailAddress);

const char* CreatePeriodicTimerTest(
								const char* user, 
								const char* agentName,
								const char* mailAddress);

const char* CreateSearchAgentTest(
								const char* user, 
								const char* agentName,
								const char* mailAddress,
								const char* collection,
								const char* pattern);

const char* CreateSearchAgentTest(const char* user, 
								const char* agentName,
								const char* mailAddress);

const char* AgentListingTest(const char* user, oreqstream& ostr); 

const char* CreateHTTPGetAgentTest(const char* user, 
								const char* agentName,
								const char* mailAddress,
								const char* url);

const char* CreateWeeklyAlarmTest(const char* user, 
								const char* agentName,
								const char* mailAddress);

const char* CreateAdvancedAgentTest(const char* user,
                                const char* agentName,
                                const char* mailAddress,
								const char* newsgroup,
								const char* getThisUrl,
								const char* postToUrl,
								const char* postMessage);

const char* CreateDirectoryAgentTest(const char* user, 
					const char* agentName, // what you want to call it
					const char* mailAddress); // when triggered send mail to

void 
AgentDetailsTest(const char* whichagent, oreqstream& ostr);

//
// Declare a WAI class deriving from Netscape base class
// This is the class used for testing agents API
//
class WAIExample: public WAIWebApplicationService
{
	public:
		WAIExample(const char *host, const char *object_name = 0);
		~WAIExample();
		long Run(WAIServerRequest_ptr session);

		// Parse: Scan form data and build a attribute-value table
		// The attribute-value table is maintained within this class
		int Parse(WAIServerRequest_ptr session, oreqstream& stream);

		// Find: Look for a name value pair in the query
		const char* Find(const char* name) const;

		// This is the driver function
		void TestAgentsAPI(oreqstream& str);
		// Overridden from base class
		char *getServiceInfo();

	private:
		char **_names; // the names in name-value pairs 
		char **_values;// the values in name-values pairs
		int  _avIndex; // the next available slot 
		char *_avPairs; // the name-value pairs as a string 
};

// Implementation of all the functions follows.

WAIExample::WAIExample(const char *host, const char *object_name):
	WAIWebApplicationService(object_name), 
	_names(0), 
	_values(0), 
	_avIndex(0),
	_avPairs(0)
{
	RegisterService(host);
}

WAIExample::~WAIExample()
{
	if (_avPairs)
		delete _avPairs;

	delete [] _values;
	delete [] _names;
}


/*
 * This function generates the menu in HTML. 
 */

void OutputHTMLPage(oreqstream& stream)
{
stream << "<HTML>";
stream << "<BODY>";
stream << "<FORM METHOD=POST>";

stream << "<B>Please select one of the following choices...</B><BR><BR>";

stream << "<INPUT type=\"radio\" name=\"whichtest\" value=\"1\"> Test Document Mailer Agent <BR> <BR> </INPUT>";

stream << "<INPUT type=\"radio\" name=\"whichtest\" value=\"11\"> Test Directory Agent <BR> <BR> </INPUT>";

stream << "<INPUT type=\"radio\" name=\"whichtest\" value=\"2\"> Test Document Agent with newsgroup post <BR> <BR> </INPUT>";

stream << "<INPUT type=\"radio\" name=\"whichtest\" value=\"3\"> Test Periodic Timer Agent with Mail <BR><BR>  </INPUT>";

stream << "<INPUT type=\"radio\" name=\"whichtest\" value=\"4\"> Test Search Agent with Mail  <BR> </INPUT>";

stream << "   Collection: <INPUT TYPE=\"text\"  NAME=\"collectionname\" VALUE=\"\" SIZE=15> ";

stream << "  Search for: <INPUT TYPE=\"text\"  NAME=\"pattern\" VALUE=\"\" SIZE=15> <BR><BR>";

stream << "<INPUT type=\"radio\" name=\"whichtest\" value=\"5\"> Test Listing User Agents <BR><BR>  </INPUT>";

stream << "<INPUT type=\"radio\" name=\"whichtest\" value=\"10\"> Get details of specified agent: </INPUT>";
stream << "   Enter agent Id: <INPUT TYPE=\"text\"  NAME=\"whichagent\" VALUE=\"\" SIZE=20><BR><BR> ";

stream << "<INPUT type=\"radio\" name=\"whichtest\" value=\"6\"> Test HTTP GET Agent:  </INPUT>";
stream << "   URL to GET from: <INPUT TYPE=\"text\"  NAME=\"urltoget\" VALUE=\"\" SIZE=25> <BR><BR>";

stream << "<INPUT type=\"radio\" name=\"whichtest\" value=\"7\"> Test Weekly Alarm  with Mail <BR><BR>  </INPUT>";

stream << "<INPUT type=\"radio\" name=\"whichtest\" value=\"8\"> Delete agent test:  </INPUT>";
stream << "   Enter agent Id: <INPUT TYPE=\"text\"  NAME=\"agentid\" VALUE=\"\" SIZE=20><BR><BR> ";

stream << "<INPUT type=\"radio\" name=\"whichtest\" value=\"9\"> Create advanced agent test: </INPUT>";
stream << "   URL to GET from: <INPUT TYPE=\"text\"  NAME=\"getfromurl\" VALUE=\"\" SIZE=25> <BR>";
stream << " POST to URL: <INPUT TYPE=\"text\"  NAME=\"urltopost\" VALUE=\" "
	<< URL_TO_POST <<"\"" << " SIZE=40> <BR>";
stream << " POST Message: <INPUT TYPE=\"text\"  NAME=\"postmessage\" VALUE=\"\" SIZE=30> <BR> <BR>";

stream << "<INPUT type=\"submit\" name=\"Submit\" value=\"Run Selected Test\"> </INPUT> <HR>";


stream << " <BR><B>These are common to all tests. If set (recommended), these values will be used instead of the built-in defaults.</B><BR>";
stream << "User name: <INPUT TYPE=\"text\"  NAME=\"username\" VALUE=\""
	<< DEFAULT_USER << "\" SIZE=25> <BR>";

stream << "Agent name: <INPUT TYPE=\"text\"  NAME=\"agentname\" VALUE=\"\" SIZE=25> <BR>";

stream << "Send mail to: <INPUT TYPE=\"text\"  NAME=\"mailaddress\" VALUE=\"\" SIZE=25> <BR>";
stream << "</FORM>";
stream << "</BODY>";
stream << "</HTML>";

}


long
WAIExample::Run(WAIServerRequest_ptr session)
{

	char *var = 0;
	oreqstream outstr(*session);
	Parse(session, outstr); // Take care of name-value pairs in query

	session->StartResponse();
	WAIServerContext_ptr context = session->getContext();
	outstr 
		<< "<P><FONT SIZE=+2>Demonstrate" 
		<< " Netscape Enterprise Server Agents API.</FONT></P>";

   if ((var = context->getHost()) && *var){
		strcpy(SERVER_NAME, var);
		strcat(URL_TO_POST,  SERVER_NAME);
       StringDelete(var);
   }

    if (session->getRequestInfo("URI", var) == WAISPISuccess){
		strcpy(URI, var);
		strcat(URL_TO_POST,  URI);
        StringDelete(var);
    }

	if (_avIndex == 0) // Means there wasn't a query. Output default page
		OutputHTMLPage(outstr);

	else TestAgentsAPI(outstr);

	session->setResponseContentLength(outstr.rdbuf()->getTotalPutCount());
    return 0;
}

/*
 * Helper function
 * Make up a from address for a user. Change this as you need
 * outBuf should point to enough memory to hold the address
 */

void BuildFromAddress(char* outBuf, const char* userName)
{
	sprintf(outBuf, "%s@netscape.COM", userName);

}


/*
 * CreateDocumentEvent()
 * Illustrates the creation of an event on a document
 * docUrl is the URL of the document
 * docPath is the absolute path to the document
 *
 */
ns_agentEvent_t CreateDocumentEvent(int eventId, const char *docUrl, 
									const char *docPath)
{
    ns_agentEvent_t event = ns_AgentEventCreate();
    ns_AgentEventSetDocumentContext(event, eventId, docUrl, docPath);
    return(event);
}

/*
 * CreateSendMailAction()
 *
 *  This routine illustrates creation of mailing action.
 */
ns_agentAction_t CreateSendMailAction(
			const char *fromUser, 
			const char *recipient, 
			const char *mailMesg)
{
	char fromAddress[256];
	BuildFromAddress(fromAddress, fromUser);
	
	ns_agentAction_t action	= ns_AgentActionMailerCreate(
							fromUser, 
							fromAddress,
							recipient,
							REPLY_TO,
							mailMesg);

    return(action);
}

void
OutputResult(oreqstream& ostr, const char* id, const char* name)
{
	if (id)
		ostr << "Created agent with id:<B> " << id << "</B> and name:<B> " <<
			name << "</B><BR>";
	else
		ostr << "Failed to create agent due to some error... <BR>";
}

// Filter and restore characters modified by the POST operation

void UnescapeString(char* ptr)
{
   char* p = ptr;
   char* c = ptr;
   while (*p != '\0') {
      if (*p == '+')
         *c++ = ' ';
      else if (*p == '%') {
         char tmp = (*++p >= 'A') ? 10+((*p & 0xDF)-'A') : (*p - '0');
         tmp <<= 4;
         tmp += (*++p >= 'A') ? 10+((*p & 0xDF)-'A') : (*p - '0');
         // do a little check, in case there's an encoded '+' sign.
         *c++ = (tmp == '+') ? ' ' : tmp;
         }
      else
         *c++ = *p;
        
      p++;
      }

   *c = '\0';

	--c;
	// Now remove trailing spaces
	while (*c == ' ')
		--c;
	*(c+1) = 0;

}


// Our main routine to process arguments and do the rest
// Everything begins here
void
WAIExample::TestAgentsAPI(oreqstream& ostr)
{
	// Find the values of different attributes if specified in the query
	const char* option = Find("whichtest");
	const char* id = 0;
	int what = 0;
	const char* MAIL_ADDRESS = Find("mailaddress");
	const char* username = Find("username");
	const char* agentname = Find("agentname");
	const char* agentid = Find("agentid");
	const char* collection = Find("collectionname");
	const char* pattern = Find("pattern");
	const char* urltoget = Find("urltoget");
	const char* urltopost = Find("urltopost");
	const char* postmessage = Find("postmessage");
	const char* whichagent = Find("whichagent");

	char buf[256];
	char buf1[256];
	char header[1024];
	char post_msg[1024];
	FILE* fp;
	const char *file;
	const char *ptr;

	if (username != 0)
		DEFAULT_USER = username;
	else DEFAULT_USER = "user";

	if (!MAIL_ADDRESS)
		MAIL_ADDRESS = DEFAULT_USER;

	if (!pattern)
		pattern = "(*)"; // default: search for everything

	if (!collection)
		collection = "WebPub";

	if (!urltoget)
		URL_TO_GET = "http://www.netscape.com";
	else URL_TO_GET = urltoget;


	if (!urltopost) {
		strcat(URL_TO_POST, SERVER_NAME);
		strcat(URL_TO_POST, URI);
		urltopost = URL_TO_POST;
	}

	if (!postmessage)
		postmessage = POST_MESSAGE;


	if (option)
		what = atoi(option); // what has the user selected to do?


	switch (what) {
		case 0: // Echo arguments
				// This is entered when the POST action is executed
				// See case 9 below
				file = Find("filename");
				if (file == 0)
					file = DEFAULT_FILE;
				fp = fopen(file, "w");
				if (!fp)
					break; // failed to open file
				fprintf(fp, "The post from an agent action succeeded\n");

				ptr = Find("agentname");
				if (ptr)
					fprintf(fp, "Find(agentname)=%s\n", ptr);

				fprintf(fp, "Filename=%s\n", file);
				fclose(fp);
				break;

		case 1: // Mail agent
				if (!agentname)
					agentname = "WAI_Mail_Agent";

				id = CreateMailAgentTest(DEFAULT_USER, 
							agentname, MAIL_ADDRESS) ;
				OutputResult(ostr, id, agentname);
				break;

		case 2: // NNTP Agent
				if (!agentname)
					agentname = "WAI_NNTP_Agent";

				id = CreateNNTPAgentTest(DEFAULT_USER,
							agentname,
							DEFAULT_NEWSGROUP);
				OutputResult(ostr, id, agentname);
				break;

		case 3: // Periodic Timer
				if (!agentname)
					agentname = "WAI_Periodic_Timer";

				id = CreatePeriodicTimerTest(DEFAULT_USER, 
											agentname,
											MAIL_ADDRESS);	
				OutputResult(ostr, id, agentname);
				break;

		case 4: // Search Agent
				if (!agentname)
					agentname = "WAI_Search_Agent";

				id = CreateSearchAgentTest(DEFAULT_USER,
										agentname,
										MAIL_ADDRESS,
										collection,
										pattern);
				OutputResult(ostr, id, agentname);
				break;

		case 5: // List Agents
				AgentListingTest(DEFAULT_USER, ostr);
				break;


		case 6: // HTTP GET agent
				if (!agentname)
					agentname = "WAI_HTTPGet_Agent";

				strcpy(buf, URL_TO_GET);
				util_uri_unescape(buf);

				id = CreateHTTPGetAgentTest(DEFAULT_USER,
										agentname,
										MAIL_ADDRESS,
										buf);
				OutputResult(ostr, id, agentname);
				break;

		case 7: // Weekly Alarm
				if (!agentname)
					agentname = "WAI_Weekly_Timer_Agent";

				id = CreateWeeklyAlarmTest(DEFAULT_USER, 
											agentname,
											MAIL_ADDRESS);	
				OutputResult(ostr, id, agentname);
				break;

		case 8: // delete agent test
				if (agentid) {
					strcpy(buf, agentid);
					// strip URL encoding characters
					UnescapeString(buf);
					ns_agentId_t id =  ns_AgentIdFromString(buf);
					if (id == 0) {
						ostr << "Error: Agent Id is invalid. <BR>";
						break;
					}

					ns_status_t st = ns_AgentDelete(id);
					if (st == NS_AGENT_SUCCESS)
						ostr << "Agent " << buf << " deleted. <BR>";
					else ostr << "Failed to delete agent " << buf 
						<< " Reason: " << ns_AgentStatusToString(st) << " <BR>";
				}
				else 
					ostr << "Error: Agent Id to delete not specified. <BR>";

				break;

		case 9:
				{
				if (!agentname)
					agentname = "WAI_Advanced_Agent";

				const char* getfromurl = Find("getfromurl");
				if (!getfromurl)
					getfromurl = URL_TO_GET;

				strcpy(buf, getfromurl);
				util_uri_unescape(buf);

				if (urltopost) {
					strcpy(buf1, urltopost);
					util_uri_unescape(buf1);
				}

				if (urltopost) {
					// Build the post message
					sprintf(header, "Content-Length:%d\n\
					Content-Type: application/x-www-form-urlencoded; charset=US-ASCII\n\
					Content-Transfer-Encoding: 7bit", strlen(postmessage));

					/* build post message  */
					sprintf(post_msg, "%s\n\n%s\n", header, postmessage);

				}

				id = CreateAdvancedAgentTest(DEFAULT_USER,
						 agentname,
						 MAIL_ADDRESS,
						 DEFAULT_NEWSGROUP,
						 buf, // GET url
						 buf1, // POST url
						 post_msg);
				OutputResult(ostr, id, agentname);
				}
				break;

		case 10: // Get details of an agent
				AgentDetailsTest(whichagent, ostr);
				break;

        case 11: // Directory agent
                if (!agentname)
                    agentname = "WAI_Directory_Agent";

                id = CreateDirectoryAgentTest(DEFAULT_USER,
                            agentname, MAIL_ADDRESS) ;
                OutputResult(ostr, id, agentname);
                break;

		default: ostr << "Unknown test selected, Try again.<BR>";
	}

	
}




char *
WAIExample::getServiceInfo()
{
	return StringDup("Agent API Example Ver 1.0");
}


WAIExample *anObject;



// BUILD A DLL
// This is called by the server initialization functions when the
// shared library is loaded
extern "C" {
#ifdef WIN32
	__declspec(dllexport) 
#endif
int agentwai_init(pblock *pb, Session *sn, Request *rq);
}

//
// This function allows this thing to be loaded from a dll.
int
agentwai_init(pblock *pb, Session *sn, Request *rq)
{
	char host[256];
	gethostname(host, sizeof(host));

	anObject = new WAIExample(host, "AgentWAI");

	return 0;
}

// Parse the incoming name-value pairs (the HTTP POST) and build a table
// You can look for an entry in the table with the Find function
int
WAIExample::Parse(WAIServerRequest_ptr session, oreqstream& stream)
{
	if (_avPairs != 0) {
		_avIndex = 0;
		delete _avPairs;
	}

	ireqstream ireq(*session);
	_avPairs = new char [4096]; // Queries are usually not that big.
	ireq.rdbuf()->setContentLengthLimit(); // read only available bytes
	ireq.read(_avPairs, 4096);
	int length = ireq.gcount();
	_avPairs[length] = 0;

	char* avPairs = _avPairs; // don't change the object
	if (_names == 0)  _names = new char*[MAX_AV_PAIR_SIZE];
	if (_values == 0) _values = new char*[MAX_AV_PAIR_SIZE];

	char* 	name = avPairs;
	char  	delim = '=';
	char* 	value = 0;

	// Scan the query. Delimiters are & and =
	while ((avPairs = strchr(avPairs, delim)) != 0) {
	  *avPairs = 0;
      if (delim == '=') {
         delim = '&';
		 *avPairs++ = 0; // remove =
         value = avPairs;
         if (value != 0 && *value != 0) {
			_names[_avIndex] = name;
			_values[_avIndex++] = value;
		 }
      }
      else { // found a '&'
         delim = '=';
		 *avPairs++ = 0; // remove &
		 name = avPairs; // the next one
      }
	}
	_names[_avIndex] = 0; // Mark end of the table
	_values[_avIndex] = 0;

	return _avIndex; // # of name-value pairs parsed

}

// Look for a value of a given name
// Return a pointer to it or 0
const char*
WAIExample::Find(const char* name) const
{
	if (_avIndex == 0)
		return 0; // no name-value pairs here


	for(int i=0; i < _avIndex; i++)
		if (strcmp(_names[i], name)==0)
			if (*_values[i] != 0)
				 return _values[i]; // found it
			else return 0; // empty value

	return 0;
}

/*
 * Given the arguments, just create an agent object and returns it
 * It defines some arbitrary limits on trigger limit and expiry date
 */
ns_agent_t CreateAgentObject(const char* owner, const char* ownerAddr,
						ns_agentEvent_t triggerEvent,
						ns_agentActionList_t actions,
						const char* creationNotificationAddr,
						const char* agentName) // user defined name
{
	size_t triggerLimit = 20; // let the agent trigger 20 times
	// time(0) gets the current time in seconds
	time_t expiryDate = time(0) + (7*86400); //  a week from now

	ns_agent_t agent = ns_AgentCreateAgentObject(owner, 
								ownerAddr, 
								expiryDate, 
								triggerLimit,
								ownerAddr, 
								triggerEvent, actions, 
								0, // userdata is not used
								0, // userdata size is zero
								agentName);
	return agent;
}


/*
 * Create a simple agent to send mail.
 * If successful, the agent id string is returned.
 * DO NOT DELETE THE RETURNED STRING
 *
 * The steps outlined in this function are followed in all the other
 * functions that follow. All of them create an event, an action, and finally
 * an agent object.
 */

const char* CreateMailAgentTest(const char* user,  // for whom agent is created
					const char* agentName, // what you want to call it
					const char* mailAddress) // when triggered send mail to
											// this address
{
	// Create the required event first
	// Assume that the URL is /index.html and its associated absolute
	// path is /Netscape/Suitespot/docs/index.html
	// These are globally defined in DOCUMENT_URL and DOCUMENT_PATH
	// The event number is any valid event supported (see message.h)
	// Let's use NS_MODIFY_MSG

	ns_agentEvent_t event =
		CreateDocumentEvent(NS_GET_PROPERTIES_MSG, DOCUMENT_URL, DOCUMENT_PATH);

	if (event == 0) // failed to create event
		return 0;

	// Next create an action list for our action(s)
    ns_agentActionList_t actionList = ns_AgentActionListCreate(1);


	// Next create an action for sending mail
	ns_agentAction_t action = 
			CreateSendMailAction(user, mailAddress, // the recipient
							MAIL_MESSAGE);

	 /*
	 *  BEWARE : actionList object adopts the action object added to
	 *   it and deletes it when the actionList is deleted.
	 *  YOU SHOULD NOT DELETE IT HERE.
	 */
	ns_AgentActionListAdd(actionList, action);

	char userAddress[256];
	const char* myAgentIdString = 0;

	BuildFromAddress(userAddress, user);

	// Now we have all the information. Let's create an agent object
	ns_agent_t myAgent = CreateAgentObject(user, 
						userAddress,
                        event,
                        actionList,
                        userAddress,
                        agentName); // user defined name

	if (myAgent != 0) { // successfully created the agent object
		// Now submit it for registration and activation
		ns_status_t st;
		st = ns_AgentSubmit(myAgent);
		if (st == NS_AGENT_SUCCESS) {
			// Get the agent id and return it
			ns_agentId_t myAgentId = ns_AgentGetId(myAgent);
			if (myAgentId)
				myAgentIdString = ns_AgentIdToString(myAgentId);
		}

	}

	// Finally, don't forget to delete the agent object
	ns_AgentDeleteAgentObject(myAgent);

	return myAgentIdString;
}

// Create an agent to post to a newsgroup when activated

const char* CreateNNTPAgentTest(const char* user,  // for whom agent is created
					const char* agentName, // what you want to call it
					const char* newsGroup) // when triggered post message to
											// this newsgroup
{
	// Create the require eventd first
	// Assume that the URL is /index.html and its associated absolute
	// path is /Netscape/Suitespot/docs/index.html
	// These are globally defined in DOCUMENT_URL and DOCUMENT_PATH
	// The event number is any valid event supported
	// Let's use NS_GET_PROPERTIES_MSG

	ns_agentEvent_t event =
		CreateDocumentEvent(NS_GET_PROPERTIES_MSG, DOCUMENT_URL, DOCUMENT_PATH);

	if (event == 0) // failed to create event
		return 0;

	// Next create an action list for our action(s)
    ns_agentActionList_t actionList = ns_AgentActionListCreate(1);


	// Next create an action for posting to newsgroup
	char userAddress[256];
	const char* myAgentIdString = 0;

	BuildFromAddress(userAddress, DEFAULT_USER);

	ns_agentAction_t action = ns_AgentActionNNTPPostCreate(
                DEFAULT_USER,
                userAddress, 
                userAddress, // retAddr
                DEFAULT_NEWSGROUP, // newsGroup,
                DEFAULT_NEWSSUBJECT, //  newsSubject
                DEFAULT_NEWSSUBJECT, // newsMesg
                DEFAULT_ORGANIZATION);  


	 /*
	 *  BEWARE : actionList object adopts the action object added to
	 *   it and deletes it when the actionList is deleted.
	 *  YOU SHOULD NOT DELETE IT HERE.
	 */
	ns_AgentActionListAdd(actionList, action);


	// Now we have all the information. Let's create an agent object
	ns_agent_t myAgent = CreateAgentObject(user, 
						userAddress,
                        event,
                        actionList,
                        userAddress,
                        agentName); // user defined name

	if (myAgent != 0) { // successfully created the agent object
		// Now submit it for registration and activation
		ns_status_t st;
		st = ns_AgentSubmit(myAgent);
		if (st == NS_AGENT_SUCCESS) {
			// Get the agent id and return it
			ns_agentId_t myAgentId = ns_AgentGetId(myAgent);
			if (myAgentId)
				myAgentIdString = ns_AgentIdToString(myAgentId);
		}

	}

	// Finally, don't forget to delete the agent object
	ns_AgentDeleteAgentObject(myAgent);

	return myAgentIdString;
}

/*
 * This example creates an agent that triggers periodically 
	(every 30 minutes) and sends a mail message. 
 */

const char* CreatePeriodicTimerTest(const char* user,
                                const char* agentName,
                                const char* mailAddress)
{
	int day = 0, month = 0, year = 1997, hour = 0, minute = 0, second = 0;
	int period = 30; // every 30 minutes
	// We don't care about the days vector here
	short  daysVec[7];
	time_t now;
	struct tm* newtime;
	ns_agentEvent_t event;

    for (int i = 0; i < 7; i++)
        daysVec[i] = 0; // this is not a specific day alarm


	time( &now );                /* Get time as long integer. */
	event =  ns_AgentEventCreate(); // Create empty event
	ns_AgentEventSetTimerContext(event,
                 eTimerPeriodicMinutes,
                 now,
                 daysVec,
                 period);


    if (event == 0) // failed to create event
        return 0;

    // Next create an action list for our action(s)
    ns_agentActionList_t actionList = ns_AgentActionListCreate(1);


    // Next create an action for sending mail
    ns_agentAction_t action =
            CreateSendMailAction(user, mailAddress, // the recipient
                            MAIL_MESSAGE);

     /*
     *  BEWARE : actionList object adopts the action object added to
     *   it and deletes it when the actionList is deleted.
     *  YOU SHOULD NOT DELETE IT HERE.
     */
    ns_AgentActionListAdd(actionList, action);

    char userAddress[256];
    const char* myAgentIdString = 0;

    BuildFromAddress(userAddress, user);

    // Now we have all the information. Let's create an agent object
    ns_agent_t myAgent = CreateAgentObject(user,
                        userAddress,
                        event,
                        actionList,
                        userAddress,
                        agentName); // user defined name

    if (myAgent != 0) { // successfully created the agent object
        // Now submit it for registration and activation
        ns_status_t st;
        st = ns_AgentSubmit(myAgent);
        if (st == NS_AGENT_SUCCESS) {
            // Get the agent id and return it
            ns_agentId_t myAgentId = ns_AgentGetId(myAgent);
            if (myAgentId)
                myAgentIdString = ns_AgentIdToString(myAgentId);
        }

    }

    // Finally, don't forget to delete the agent object
    ns_AgentDeleteAgentObject(myAgent);

    return myAgentIdString;
}


// Create an agent to perform periodic searches of a collection
// The search is performed every 24 hours 

const char* CreateSearchAgentTest(const char* user,
									const char* agentName,
									const char* mailAddress,
									const char* collection,
									const char* pattern)
{

	// create a timer event first
    int day = 0, month = 0, year = 1997, hour = 0, minute = 0, second = 0;
    int period = 24; // every 24 hours
    // We don't care about the days vector here
    short  daysVec[7];
    time_t now;
    struct tm* newtime;
    ns_agentEvent_t event;

    for (int i = 0; i < 7; i++)
        daysVec[i] = 0;

    time( &now );                /* Get time as long integer. */
    event =  ns_AgentEventCreate(); // Create empty event
    ns_AgentEventSetTimerContext(event,
                 eTimerPeriodicHours,
                 now,
                 daysVec,
                 period);


    if (event == 0) // failed to create event
        return 0;


    // Next create an action list for our action(s)
    ns_agentActionList_t actionList = ns_AgentActionListCreate(1);

    char userAddress[256];
    const char* myAgentIdString = 0;

    BuildFromAddress(userAddress, user);


    // Next create an action for sending mail
    ns_agentAction_t action =
		ns_AgentActionSearchCreate(user,
                            userAddress,
                            mailAddress,
                            0,
                            MAIL_MESSAGE,
                            0, // no news group data
                            0,
                            0,
                            0,
                            collection,
                            eSearch_by_Mdate,
                            pattern);

     /*
     *  BEWARE : actionList object adopts the action object added to
     *   it and deletes it when the actionList is deleted.
     *  YOU SHOULD NOT DELETE IT HERE.
     */
    ns_AgentActionListAdd(actionList, action);


    // Now we have all the information. Let's create an agent object
    ns_agent_t myAgent = CreateAgentObject(user,
                        userAddress,
                        event,
                        actionList,
                        userAddress,
                        agentName); // user defined name

    if (myAgent != 0) { // successfully created the agent object
        // Now submit it for registration and activation
        ns_status_t st;
		 ns_AgentSetSubType(myAgent, eSearchSubType);
        st = ns_AgentSubmit(myAgent);
        if (st == NS_AGENT_SUCCESS) {
            // Get the agent id and return it
            ns_agentId_t myAgentId = ns_AgentGetId(myAgent);
            if (myAgentId)
                myAgentIdString = ns_AgentIdToString(myAgentId);
        }

    }

    // Finally, don't forget to delete the agent object
    ns_AgentDeleteAgentObject(myAgent);

    return myAgentIdString;
	return 0;

}



// List all agents owned by a user. Only the agent ids (not their names)
// are listed.
const char* AgentListingTest(const char* user, oreqstream& ostr)
{
	int countP = 0;
	ns_agentId_t *idList;

	ns_status_t st = ns_AgentGetAgentListByUser(user, &countP, &idList);

	if (countP > 0) {
		ostr << "User has created " << countP << " agents <BR>";

		while (--countP >= 0) {
			ostr << "Agent Id: <B>" << ns_AgentIdToString(idList[countP])
				<< "</B>";
			ns_agent_t agentP = 0;
			ns_status_t status =  ns_AgentLookup(idList[countP], &agentP);
			if (status == NS_AGENT_SUCCESS) {
				const char * name = ns_AgentGetDescription(agentP);
				ostr << "  Agent Name: <B>" << name <<  "</B><BR>";
			}
			if (agentP) ns_AgentDeleteAgentObject(agentP);
		}

	}
	else
		ostr << "User has not created any agents  <BR>";

	int count = -1;
	ns_AgentGetAgentCount(&count);
	if (count != -1) {
		ostr << "<BR> <B>Total Number of Agents on server "
		<< SERVER_NAME << ": " << 
			count << " </B> <BR>";
	}

	return 0;
}

/*
 * Create an agent that performs HTTP GET of a specified URL
 * getThisUrl - The URL to get when agent is triggered
 */
const char* CreateHTTPGetAgentTest(const char* user,
                                const char* agentName,
                                const char* mailAddress,
								const char* getThisUrl)
{
	// Create the required event first
	// Assume that the URL is /index.html and its associated absolute
	// path is /Netscape/Suitespot/docs/index.html
	// These are globally defined in DOCUMENT_URL and DOCUMENT_PATH
	// The event number is any valid event supported
	// Let's use NS_GET_PROPERTIES_MSG

	ns_agentEvent_t event =
		CreateDocumentEvent(NS_GET_PROPERTIES_MSG, DOCUMENT_URL, DOCUMENT_PATH);

	if (event == 0) // failed to create event
		return 0;

	// Next create an action list for our action(s)
    ns_agentActionList_t actionList = ns_AgentActionListCreate(1);


	// Next create an action for posting to newsgroup
	char userAddress[256];
	const char* myAgentIdString = 0;

	BuildFromAddress(userAddress, DEFAULT_USER);

	ns_agentAction_t action = ns_AgentActionGetAndMailCreate(
                            DEFAULT_USER,
                            userAddress,
                            mailAddress,
                            mailAddress,
                            MAIL_MESSAGE,
                            getThisUrl);


	 /*
	 *  BEWARE : actionList object adopts the action object added to
	 *   it and deletes it when the actionList is deleted.
	 *  YOU SHOULD NOT DELETE IT HERE.
	 */
	ns_AgentActionListAdd(actionList, action);


	// Now we have all the information. Let's create an agent object
	ns_agent_t myAgent = CreateAgentObject(user, 
						userAddress,
                        event,
                        actionList,
                        userAddress,
                        agentName); // user defined name

	if (myAgent != 0) { // successfully created the agent object
		// Now submit it for registration and activation
		ns_status_t st;
		st = ns_AgentSubmit(myAgent);
		if (st == NS_AGENT_SUCCESS) {
			// Get the agent id and return it
			ns_agentId_t myAgentId = ns_AgentGetId(myAgent);
			if (myAgentId)
				myAgentIdString = ns_AgentIdToString(myAgentId);
		}

	}

	// Finally, don't forget to delete the agent object
	ns_AgentDeleteAgentObject(myAgent);

	return myAgentIdString;
	return 0;
}

/*
 * Create a timer agent that triggers every Monday and Friday  
 */
const char* CreateWeeklyAlarmTest(const char* user,
                                const char* agentName,
                                const char* mailAddress)

{
    int day = 0, month = 0, year = 1997, hour = 0, minute = 0, second = 0;
    int period = 0; // not needed here

	// Let's set it for alarms on Monday and Friday at current time 
    short  daysVec[7];
    time_t now;
    struct tm* newtime;
    ns_agentEvent_t event;

    for (int i = 0; i < 7; i++)
        daysVec[i] = 0;
	daysVec[0] = 1; // Monday
	daysVec[4] = 1; // Friday


    time( &now );                /* Get time as long integer. */
    event =  ns_AgentEventCreate(); // Create empty event
    ns_AgentEventSetTimerContext(event,
                 eTimerSelective,
                 now,
                 daysVec,
                 period);


    if (event == 0) // failed to create event
        return 0;

    // Next create an action list for our action(s)
    ns_agentActionList_t actionList = ns_AgentActionListCreate(1);


    // Next create an action for sending mail
    ns_agentAction_t action =
            CreateSendMailAction(user, mailAddress, // the recipient
                            MAIL_MESSAGE);

     /*
     *  BEWARE : actionList object adopts the action object added to
     *   it and deletes it when the actionList is deleted.
     *  YOU SHOULD NOT DELETE IT HERE.
     */
    ns_AgentActionListAdd(actionList, action);

    char userAddress[256];
    const char* myAgentIdString = 0;

    BuildFromAddress(userAddress, user);

    // Now we have all the information. Let's create an agent object
    ns_agent_t myAgent = CreateAgentObject(user,
                        userAddress,
                        event,
                        actionList,
                        userAddress,
                        agentName); // user defined name

    if (myAgent != 0) { // successfully created the agent object
        // Now submit it for registration and activation
        ns_status_t st;
        st = ns_AgentSubmit(myAgent);
        if (st == NS_AGENT_SUCCESS) {
            // Get the agent id and return it
            ns_agentId_t myAgentId = ns_AgentGetId(myAgent);
            if (myAgentId)
                myAgentIdString = ns_AgentIdToString(myAgentId);
        }

    }

    // Finally, don't forget to delete the agent object
    ns_AgentDeleteAgentObject(myAgent);

    return myAgentIdString;
	return 0;
}

/*
 * This agent will do a combination of
   1. Mail
   2. Newsgroup Post
   3. POST to a Url
   4. Get from a Url
 * This is the most complex example
 */
const char* CreateAdvancedAgentTest(const char* user,
                                const char* agentName,
                                const char* mailAddress,
								const char* newsgroup,
								const char* getThisUrl,
								const char* postToUrl,
								const char* postMessage)
{
	// Create the required event first
	// Assume that the URL is /index.html and its associated absolute
	// path is /Netscape/Suitespot/docs/index.html
	// These are globally defined in DOCUMENT_URL and DOCUMENT_PATH
	// The event number is any valid event supported
	// Let's use NS_GET_PROPERTIES_MSG

	ns_agentEvent_t event =
		CreateDocumentEvent(NS_GET_PROPERTIES_MSG, DOCUMENT_URL, DOCUMENT_PATH);

	if (event == 0) // failed to create event
		return 0;

	// Next create an action list for our action(s)
    ns_agentActionList_t actionList = ns_AgentActionListCreate(1);


	// Next create an action for posting to newsgroup
	char userAddress[256];
	const char* myAgentIdString = 0;

	BuildFromAddress(userAddress, DEFAULT_USER);

	ns_agentAction_t action = ns_AgentCreateCompositeAction(
						user, 
                        userAddress,
                        mailAddress,
                        mailAddress,
                        MAIL_MESSAGE,
                        DEFAULT_NEWSGROUP,
                        DEFAULT_NEWSSUBJECT,
                        getThisUrl,
                        postToUrl,
                        postMessage,
                        0,
                        0,
                        eSearch_All,
                        DEFAULT_ORGANIZATION);


	 /*
	 *  BEWARE : actionList object adopts the action object added to
	 *   it and deletes it when the actionList is deleted.
	 *  YOU SHOULD NOT DELETE IT HERE.
	 */
	ns_AgentActionListAdd(actionList, action);


	// Now we have all the information. Let's create an agent object
	ns_agent_t myAgent = CreateAgentObject(user, 
						userAddress,
                        event,
                        actionList,
                        userAddress,
                        agentName); // user defined name

	if (myAgent != 0) { // successfully created the agent object
		// Now submit it for registration and activation
		ns_status_t st;
		st = ns_AgentSubmit(myAgent);
		if (st == NS_AGENT_SUCCESS) {
			// Get the agent id and return it
			ns_agentId_t myAgentId = ns_AgentGetId(myAgent);
			if (myAgentId)
				myAgentIdString = ns_AgentIdToString(myAgentId);
		}

	}

	// Finally, don't forget to delete the agent object
	ns_AgentDeleteAgentObject(myAgent);

	return myAgentIdString;
	return 0;
}

/*
 * Given an agent id, list all the details of the agent
 * whichagent - id of the agent (not its name)
 */
void 
AgentDetailsTest(const char* whichagent, oreqstream& ostr)
{
	char idbuf[256];

	if (whichagent == 0 || *whichagent==0) {
		ostr << "You have not specified an agent Id. Please try again<BR>";
		return;
	}
	strcpy(idbuf, whichagent);
	// Strip the URL encoding characters in place
	util_uri_unescape(idbuf);

	ns_agentId_t id = ns_AgentIdFromString(idbuf);
	if (id == 0) {
		ostr << "Error: Agent Id is invalid. <BR>";
		return;
	}

	ns_agent_t agentP;
	ns_status_t status =  ns_AgentLookup(id, &agentP);
	if (status == NS_AGENT_SUCCESS) {

		const char * name = ns_AgentGetDescription(agentP);
		ostr << "Agent id is: " << idbuf << "<BR>";
		ostr << "Agent name is: " << name << "<BR>";
		EAgentState state = ns_AgentGetState(agentP);
		switch(state) {
			case eEnabled:
				ostr << "Agent is Enabled <BR>";
				break;
			case eDisabled:
				ostr << "Agent is Disabled <BR>";
				break;
			case eDeleted:
				ostr << "Agent has been Deleted <BR>";
				break;
		}
		time_t expiry = ns_AgentGetExpiryDate(agentP);
		ostr << "Agent expires on: " << ctime(&expiry) << "<BR>";
		time_t modify = ns_AgentGetLastModifiedDate(agentP);
		ostr << "Agent was last modified on: " << ctime(&modify) << "<BR>";
		size_t trigger = ns_AgentGetTriggerCount(agentP);
		ostr << "Agent has been triggered  " << trigger << " times<BR>";
		size_t limit = ns_AgentGetTriggerLimit(agentP);
		ostr << "Agent's  trigger limit is: " << limit << "<BR>";

		if (trigger > 0) {
			time_t lasttrigger = ns_AgentGetLastTriggerDate(agentP);
			ostr << 
			"Agent was last triggered on: " << ctime(&lasttrigger) << "<BR>";
		}
		time_t created = ns_AgentGetCreationDate(agentP);
		ostr << "Agent was created on: " << ctime(&created) << "<BR>";

		/* DO NOT FREE THE RETURNED POINTER */
		const char* username = ns_AgentGetUserName(agentP);
		ostr << "Agent belongs to: " << username << "<BR>";
		ns_AgentDeleteAgentObject(agentP);


	}
	else
		ostr << "Failed to locate agent: " << idbuf << " on server <BR>";

}


/*
 * Create a simple directory agent to send mail.
 * If successful, the agent id string is returned.
 * DO NOT DELETE THE RETURNED STRING
 *
 * As far as the agent system is concerned, a directory agent is no different
 * from a document agent. What distinguishes the two is the absolute path name
 * and the URL. For a document agent, the event is created on a document. The
 * absolute path must specify a document. For a directory agent, the absolute
 * path must specify a directory and a trailing '/' is required on the 
 * directory name (see DIRECTORY_PATH and DIRECTORY_URL  above). 
 */

const char* CreateDirectoryAgentTest(const char* user, 
					const char* agentName, // what you want to call it
					const char* mailAddress) // when triggered send mail to
											 // this address
{
	// Create the required event first
	// Assume that the URL is /index.html and its associated absolute
	// path is /Netscape/Suitespot/docs/index.html
	// These are globally defined in DOCUMENT_URL and DOCUMENT_PATH
	// The event number is any valid event supported (see message.h)
	// Let's use NS_MODIFY_MSG

	ns_agentEvent_t event =
		CreateDocumentEvent(NS_GET_PROPERTIES_MSG, DIRECTORY_URL, 
										DIRECTORY_PATH);

	if (event == 0) // failed to create event
		return 0;

	// Next create an action list for our action(s)
    ns_agentActionList_t actionList = ns_AgentActionListCreate(1);


	// Next create an action for sending mail
	ns_agentAction_t action = 
			CreateSendMailAction(user, mailAddress, // the recipient
							MAIL_MESSAGE);

	 /*
	 *  BEWARE : actionList object adopts the action object added to
	 *   it and deletes it when the actionList is deleted.
	 *  YOU SHOULD NOT DELETE IT HERE.
	 */
	ns_AgentActionListAdd(actionList, action);

	char userAddress[256];
	const char* myAgentIdString = 0;

	BuildFromAddress(userAddress, user);

	// Now we have all the information. Let's create an agent object
	ns_agent_t myAgent = CreateAgentObject(user, 
						userAddress,
                        event,
                        actionList,
                        userAddress,
                        agentName); // user defined name

	if (myAgent != 0) { // successfully created the agent object
		// Now submit it for registration and activation
		ns_status_t st;
		ns_AgentSetSubType(myAgent, eDirSubType); // set agent's subtype
		st = ns_AgentSubmit(myAgent);
		if (st == NS_AGENT_SUCCESS) {
			// Get the agent id and return it
			ns_agentId_t myAgentId = ns_AgentGetId(myAgent);
			if (myAgentId)
				myAgentIdString = ns_AgentIdToString(myAgentId);
		}

	}

	// Finally, don't forget to delete the agent object
	ns_AgentDeleteAgentObject(myAgent);

	return myAgentIdString;
}
