#include "utils.h"

const int NET_CONNECT_ERROR = -2;
const int OUT_OF_MEMORY = -3;
const int NET_SOCKET_ERROR = -4;
const int HTTP_ERROR = -6;
const int NO_SUCH_HOST = -5;
const int NO_SERVER_NAME = -7;
const int SUCCESS = 1;
const int FAILURE = 0;

/* The user name here is "user" and password is "user1" */

const char* TRICKY_POST_MSG = "Content-Length:316\n\
Content-Type: application/x-www-form-urlencoded; charset=US-ASCII\n\
Content-Transfer-Encoding: 7bit\n\
Authorization: basic dXNlcjp1c2Vy\n\n\
NS-agent-page=create&NS-agent-action=yes&NS-agent-type=DOCUMENT&nsDocIsDir=0&actionType=e-mail&timerType=0&agentName=SPECIAL_AGENT&documentURL=/index.html&documentEventType=5&actionEmailAddr=user&userMesg=Agent created from another agent&newsGroup=&notifyEmailAddr=user&NOTHING=XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX";


int ConnectToServer(const char* server, unsigned int port )
{

	struct sockaddr_in sin;
    int           mySocket;
	int errorp;
	struct hostent* hp = 0;
	int rv = 0;

    memset((char *) &sin, 0, sizeof(sin));
	if(!isdigit(server[0])) { /* server specified by name */
		hp = gethostbyname(server);
		if (hp == 0) {
			perror("GetHostByName: ");
			rv = NO_SUCH_HOST;
			return rv;
		}

		sin.sin_addr = *((struct in_addr *)hp->h_addr_list[0]);
	}
	else { /* server specified by address */
		sin.sin_addr.s_addr = inet_addr(server);
	}


#ifdef WIN32
	mySocket = socket(AF_INET, SOCK_STREAM, 0);
#else
	mySocket = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP);
#endif
	if (mySocket == SOCKET_ERROR) {
		perror("Socket: : ");
		rv = NET_SOCKET_ERROR;
		return rv;
	}
    sin.sin_family = AF_INET;
    sin.sin_port = htons((unsigned short)port);

#ifdef WIN32
    if(connect(mySocket, (struct sockaddr *) &sin, sizeof(sin)) 
								== SOCKET_ERROR) {
#else
    if(connect(mySocket, (struct sockaddr *) &sin, sizeof(sin)) 
								== -1) {
#endif
		perror("Connect: : ");
		rv = NET_CONNECT_ERROR;
		return rv;
    }

	return mySocket;

}

int Write(int mySocket, const char* fromBuf, int n)
{
	int nbytes = 0;

    if(mySocket > 0){
		nbytes = send(mySocket, (const char*)fromBuf, n, 0);
		if (nbytes != n) {
            perror("Send: ");
		}
    }
	return n;;
}

int Read(int mySocket,  char* toBuf, int n)
{
	int nbytes = 0;

    if(mySocket > 0 && n > 0)
		nbytes = recv (mySocket,	toBuf, n, 0); 	

	return nbytes;
}


int DoHttpRequest(const char* server, 
		  unsigned int port, 
		  const char* msg, 
		  char** oheader,  /* out */
		  char** oresponse,  /* out */
		  int* status) /* out */
{
	char buf[256];
	int bufSize = 256;
	int mySocket = 0;
	int rv = 0;
	const int  packet_size = 1024;
	size_t     response_size = packet_size;
    int len = 0, n = 0;
	char *s;
	char *start_response_u;
	char *start_response_pc;
	size_t header_size;
    int       eoh = 0;
    int       status_set = 0;
    char      *response_body = NULL;
    char      *end = NULL;
	char stat_str[32];
	char* header = 0;
	char* response = 0;

	*oheader = 0;
	*oresponse = 0;

	mySocket = ConnectToServer(server, port);
#ifdef WIN32
	if (mySocket <= 0) {
#else
	if (mySocket < 0) {
#endif
		printf("Failed to connect to server\n");
		CLOSESOCKET(mySocket);
		return mySocket;
	}


	rv = Write(mySocket, msg, strlen(msg));
	if (rv <= 0) {
		CLOSESOCKET(mySocket);
		return rv;
	}
	

   response = malloc(response_size);
   if(response == 0) {
	   rv = OUT_OF_MEMORY;
		CLOSESOCKET(mySocket);
	   return rv;
   }
	

    while((n = Read(mySocket, response + len, packet_size)) > 0){
        len += n;
		if(response_size - len <  packet_size){
			/* not enough free space left - */
			/* allocate new buffer and copy response to it */
			response_size += 2 * packet_size;
			s = malloc(response_size);
			if(!s){
				free(response);
				rv = OUT_OF_MEMORY;
				CLOSESOCKET(mySocket);
				return rv;
			}
			memset(s, 0, response_size);
			memcpy(s, response, len);
			free(response);
			response = s;
		}
        if(!eoh)  {
            start_response_u = strstr(response, "\n\n");
            start_response_pc = strstr(response, "\r\n\r\n");
			if(start_response_u || start_response_pc) {
					if(start_response_pc)
						response_body = start_response_pc + 4;
					else if (start_response_u)
						response_body = start_response_u + 2;

				eoh = 1;
				header_size = (size_t)(response_body - response);
				len -= header_size;
				header = malloc(header_size + 1);
				if(!header){
					free(response); response = NULL;
					CLOSESOCKET(mySocket);
					rv = OUT_OF_MEMORY;
					return rv;
				}
				memset(header, 0, header_size + 1);
				memcpy(header, response, header_size);
				memcpy(response, response_body, len);
				memset(response + len, 0, response_size - len);
			}
		}
		if(!status_set && eoh && header) {
			const char *HTTP_str = "HTTP/";
			char *start = NULL;
			char stat_str[32];
			if((start = strstr(header, HTTP_str))) {
				start += strlen(HTTP_str);
				start = strchr(start, ' ');
						if (start)
							start++;
				else {
					rv = HTTP_ERROR;
					CLOSESOCKET(mySocket);
					return rv;
				}
				end = strchr(start, ' ');
				if(!end){
					rv = HTTP_ERROR;
					CLOSESOCKET(mySocket);
					return rv;
				}
				memset(stat_str, 0, 32);
				strncpy(stat_str, start, end - start);
				*status = atoi(stat_str);
				switch(*status){
					case 200:
						/* OK */
					break;
					case 201:
						/* Created (only for POST) */
						break;
					default:
						/* delete [] response; response = NULL; */
						CLOSESOCKET(mySocket);
					return rv;
				}
				status_set = 1;
			}
		}
		}
		if(!eoh || !status_set || n == -1) {
			rv = HTTP_ERROR;
		}

		*oresponse = response;
		*oheader = header;
		CLOSESOCKET(mySocket);
		return rv;
	
}

/* uuencode a src string into dst string - dst must be long enough! */
/* return the length of the uuencoded string */

size_t
NetUUEncode(const unsigned char *src, unsigned char *dst, const int srclen)
{
    int  i, r;
    unsigned char *p;
    if(!src || srclen <= 0)
    return 0;

    /* To uuencode, we snip 8 bits from 3 bytes and store them as
       6 bits in 4 bytes.   6*4 == 8*3 (get it?) and 6 bits per byte
       yields nice clean bytes

       It goes like this:
       AAAAAAAA BBBBBBBB CCCCCCCC
       turns into the standard set of uuencode ascii chars indexed by numbers:
       00AAAAAA 00AABBBB 00BBBBCC 00CCCCCC

       Snip-n-shift, snip-n-shift, etc....

       */

    for (p=dst,i=0; i < srclen; i += 3) {
        /* Do 3 bytes of src */
        register char b0, b1, b2;

        b0 = src[0];
        if (i==srclen-1)
            b1 = b2 = '\0';
        else if (i==srclen-2) {
            b1 = src[1];
            b2 = '\0';
        }
        else {
            b1 = src[1];
            b2 = src[2];
        }
	    *p++ = uuset[b0>>2 & 0x3f];
        *p++ = uuset[(((b0 & 0x03) << 4) | ((b1 & 0xf0) >> 4))];
        *p++ = uuset[(((b1 & 0x0f) << 2) | ((b2 & 0xc0) >> 6))];
        *p++ = uuset[b2 & 0x3f];
        src += 3;
    }
    *p = 0;      /* terminate the string */
    r = (unsigned char *)p - (unsigned char *)dst;     /* remember how many we
                                did */

    /* Always do 4-for-3, but if not round threesome, have to go
       clean up the last extra bytes */

    for( ; i != srclen; i--)
        *--p = '=';

    return r;
}

RC MakeBasicAuthentication(const char *userid, const char *passwd,
               char** authentication)
{
    RC rc = SUCCESS;
    const char *scheme = "basic ";
    char *tail;

    int luid = strlen(userid) + strlen(passwd);
    char *idpassw = malloc( luid + 2);

    if(!idpassw){
		rc = OUT_OF_MEMORY; return rc;
    }

    sprintf(idpassw, "%s:%s", userid, passwd);

    if(*authentication == 0){
		*authentication = malloc(luid+12);
		if(! (*authentication) ){
			free(idpassw); rc = OUT_OF_MEMORY; return rc;
		}
	}
    memset(*authentication, 0, luid+12);

    sprintf(*authentication, "%s", scheme);
    tail = *authentication + strlen(*authentication);
	NetUUEncode((const unsigned char*)idpassw, (unsigned char*)tail, 
				strlen(idpassw));
    free(idpassw);

    return rc;
}



int DoHttpPost(const char* server, 
		  unsigned int port, 
		  const char* uri, 
		  const char* msg, 
		  const char* authentication, 
		  char** header,  /* out */
		  char** response,  /* out */
		  int* status) /* out */
{
	char url[256];
	char *message = (char*) malloc(strlen(msg) + 1024);


	if (server == 0)
		return NO_SERVER_NAME;

	sprintf(message, "POST %s HTTP/1.0\n", uri);

    if(authentication != 0) {
		strcat(message, "Authorization: ");
		strcat(message, authentication);
		strcat(message, "\n"); 
    }

    if(msg != 0) 
        strcat(message, msg);
    else
        strcat(message, "\n");

	DoHttpRequest(server, port, message, header, response, status);
	free(message);
}

/*
 * Scan the incoming strins s and replace special characters by the
 * appropriate encodings and place the new string in od
 * if od is 0, memory is allocated
 * This is a special version. It also encodes & and = because with agents,
 * the POST message (say B) is sent in another POST message (say A). 
 * We don't want the server interpreting the contents of message B. 
 * Therefore, we encode even the = and & characters.
 */
char* EncodeUrl(char *od, const char *s)
{
    char *d;

    if(!od)
        od = (char *) malloc((strlen(s)*3) + 1);
    d = od;

    while(*s) {
        if(strchr("% +*\"<>\r\n=&", *s)) {
            sprintf(d, "%%%.2x", *s);
            ++s; d += 3;
        }
        else
            *d++ = *s++;
    }
    *d = '\0';
    return od;
}

/*
 * scan the response from the server and extract the id of the agent
 * created
 */
void
GetAgentId(const char* response, char* id)
{
	const char* p = strstr(response, "Agent Id:");
	p = strchr(p, ':');
	p++;
	while (*p && *p == ' ')   
		++p;
	while (*p && *p != ' ' && *p != '\\')   
		*id++ = *p++;

	*id = 0;
}


