#include "corba.h"


// Dynamic Implementation of Calculator.
class DSICalculator: public CORBA::DynamicImplementation
{
    private:
	CORBA::NVList_var 	_nv;
	CORBA::Any_var		_result;


	void  invoke(CORBA::ServerRequest_ptr req);
	void  add(CORBA::ServerRequest_ptr req);
	void  sub(CORBA::ServerRequest_ptr req);
    public:
	DSICalculator(const char *obj_name=NULL);
	~DSICalculator() {}
};


DSICalculator::DSICalculator(const char *obj_name) : 
		CORBA_DynamicImplementation("Calc", obj_name),
		_nv(new CORBA::NVList),
		_result(new CORBA::Any)
{
	// Initialize parameter list
	CORBA::Any doubleVal;
	doubleVal <<= (double)0;	// Sets typecode to double
	_nv->add_value("x", doubleVal, CORBA::ARG_IN);
	_nv->add_value("y", doubleVal, CORBA::ARG_IN);
}

void DSICalculator::add(CORBA::ServerRequest_ptr req)
{
	// Call params on req. After this call returns, the DSI
	// will unmarshal all the data values into the NameValue list 
	req->params(_nv);

	CORBA::NamedValue_var x_nv(_nv->item(0));
	CORBA::NamedValue_var y_nv(_nv->item(1));
	CORBA::Any_var x(x_nv->value());
	CORBA::Any_var y(y_nv->value());

	// Compute result
	_result->operator<<=( (*(CORBA::Double *)x->value() + 
			*(CORBA::Double *)y->value()));
}

void DSICalculator::sub(CORBA::ServerRequest_ptr req)
{
	// Call params on req. After this call returns, the DSI
	// will unmarshal all the data values into the NameValue list 
	req->params(_nv);

	CORBA::NamedValue_var x_nv(_nv->item(0));
	CORBA::NamedValue_var y_nv(_nv->item(1));
	CORBA::Any_var x(x_nv->value());
	CORBA::Any_var y(y_nv->value());

	// Compute result
	_result->operator<<=( (*(CORBA::Double *)x->value() -
			*(CORBA::Double *)y->value()));
}

void DSICalculator::invoke(CORBA::ServerRequest_ptr req)
{
	if ( strcmp(req->op_name(), "add") == 0)
		add(req);
	else 
		sub(req);

	// Set the computed result.
	req->result(_result);
}




int main(int argc, char *const *argv)
{
	CORBA::ORB_var orb = CORBA::ORB_init(argc, argv);
	CORBA::BOA_var boa = orb->BOA_init(argc, argv);

	
	DSICalculator calc("test");

	boa->obj_is_ready(&calc);

	boa->impl_is_ready();

	return 0;
}
