#include "linklist.h"

template <class T>
ListEntry<T>::ListEntry(T &entry)
{
  thisentry = entry;
  nextentry = 0;
  preventry = 0;
}

template <class T>
LinkedList<T>::LinkedList()
{
  iterator = 0;
  firstentry = 0;
  lastentry = 0;
}

template <class T>
LinkedList<T>::~LinkedList()
{
  while (firstentry)
    RemoveEntry(firstentry);
}

template <class T>
void LinkedList<T>::AppendEntry(T& entry)
{
	ListEntry<T> *newentry = new ListEntry<T>(entry);
	newentry->preventry = lastentry;
	if (lastentry)
		lastentry->nextentry = newentry;
	if (firstentry == 0)
		firstentry = newentry;
	lastentry = newentry;
}

template <class T>
void LinkedList<T>::RemoveEntry(ListEntry<T> *lentry)
{
	if (lentry == 0)
		return;
	if (lentry == iterator)
		iterator = lentry->preventry;
	if (lentry->nextentry)
		lentry->nextentry->preventry = lentry->preventry;
	if (lentry->preventry)
		lentry->preventry->nextentry = lentry->nextentry;
	if (lentry == lastentry)
		lastentry = lentry->preventry;
	if (lentry == firstentry)
		firstentry = lentry->nextentry;
	delete lentry;
}

template <class T>
void LinkedList<T>::InsertEntry(T& entry, ListEntry<T> *lentry)
{
	ListEntry<T> *newentry = new ListEntry<T>(entry);
	newentry->nextentry = lentry;
	if (lentry) {
		newentry->preventry = lentry->preventry;
		lentry->preventry = newentry;
	}
	if (newentry->preventry)
		newentry->preventry->nextentry = newentry;
	if (lentry == firstentry)
		firstentry = newentry;
}

template <class T>
void LinkedList<T>::RemoveEntry(int pos)
{
	FindEntry(pos);
	RemoveEntry(iterator);
}	

template <class T>
void LinkedList<T>::InsertEntry(T& entry, int pos)
{
	FindEntry(pos);
	InsertEntry(entry, iterator);
}

template <class T>
T *LinkedList<T>::CurrentEntry()
{
	return iterator ? &(iterator->thisentry) : 0;
}

template <class T>
T *LinkedList<T>::FindEntry(int pos)
{
	if (pos != -1) {
		iterator = firstentry;
		if (iterator) {
			while (pos--)
				iterator = iterator->nextentry;
		}
	}
	return CurrentEntry();
}

template <class T>
T *LinkedList<T>::FirstEntry()
{
	iterator = firstentry;
	return CurrentEntry();
}

template <class T>
T *LinkedList<T>::LastEntry()
{
	iterator = lastentry;
	return CurrentEntry();
}

template <class T>
T *LinkedList<T>::NextEntry()
{
	if (iterator == 0)
		iterator = firstentry;
	else
		iterator = iterator->nextentry;
	return CurrentEntry();
}

template <class T>
T *LinkedList<T>::PrevEntry()
{
	if (iterator == 0)
		iterator = lastentry;
	else
		iterator = iterator->preventry;
	return CurrentEntry();
}





