//  The client and server are linked into the same program
#include <iostream.h>
#include "lib_c.hh"
#include "libsrv.h"

int main(int argc, char *const *argv)
{
	// Initialize ORB
	// Conforms to ORB initialization spec - 94-10-24
	CORBA::ORB_var orb = CORBA::ORB_init(argc, argv);
	CORBA::BOA_var boa = orb->BOA_init(argc, argv);

	// Create the server instance
	Library library_server("Harvard");

	boa->obj_is_ready(&library_server);

	CORBA::Boolean 		ret;

	// Client portion
	if (argc < 3) {
		cout << "library_client: You must specify an author and title"
			<< endl;
		return 0;
	}
	book book_entry;
	book_entry.author = (const char *)argv[1];
	book_entry.title = (const char *)argv[2];

	library_var library_object;
	try {
		library_object = library::_bind();
	}
	catch(const CORBA::SystemException& excep) {
		cout << "Error binding to library" << endl;
		cout << excep;
		return(0);
	}
	cout << "Bound to library server" << endl;
	try {
		ret = library_object->add_book(book_entry);
	}
	catch(const CORBA::SystemException& excep) {
		cout << "Error adding book" << endl;
		cout << excep;
		return 0;
	}
	if (ret)
		cout << "Added book to library" << endl;
	else 
		cout << "add_book invocation failed" << endl;
	return(1);

}


// Server functions
Library::Library(const char *object_name) : _sk_library(object_name)
{
}

CORBA::Boolean Library::add_book(const book& book_info) 
{
	return bk_list.add_to_list(book_info);
}
