#include <iostream.h>
#include "corba.h"


int main(int argc, char *const *argv)
{
	CORBA::ORB_var orb = CORBA::ORB_init(argc, argv);
	CORBA::Object_var	library;
	CORBA::Request_var 	req;
	CORBA::TypeCode_var 	bookTypeCode;
	CORBA::Any 		bookValue;
	if (argc < 3) {
		cout << "library_client: You must specify an author and title"
			<< endl;
		return(0);
	}


	
	try {
		library = orb->bind("library");
	}
	catch(CORBA::Exception& excep) {
		cout << "Error binding to library" << endl;
		cout << excep;
	}
	cout << "Bound to library server" << endl;

	req = library->_request("add_book");

	// Create TypeCode for structure
	CORBA::StructMemberSeq members;
	members.length(2);
	members[0].name = (const char *)"author";
	members[0].type = CORBA::TypeCode::_duplicate(CORBA::_tc_string);
	members[1].name = (const char *)"title";
	members[1].type = CORBA::TypeCode::_duplicate(CORBA::_tc_string);
	
	bookTypeCode = orb->create_struct_tc(
				"book", "book", members);
				
	// Write out author and title to a MarshalOutBuffer
	CORBA::MarshalOutBuffer buf;
	buf << argv[1];		// Author
	buf << argv[2];		// Title
	bookValue.replace(bookTypeCode, buf);

	// Get Argument list from request.
	CORBA::NVList_var arguments = req->arguments();
	arguments->add_value("book", bookValue, CORBA::ARG_IN);

	
	// Set result
	// NOTE: All parameters types (IN, OUT, INOUT and RETURN) need
	//	to be set so that DII knows the data types of all 
	//	arguments.
	CORBA::Boolean ret=0;
	CORBA::NamedValue_var result(req->result());
	CORBA::Any_var  resultAny(result->value());
	resultAny->replace(CORBA::_tc_boolean, &result);

	// Execute the function
	req->invoke();
	CORBA::Environment_var env = req->env();
	if ( env->exception() ) 
		cout << "Exception occured" << endl;
	else  {
		// Get the return value;
		ret = *(CORBA::Boolean *)resultAny->value();
	}
	cout << "Return value from invoke: " << (int)ret << endl;
	return(1);

}


