#include <signal.h>
#include "db_s.hh"

class DBObjectImpl: public _sk_DBObject
{
    private:
	CORBA::String_var	_name;
    public:
	DBObjectImpl(const char *nm, const CORBA::ReferenceData& data)
			: _sk_DBObject("DBService", data), _name(nm) {}
	~DBObjectImpl() {}

	char *get_name() { return CORBA::strdup(_name); }

	void	set_name(const char *nm) { _name = nm; }
};

class MyDB: public _sk_DB
{
    private:
	CORBA::Object_var	_prevObj;
    public:
	MyDB(const char *name=NULL): _sk_DB(name) {}
	
	DBObject_ptr create_object(const char *name) {
		char ref_data[100];
		sprintf(ref_data, "%s", name);
		CORBA::ReferenceData id(100, 100, (CORBA::Octet *)ref_data);
		DBObjectImpl *obj = new DBObjectImpl(name, id);
		_boa()->obj_is_ready(obj);
		_prevObj = obj;
		return obj;
	}
};


	


class DBActivator: public CORBA::Activator
{
	virtual CORBA::Object_ptr activate(CORBA::ImplementationDef_ptr impl);
	virtual void deactivate(CORBA::Object_ptr, 
			CORBA::ImplementationDef_ptr impl );
};

CORBA::Object_ptr DBActivator::activate(CORBA::ImplementationDef_ptr impl)
{
	static int count =0;
	cout << "Activator called " << ++count << " times" << endl;
	CORBA::ReferenceData_var id(impl->id());
	return new DBObjectImpl((char *)id->data(), id);
}

void DBActivator::deactivate(CORBA::Object_ptr obj, 
			CORBA::ImplementationDef_ptr impl )
{
	obj->_release();
} 

int main(int argc, char **argv)
{
	// Initialize ORB. 
	// Conforms to ORB initialization spec - 94-10-24
	CORBA::ORB_ptr orb = CORBA::ORB_init(argc, argv);
	CORBA::BOA_ptr boa = orb->BOA_init(argc, argv);

	MyDB db;
	boa->obj_is_ready(&db);
	

	// do something, and get ready to receive requests
	boa->impl_is_ready("DBService", new DBActivator);

	return(1);
}
