#ifndef _NAMELIB_HPP
#define _NAMELIB_HPP

#include <corba.h>
#include "netsite.h"
#include "ONEiiop.h"
#include "cosnaming_c.hpp"

#ifdef _MSC_VER
#pragma warning( disable : 4275)
#endif

#ifdef XP_WIN32
#define DLLEXPORT __declspec(dllexport)
#else
#define DLLEXPORT
#endif

class DLLEXPORT LNameComponent: public CosNaming::NameComponent 
{
public:
	class DLLEXPORT NotSet {}; // Exception

public:
	LNameComponent();
	LNameComponent(const char *i, const char *k="");
	LNameComponent(const CosNaming::NameComponent& rhs);
	~LNameComponent();
	LNameComponent& operator =(const LNameComponent& rhs);
	const char *get_id()const;
	const char *set_id(const char *i);
	const char *get_kind()const;
	const char *set_kind(const char *k);
	void destroy();
};

class LNCList;

class DLLEXPORT LName
{
public:
	class DLLEXPORT NoComponent {}; // Exception
	class DLLEXPORT OverFlow {};	// Exception
	class DLLEXPORT InvalidName{};  // Exception

public:
	LName();
	~LName();
	void insert_component(unsigned long i, LNameComponent* n);
	const LNameComponent *get_component(unsigned long i)const;
	LNameComponent *delete_component(unsigned long i);
	unsigned long num_components()const;
	CORBA::Boolean equal(const LName& rhs);
	CORBA::Boolean less_than(const LName& rhs);
	CosNaming::Name *to_idl_form();
	void from_idl_form(const CosNaming::Name& rhs);
	void destroy();

private:

	LNCList *_list;
};

//
// The following are not part of the Library Naming spec, but they can come in handy
//

//
// This provides an exception safe (and convenient) way to hold the
// Name returned by the LName to_idl_form method.
class DLLEXPORT safeName {
public:
	safeName();
	safeName(CosNaming::Name *p):_p(p){}
	~safeName(){delete _p;}
	safeName& operator =(CosNaming::Name *p);
	CosNaming::Name *operator ()(void){return _p;}

private:
	CosNaming::Name *_p;
};

//
// For the time being these are private to the IIOP module.
//

CosNaming::Name * DLLEXPORT NameFromString(const char *s, char sepchar);

CosNaming::NamingContext * DLLEXPORT getRootNaming(const char *host, int port=0);

CORBA::Object_ptr DLLEXPORT resolveWAS(const char *object_name);

CORBA::Object_ptr DLLEXPORT resolveURI(const char *host, int port, const char *uri);

WAIBool DLLEXPORT registerWAS(const char *host, const char *object_name, CORBA::Object_ptr obj);
WAIBool DLLEXPORT registerObject(const char *host, const char *url, CORBA::Object_ptr obj);


#endif /* _NAMELIB_HPP */
