#ifndef _NAMESRV_HPP
#define _NAMESRV_HPP

#include "cosnaming_s.hpp"
#include <rw/hashtab.h>
#include <rw/collstr.h>
#include <rw/gdlist.h>
#include <rw/slistcol.h>
#include "NameLib.hpp"
#include "waicrtsc.hpp"

class NSBindingIterator;
class NSNameContext;

declare(RWGDlist, NSBindingIterator)

class ContextList: public RWSlistCollectables 
{
RWDECLARE_COLLECTABLE(ContextList)
public:
	ContextList();
	~ContextList();
	void AddContext(RWCollectable *c);
	void RemoveContext(RWCollectable *c);
	void Save();
	void Restore();
	static ContextList *TheContexts();
	static const RWCString getArchivePath(const char *suffix);
	void SaveLock(){_crit->Acquire();}
	void SaveUnlock(){_crit->Release();}
	WAICriticalSectionBase& getSaveLock(){return *_crit;}
	unsigned long incrWaterMark();
	void saveGuts(RWvostream& strm)const;
	void restoreGuts(RWvistream& strm);

private:
	static ContextList *_theContexts;
    WAICriticalSectionBase *_crit;
	unsigned long _waterMark;

};

inline unsigned long 
ContextList::incrWaterMark()
{
	unsigned long wm;
	SaveLock();
	wm = _waterMark++;
	SaveUnlock();
	return wm;
}

class NSRootNaming: public RWHashTable
{
	RWDECLARE_COLLECTABLE(NSRootNaming)
	friend class NSNameContext;
public:
	NSRootNaming();
	NSRootNaming(const char *instance);
	NSRootNaming(const NSRootNaming& rhs);
	virtual ~NSRootNaming();
	NSNameContext *CorbaContext(){return _corba_context;}

	// Inherited from RWCollectable
	RWBoolean isEqual(const RWCollectable *c)const;
	void saveGuts(RWvostream& strm)const;
	void restoreGuts(RWvistream& strm);

private:
    WAICriticalSectionBase *_crit;
    RWGDlist(NSBindingIterator) _iters;
	NSNameContext *_corba_context;
	RWCString _serviceName; // Service name of associated corba context
};

class NSNameContext: public _sk_CosNaming::_sk_NamingContext
{
public:
	NSNameContext(NSRootNaming& rn, const char *instance=0);
	NSNameContext(NSRootNaming& rn, const char *service_name, const CORBA::ReferenceData& data);
	NSNameContext(const NSNameContext& rhs);
	virtual ~NSNameContext();
	virtual void bind(const CosNaming::Name& n,
			CORBA::Object_ptr obj);
	virtual void rebind(const CosNaming::Name& n,
			CORBA::Object_ptr obj);
	virtual void bind_context(const CosNaming::Name& n,
			CosNaming::NamingContext_ptr nc);
	virtual void rebind_context(const CosNaming::Name& n,
			CosNaming::NamingContext_ptr nc);
	virtual CORBA::Object_ptr resolve(const CosNaming::Name& n);
	virtual void unbind(const CosNaming::Name& n);
	virtual CosNaming::NamingContext_ptr new_context();
	virtual CosNaming::NamingContext_ptr bind_new_context(const CosNaming::Name& n);
	virtual void destroy();
	virtual void list(CORBA::ULong how_many,
			CosNaming::BindingList *& bl,
			CosNaming::BindingIterator_ptr& bi);
    void removeIterator(NSBindingIterator *iter);
private:
	NSRootNaming& objDict(){return _rootNaming;}

private:
    RWGDlist(NSBindingIterator) _iters;
	NSRootNaming& _rootNaming;
};




class CosNameEntry: public RWCollectableString
{
	RWDECLARE_COLLECTABLE(CosNameEntry)

public:
	CosNameEntry():_type(CosNaming::nobject){}
	CosNameEntry(const CosNaming::NameComponent& nc, 
					const RWCString& ior,
					CosNaming::BindingType type = CosNaming::ncontext);
	CosNameEntry(const CosNaming::NameComponent& nc, CosNaming::BindingType type = CosNaming::ncontext); 
	CosNameEntry(const char *rhs):RWCollectableString(rhs){}
	~CosNameEntry();
#ifndef HPUX
	RWCollectableString& operator =(const char *rhs){return RWCollectableString::operator =(rhs);}
#endif
	CosNameEntry& operator =(const CosNameEntry& rhs);
	void setObject(const RWCString& ior){_ior = ior;}
	const RWCString& getObject()const{return _ior;}
	const RWCString& get_id()const{return *this;}
	const RWCString& get_kind()const{return _kind;}
	const CosNaming::BindingType get_type()const{return _type;}
	// Inherited from RWCollectable
	// RWBoolean operator ==(const CosNameEntry& rhs)const;
	RWBoolean isEqual(const RWCollectable *c)const;
	void saveGuts(RWvostream& strm)const;
	void restoreGuts(RWvistream& strm);


private:
	RWCString _kind;
	RWCString _ior;
	CosNaming::BindingType _type;
};

class NSBindingIterator: public _sk_CosNaming::_sk_BindingIterator
{
public:
    NSBindingIterator(const char *object_name = NULL);
    NSBindingIterator(const char *service_name, const CORBA::ReferenceData& data);
    NSBindingIterator(NSNameContext& context);
    ~NSBindingIterator();
    // Inherited implementation methods
    virtual CORBA::Boolean next_one(CosNaming::Binding *& b);
    virtual CORBA::Boolean next_n(CORBA::ULong how_many, CosNaming::BindingList *& bl);
    virtual void destroy();
    void Allocate(CORBA::ULong how_many);
    void AppendItem(const CosNameEntry& b);
private:
    CosNaming::BindingList *_List;
    unsigned long _CurrentItem;
    NSNameContext *_context;
};


class NSNameComponent: public LNameComponent
{
public:
	NSNameComponent();
	NSNameComponent(const CosNaming::NameComponent& rhs):
	  LNameComponent(rhs){}
	NSNameComponent(const CosNameEntry& rhs);
};


#endif // _NAMESRV_HPP
