#ifndef _WAISRVPI_HPP
#define _WAISRVPI_HPP

/*
 * Provides C++ interface for IIOP based Server Plug-In objects
 * CONFIDENTIAL AND PROPRIETARY SOURCE CODE OF NETSCAPE COMMUNICATIONS CORPORATION
 *
 * Copyright (c) 1996 Netscape Communications Corporation.
 * All Rights Reserved.
 * Use of this Source Code is subject to the terms of the applicable
 * license agreement from Netscape Communications Corporation.
 *
 * The copyright notice(s) in this Source Code does not indicate actual or
 * intended publication of this Source Code. *
 * Robin J. Maxwell 11-19-1996
 */

#include "ONEiiop.h" // Get notification types

#if defined(XP_WIN32) && defined(BUILD_DLL)
#define DLLEXPORT __declspec(dllexport)
#else
#define DLLEXPORT
#endif

//
// Forward declarations
class HttpServerRequest;
class HttpServerContext;
class WebApplicationServiceSkeleton;

class DLLEXPORT WAIServerContext
{
public:
    WAIServerContext(HttpServerContext* rhs=0);
    virtual ~WAIServerContext();
    WAIServerContext& operator =(HttpServerContext *rhs);
    HttpServerContext *operator ()(){return _Context;}

    virtual WAIReturnType getInfo(const char * name,
			                      char *& value);
	virtual long getPort();
	
	virtual char *getName();
	
	virtual char *getHost();
	
	virtual char *getServerSoftware();
	
	virtual int isSecure();

private:
    HttpServerContext *_Context;
};

typedef WAIServerContext *WAIServerContext_ptr;

class DLLEXPORT WAIServerRequest
{
public:
    WAIServerRequest(HttpServerRequest* rhs=0);
    virtual ~WAIServerRequest();
    WAIServerRequest& operator =(HttpServerRequest *rhs);
    HttpServerRequest *operator ()(){return _Session;}
    virtual WAIServerContext_ptr getContext();
		
	virtual WAIReturnType getRequestInfo(const char * name,
			char *& value);
	
	virtual WAIReturnType setRequestInfo(const char * name,
			const char * value);
	
	virtual WAIReturnType getRequestHeader(const char * header,
			char *& value);

    virtual WAIReturnType getConfigParameter(const char * name,
			char *& value);
	
	virtual long WriteClient(const unsigned char *buffer, 
							 unsigned buffsize);
	
	virtual long ReadClient(unsigned char *buffer, 
							unsigned buffsize);
	
	virtual long StartResponse();
	
	virtual WAIReturnType setResponseStatus(long status,
			const char * reason);
	
	virtual WAIReturnType setResponseContentType(const char * ContentType);
	
	virtual WAIReturnType setResponseContentLength(unsigned long Length);
	
	virtual WAIReturnType getResponseContentLength(unsigned long& Length);
	
	virtual WAIReturnType getResponseHeader(const char * header,
			char *& value);
	
	virtual WAIReturnType addResponseHeader(const char * header,
			const char * value);
	
	virtual WAIReturnType delResponseHeader(const char * header);
	
	virtual char * BuildURL(const char * prefix,
			const char * suffix);
	
	virtual WAIReturnType LogError(long degree,
			const char * func,
			const char * msg,
			WAIBool clientinfo);
	
	virtual WAIReturnType RespondRedirect(const char * url);

	virtual WAIReturnType setCookie(const char * name,
                                    const char * value,
                                    const char * expires,
                                    const char * domain,
                                    const char * path,
                                    WAIBool secure);
	
	virtual WAIReturnType getCookie(char *& cookie);

private:
	HttpServerRequest *_Session;
    WAIServerContext _Context;
};

typedef WAIServerRequest *WAIServerRequest_ptr;

//
// Base class for Server Plug-ins
//

class DLLEXPORT WAIWebApplicationService
{
public:
    WAIWebApplicationService(const char *object_name = 0);
    WAIWebApplicationService(const char *object_name, int argc, char **argv);

    ~WAIWebApplicationService();
	WAIBool RegisterService(const char *host=NULL);
	// Use these functions for
	// allocating and freeing strings.
	char *StringAlloc(size_t size)const;
	void StringDelete(char *s)const;
	char *StringDup(const char *s)const;
	virtual char *getServiceInfo()=0;
    virtual long Run(WAIServerRequest_ptr session)=0;

private:
    WebApplicationServiceSkeleton *_spis;
};

#endif // _WAISRVPI_HPP
