#ifndef _WAIIIOP_H
#define _WAIIIOP_H

/*
 * WAI Server IIOP Plug In.
 * PROPRIETARY SOURCE CODE OF NETSCAPE COMMUNICATIONS CORPORATION
 *
 * Copyright (c) 1996-1997 Netscape Communications Corporation.
 * All Rights Reserved.
 *
 * Use of this Source Code is subject to the terms of the applicable
 * license agreement from Netscape Communications Corporation.
 *
 * Robin J. Maxwell
 */

#if defined(WIN32)
#include <windows.h>
#endif
#include "netsite.h"

typedef enum { WAI_FALSE = 0, WAI_TRUE = 1 } WAIBool;

enum WAIReturnType {
    WAISPISuccess,
    WAISPIFailure
};
typedef enum WAIReturnType WAIReturnType_t;

typedef struct{
	void *reserved;
} *ServerSession_t;

typedef struct{
	void *reserved;
} *IIOPWebAppService_t;

typedef struct{
	void *reserved;
} *ServerContext_t;

#if defined(__cplusplus)

typedef long (*WAIRunFunction)(ServerSession_t obj);

#define BEGINEXTERNC extern "C" {
#define ENDEXTERNC }

#else

typedef long (*WAIRunFunction)(ServerSession_t obj);

#define BEGINEXTERNC
#define ENDEXTERNC

#endif /* __cplusplus */


BEGINEXTERNC

/* Create a plug in object */
NSAPI_PUBLIC IIOPWebAppService_t WAIcreateWebAppService(const char *name, WAIRunFunction func,
														int argc, char **argv);
NSAPI_PUBLIC WAIBool WAIregisterService(IIOPWebAppService_t p, const char *host);

NSAPI_PUBLIC void WAIimplIsReady(void);

/* Destroy a plug in object */
NSAPI_PUBLIC void WAIdeleteService(IIOPWebAppService_t WebAppService);
		
NSAPI_PUBLIC WAIBool WAIgetInfo(ServerSession_t p, const char * name, char ** value);
		
NSAPI_PUBLIC long WAIgetPort(ServerSession_t p);
	
NSAPI_PUBLIC char * WAIgetName(ServerSession_t p);
		
NSAPI_PUBLIC char * WAIgetHost(ServerSession_t p);
		
NSAPI_PUBLIC char * WAIgetServerSoftware(ServerSession_t p);
		
NSAPI_PUBLIC WAIBool WAIisSecure(ServerSession_t p);

NSAPI_PUBLIC WAIReturnType_t WAIgetRequestInfo(ServerSession_t p, 
									const char * name,
									char ** value);		
		
NSAPI_PUBLIC WAIReturnType_t WAIsetRequestInfo(ServerSession_t p, 
									const char * name,
									const char * value);

NSAPI_PUBLIC WAIReturnType_t WAIgetRequestHeader(ServerSession_t p, 
										const char * name,
										char ** value);

NSAPI_PUBLIC WAIReturnType_t WAIgetConfigParameter(ServerSession_t p, 
										const char * name,
										char ** value);
		
NSAPI_PUBLIC long WAIWriteClient(ServerSession_t p, 
								 const unsigned char *buffer, 
								 unsigned buffsize);
		
NSAPI_PUBLIC long WAIReadClient(ServerSession_t p, 
								unsigned char *buffer, 
								unsigned buffsize);
		
		
NSAPI_PUBLIC long WAIStartResponse(ServerSession_t p);
		
NSAPI_PUBLIC WAIReturnType_t WAIsetResponseStatus(ServerSession_t p, 
									   long status,
									   const char * reason);
		
NSAPI_PUBLIC WAIReturnType_t WAIsetResponseContentType(ServerSession_t p, 
											const char * ContentType);
		
NSAPI_PUBLIC WAIReturnType_t WAIsetResponseContentLength(ServerSession_t p, 
											  unsigned long Length);

NSAPI_PUBLIC WAIReturnType_t WAIgetResponseContentLength(ServerSession_t p, 
											  unsigned long *Length);
		
NSAPI_PUBLIC WAIReturnType_t WAIgetResponseHeader(ServerSession_t p, 
									   const char * header,
									   char ** value);
		
NSAPI_PUBLIC WAIReturnType_t WAIaddResponseHeader(ServerSession_t p, 
									   const char * header,
									   const char * value);
		
NSAPI_PUBLIC WAIReturnType_t WAIdelResponseHeader(ServerSession_t p, 
									   const char * header);
		
NSAPI_PUBLIC char * WAIBuildURL(ServerSession_t p, 
								const char * prefix,
							    const char * suffix);
		
NSAPI_PUBLIC WAIReturnType_t WAILogError(ServerSession_t p, 
										 long degree,
										 const char * func,
										 const char * msg,
										 WAIBool clientinfo);
		
		
NSAPI_PUBLIC WAIReturnType_t WAIRespondRedirect(ServerSession_t p, const char * url);

NSAPI_PUBLIC WAIReturnType_t WAIsetCookie(ServerSession_t p,
										  const char * name,
										  const char * value,
										  const char * expires,
										  const char * domain,
										  const char * path,
										  WAIBool secure);

NSAPI_PUBLIC WAIReturnType_t WAIgetCookie(ServerSession_t p, 
										char ** cookie);

NSAPI_PUBLIC void WAIstringFree(char *s);

ENDEXTERNC

#endif /* _WAIIIOP_H */


