#ifndef _any_h_
#define _any_h_
/****************************************************************************/
/*                                                                          */
/*  Copyrighted by PostModern Computing Technologies, Inc   		    */
/*                                                                          */
/*  Copyright 1992, 1993, 1994 by PostModern Computing Technologies, Inc.   */
/*                          1897 Landings Drive				    */
/*                          Mountain View, California, USA                  */
/*                          Telephone (415) 967-6169                        */
/*                          Facsimile (415) 967-6212                        */
/*                                                                          */
/*  This code is the sole property of PostModern Computing Technologies,    */
/*  Inc.  and is  protected  by  copyright under the laws of the United     */
/*  States.   This  program is confidential, proprietary, and  a  trade     */
/*  secret,  not  to  be disclosed  without written authorization  from     */
/*  PostModern Computing Technologies, Inc.  Any use,  duplication,  or     */
/*  disclosure  of  this  program  by other than  PostModern  Computing     */
/*  Technologies, Inc. and its assigned licensees is strictly forbidden     */
/*  by law.                                                                 */
/*                                                                          */
/*  All rights reserved.                                                    */
/*                                                                          */
/*  Author: psm                                                             */
/*                                                                          */
/****************************************************************************/

#include "typecode.h"

// Any Class conforming to the C++ mapping as specified in OMG 
// Document 94-9-14, page 94

class _PMCEXPORT CORBA_Any
{
	friend CORBA_TypeCode;
    public:
	CORBA_Any();
	CORBA_Any(const CORBA::Any&);
	CORBA_Any(CORBA::TypeCode_ptr tc, void *value, CORBA::Boolean release=0);
	
	// PostModern Extension
	CORBA_Any(CORBA::TypeCode_ptr tc, const CORBA::MarshalOutBuffer&);

	~CORBA_Any();

	CORBA::Any& operator=(const CORBA::Any& );
	
	void operator<<=(CORBA::Short);
	void operator<<=(CORBA::UShort);
	void operator<<=(CORBA::Long);
	void operator<<=(CORBA::ULong);
	void operator<<=(CORBA::Float);
	void operator<<=(CORBA::Double);
	void operator<<=(const CORBA::Any&);
	void operator<<=(const char *);
	void operator<<=(CORBA::TypeCode_ptr tc) {
		replace(CORBA::_tc_TypeCode, 
		(void *)CORBA::TypeCode::_duplicate(tc), 1);
	}

	CORBA::Boolean operator>>=(CORBA::Short&) const;
	CORBA::Boolean operator>>=(CORBA::UShort&) const;
	CORBA::Boolean operator>>=(CORBA::Long&) const;
	CORBA::Boolean operator>>=(CORBA::ULong&) const;
	CORBA::Boolean operator>>=(CORBA::Float&) const;
	CORBA::Boolean operator>>=(CORBA::Double&) const;
	CORBA::Boolean operator>>=(CORBA::Any&) const;
	CORBA::Boolean operator>>=(char *&) const;
	CORBA::Boolean operator>>=(CORBA::TypeCode_ptr& tc) const;

	struct _PMCEXPORT from_boolean {
		from_boolean(CORBA::Boolean b) : val(b) {}
		CORBA::Boolean val;
	};
	struct _PMCEXPORT from_octet {
		from_octet(CORBA::Octet b) : val(b) {}
		CORBA::Octet val;
	};
	struct _PMCEXPORT from_char {
		from_char(CORBA::Char b) : val(b) {}
		CORBA::Char val;
	};
	
	void operator<<=(from_boolean);
	void operator<<=(from_octet);
	void operator<<=(from_char);

	struct _PMCEXPORT to_boolean {
		to_boolean(CORBA::Boolean& b) : ref(b) {}
		CORBA::Boolean& ref;
	};
	struct _PMCEXPORT to_octet {
		to_octet(CORBA::Octet& b) : ref(b) {}
		CORBA::Octet& ref;
	};
	struct _PMCEXPORT to_char {
		to_char(CORBA::Char& b) : ref(b) {}
		CORBA::Char& ref;
	};

	CORBA::Boolean operator>>=(to_boolean) const;
	CORBA::Boolean operator>>=(to_char) const;
	CORBA::Boolean operator>>=(to_octet) const;

	void replace(CORBA::TypeCode_ptr, void *value, CORBA::Boolean release=0);

	// PostModern Extension
	void replace(CORBA::TypeCode_ptr,  const CORBA::MarshalOutBuffer&);
	void write_value(NCostream&);
	void read_value(NCistream&, CORBA::TypeCode_ptr tc);
	
	CORBA::TypeCode_ptr type() const { return CORBA::TypeCode::_duplicate(_tc); }
	const void   *value() const;

	CORBA::Long	len() const { return _len; }
	static CORBA::Any_ptr	_nil() { return (CORBA::Any_ptr)NULL; }
	static CORBA::Any_ptr _duplicate(CORBA::Any_ptr ptr) {
		if (ptr) ptr->_ref_count++;
		return ptr;
	}
	static void _release(CORBA::Any *ptr) {
		if ( ptr && (--(ptr->_ref_count) == 0) )
			delete ptr;
	}
	_PMCEXPORT friend NCostream& operator<<(NCostream& strm, const CORBA::Any& any);
	_PMCEXPORT friend NCostream& operator<<(NCostream& strm, const CORBA::Any_ptr any);
	_PMCEXPORT friend NCistream& operator>>(NCistream& strm, CORBA::Any& any);
	_PMCEXPORT inline friend NCistream& operator>>(NCistream& strm, CORBA::Any_ptr& any) {
		any = new CORBA::Any;
		strm >> *any;
		return strm;
	}
	_PMCEXPORT friend ostream& operator<<(ostream&, const CORBA::Any&);
	_PMCEXPORT inline friend istream& operator>>(istream& strm, CORBA::Any& any) {
		NCistream istrm(strm);
		istrm >> any;
		return strm;
	}
	_PMCEXPORT inline friend istream& operator>>(istream& strm, CORBA::Any_ptr& any) {
		NCistream istrm(strm);
		istrm >> any;
		return strm;
	}
	_PMCEXPORT friend CORBA::Long compare(const CORBA::Any&, const CORBA::Any&);
	_PMCEXPORT friend CORBA::ULong hash(const CORBA::Any&);
    private:
	void operator<<=(unsigned char) {}
	void operator>>=(unsigned char&) const {}
	
	CORBA::TypeCode_ptr	_tc;
	void			*_value;
	CORBA::Long		_len;
	CORBA::Boolean		_release_flag;
	CORBA::ULong		_ref_count;
};

class _PMCEXPORT CORBA_Any_var
{
    private:
	CORBA::Any_ptr	_ptr;
    public:
	CORBA_Any_var() { _ptr = CORBA::Any::_nil(); }
	CORBA_Any_var(CORBA::Any_ptr a) { 
		_ptr = a; 
	}
	CORBA_Any_var(const CORBA::Any_var& a) { 
		_ptr = CORBA::Any::_duplicate((CORBA::Any_ptr )a);
	}
	~CORBA_Any_var() { CORBA::Any::_release(_ptr); }

	CORBA::Any_var& operator=(CORBA::Any_ptr p) {
		if ( _ptr != p) { 
			CORBA::Any::_release(_ptr);
			_ptr  = p;
		}
		return *this;
	}
	CORBA::Any_var& operator=(const CORBA::Any_var& a) {
		CORBA::Any::_release(_ptr);
		_ptr = CORBA::Any::_duplicate((CORBA::Any_ptr )a);
		return *this;
	}
	
	CORBA::Any_ptr operator->() const { return _ptr; }
	operator const CORBA::Any& () const { return *_ptr; }
	operator CORBA::Any& () { return *_ptr; }
	operator CORBA::Any_ptr() const { return _ptr; }
#if defined(_HPCC_BUG)
	operator CORBA::Any*& () { return _ptr; }
#else
	operator CORBA::Any_ptr& () { return _ptr; }
#endif

	_PMCEXPORT inline friend NCistream& operator>>(NCistream& strm, CORBA::Any_var& obj) {
		CORBA::release(obj._ptr);
		strm >> obj._ptr;
		return strm;
	}	
	_PMCEXPORT inline friend NCostream& operator<<(NCostream& strm, 
					const CORBA::Any_var& obj) {
		strm << obj._ptr;
		return strm;
	}
};


#endif
