#ifndef _boa_h
#define _boa_h
/****************************************************************************/
/*                                                                          */
/*  Copyrighted by PostModern Computing Technologies, Inc   		    */
/*                                                                          */
/*  Copyright 1992, 1993, 1994 by PostModern Computing Technologies, Inc.   */
/*                          1897 Landings Drive				    */
/*                          Mountain View, California, USA                  */
/*                          Telephone (415) 967-6169                        */
/*                          Facsimile (415) 967-6212                        */
/*                                                                          */
/*  This code is the sole property of PostModern Computing Technologies,    */
/*  Inc.  and is  protected  by  copyright under the laws of the United     */
/*  States.   This  program is confidential, proprietary, and  a  trade     */
/*  secret,  not  to  be disclosed  without written authorization  from     */
/*  PostModern Computing Technologies, Inc.  Any use,  duplication,  or     */
/*  disclosure  of  this  program  by other than  PostModern  Computing     */
/*  Technologies, Inc. and its assigned licensees is strictly forbidden     */
/*  by law.                                                                 */
/*                                                                          */
/*  All rights reserved.                                                    */
/*                                                                          */
/*  Author: psm                                                             */
/*                                                                          */
/****************************************************************************/

#include "orbtypes.h"

// BOA class conforming to C++ mapping as specified in OMG Document
// 94-9-14 page 102

class _PMCEXPORT CORBA_BOA
{
    public:
	// Create is not needed by ORBeline. In ORBeline, instantiating
	// the implementation (Class derived from skeleton) is equivalent
	// to creating an implementation.
	// This function is however provided inorder to comply with the
	// CORBA spec.

	virtual CORBA::Object_ptr create(const CORBA::ReferenceData&,
					 CORBA::InterfaceDef_ptr,
					 CORBA::ImplementationDef_ptr)=0;

	virtual void 		dispose(CORBA::Object_ptr) =0;
	virtual CORBA::ReferenceData_ptr 	
				get_id(CORBA::Object_ptr) =0;
	virtual void 		change_implementation(CORBA::Object_ptr, 
					CORBA::ImplementationDef_ptr)=0;
	virtual CORBA::Principal_ptr get_principal(CORBA::Object_ptr, 
					      CORBA::Environment_ptr)=0;
	virtual void 		obj_is_ready(CORBA::Object_ptr, 
				     CORBA::ImplementationDef_ptr impl=NULL) =0;
	virtual void 		impl_is_ready(CORBA::ImplementationDef_ptr impl=NULL)=0;
	virtual void		impl_is_ready(const char *service_name,
					CORBA::Activator_ptr activator,
					CORBA::Boolean block=1) =0;
	virtual void		deactivate_impl(CORBA::ImplementationDef_ptr)=0;
	virtual void 		deactivate_obj(CORBA::Object_ptr) =0;

	static CORBA::BOA_ptr 		_duplicate(CORBA::BOA_ptr ptr) { return ptr; }
	static CORBA::BOA_ptr 		_nil() { return (CORBA::BOA_ptr)NULL; }

	// PostModern Extensions
	enum RegistrationScope {
		SCOPE_GLOBAL = 0,
		SCOPE_LOCAL = 1
	};
	static RegistrationScope scope();
	static void 		scope(RegistrationScope val);

	virtual	void		exit_impl_ready() =0;

    protected:
	CORBA_BOA(); 
	~CORBA_BOA() {}
	CORBA_BOA(const CORBA::BOA&) {}
	CORBA::BOA& operator=(const CORBA::BOA&) { return *this; }

};

class _PMCEXPORT CORBA_BOA_var
{
    public:
	CORBA_BOA_var() : _ptr(CORBA::BOA::_nil()) {}
	CORBA_BOA_var(CORBA::BOA_ptr ptr) : _ptr(ptr) {}
	CORBA_BOA_var(const CORBA::BOA_var& var) : _ptr((CORBA::BOA_ptr)var) {}
	~CORBA_BOA_var() {}
	CORBA::BOA_var& operator=(CORBA::BOA_ptr p) { _ptr = p; return *this; }
	CORBA::BOA_ptr operator->() const { return _ptr; }
	operator CORBA::BOA_ptr() const { return _ptr; }
    private:
	CORBA::BOA_ptr  _ptr;
	void operator=(const CORBA::BOA_var&) {}
};
	
#endif
