#ifndef _bopt_h_
#define _bopt_h_
/****************************************************************************/
/*                                                                          */
/*  ORBeline (c)   is copyrighted by PostModern Computing Technologies, Inc */
/*                                                                          */
/*  Copyright 1993, 1994 by PostModern Computing Technologies, Inc.         */
/*                          1897 Landings Drive                             */
/*                          Mountain View, California, USA                  */
/*                          Telephone (415) 967-6169                        */
/*                          Facsimile (415) 967-6212                        */
/*                                                                          */
/*  This code is the sole property of PostModern Computing Technologies,    */
/*  Inc.  and is  protected  by  copyright under the laws of the United     */
/*  States.   This  program is confidential, proprietary, and  a  trade     */
/*  secret,  not  to  be disclosed  without written authorization  from     */
/*  PostModern Computing Technologies, Inc.  Any use,  duplication,  or     */
/*  disclosure  of  this  program  by other than  PostModern  Computing     */
/*  Technologies, Inc. and its assigned licensees is strictly forbidden     */
/*  by law.                                                                 */
/*                                                                          */
/*  All rights reserved.                                                    */
/*                                                                          */
/*  Author: psm                                                             */
/*                                                                          */
/****************************************************************************/

#include "orbtypes.h"

// Bind options to be used during binding (proxy _bind call).
// defer_bind - If set, bind occurs when the first operation on the
//		proxy is invoked, otherwise the _bind call establishes the 
//		connection.
// enable_rebind - If set, when an operation is being invoked and the
//		connection to the implementation is broken, ORB tries to
//		rebind to the implementation. If a replica of the implementation
//		exists, the ORB would bind to the replica.
// max_bind_tries - Specifies the number of retries for binding. If an
//		Object Implementation is registered with an OAD, ORB 
//		would request the OAD for the address of the implementation.
//		If the OAD replies with a busy exception, ORB retries again
//		'max_bind_tries' (sleeps one second and retries)
// send_timeout - Specifies the max time in seconds to block on a 
//		"send/" call. Since TCP has flow-control, if the  peer
//		is busy and does not respond, it is possible to block on
//		a send call for a long time. This parameter sets the
//		max seconds to block. If timed out a CORBA::NO_RESPONSE
//		exception is thrown, and the connection to the peer is
//		broken. The default value - 0, implies inifinite time
// receive_timeout - Specifies the max time in seconds to wait for a 
//		response to a request. If timed out a CORBA::NO_RESPONSE
//		exception is thrown, and the connection to the peer is
//		broken. The default value - 0, implies inifinite time
// connection_timeout- Specifies the max time in seconds to wait for a
//		connection. If timed out a CORBA::NO_IMPLEMENT 
//		exception is thrown. The default value - 0, implies
//		default system timeout for connects


struct _PMCEXPORT CORBA_BindOptions {
	CORBA::Boolean		defer_bind;
	CORBA::Boolean		enable_rebind;
	CORBA::Long		max_bind_tries;
	CORBA::ULong		send_timeout;
	CORBA::ULong		receive_timeout;
	CORBA::ULong		connection_timeout;

	CORBA_BindOptions() : defer_bind(0), enable_rebind(1), max_bind_tries(5),
			send_timeout(0), receive_timeout(0),
			connection_timeout(0) {}
};


class _PMCEXPORT CORBA_BindOptions_var
{
    public:
	CORBA_BindOptions_var() { _ptr = (CORBA::BindOptions*)NULL;}
	CORBA_BindOptions_var(CORBA::BindOptions *ptr) {
		_ptr = ptr;
	}
	CORBA_BindOptions_var(const CORBA::BindOptions_var& var) {
		if (var._ptr)
			_ptr = new CORBA::BindOptions(*var._ptr);
		else
			_ptr = (CORBA::BindOptions *)NULL;
	}
	~CORBA_BindOptions_var() {
		if (_ptr != (CORBA::BindOptions *)NULL) delete _ptr;
	}
	CORBA::BindOptions_var& operator=(CORBA::BindOptions *ptr) {
		if (_ptr != (CORBA::BindOptions *)NULL) delete _ptr;
		_ptr = ptr;
		return *this;
	}
	CORBA::BindOptions_var& operator=(const CORBA::BindOptions_var& var) {
		if (_ptr != (CORBA::BindOptions *)NULL) delete _ptr;
		if (var._ptr)
			_ptr = new CORBA::BindOptions(*var._ptr);
		else
			_ptr = (CORBA::BindOptions *)NULL;
		return *this;
	}
	CORBA::BindOptions *operator->() { return _ptr; }
	operator CORBA::BindOptions () const { return *_ptr; }
	operator CORBA::BindOptions& () { return *_ptr; }
    private:
	CORBA::BindOptions *_ptr;
};

#endif
