#ifndef _ctx_h_
#define _ctx_h_
/****************************************************************************/
/*                                                                          */
/*  Copyrighted by PostModern Computing Technologies, Inc   		    */
/*                                                                          */
/*  Copyright 1992, 1993, 1994 by PostModern Computing Technologies, Inc.   */
/*                          1897 Landings Drive				    */
/*                          Mountain View, California, USA                  */
/*                          Telephone (415) 967-6169                        */
/*                          Facsimile (415) 967-6212                        */
/*                                                                          */
/*  This code is the sole property of PostModern Computing Technologies,    */
/*  Inc.  and is  protected  by  copyright under the laws of the United     */
/*  States.   This  program is confidential, proprietary, and  a  trade     */
/*  secret,  not  to  be disclosed  without written authorization  from     */
/*  PostModern Computing Technologies, Inc.  Any use,  duplication,  or     */
/*  disclosure  of  this  program  by other than  PostModern  Computing     */
/*  Technologies, Inc. and its assigned licensees is strictly forbidden     */
/*  by law.                                                                 */
/*                                                                          */
/*  All rights reserved.                                                    */
/*                                                                          */
/*  Author: psm                                                             */
/*                                                                          */
/****************************************************************************/

#include "strvar.h"
#include "nameval.h"

class _PMCEXPORT CORBA_Context
{
	friend CORBA_ORB;
    public:
	const char 	*context_name() const { return _name; }
	CORBA::Context_ptr 	parent() { return CORBA::Context::_duplicate(_parent); }
	CORBA::Status 		create_child(const char *name, CORBA::Context_ptr&);
	CORBA::Status 		set_one_value(const char *name, const CORBA::Any&);
	CORBA::Status 		set_values(CORBA::NVList_ptr);
	CORBA::Status 		delete_values(const char *name);
	CORBA::Status		get_values(const char *start_scope, CORBA::Flags, 
				const char *name, CORBA::NVList_ptr&) const;

	static void   		_release(CORBA::Context_ptr ctx) {
			if (ctx && --ctx->_ref_count <= 0)
				delete ctx;
	} 
	static CORBA::Context_ptr 	_duplicate(CORBA::Context_ptr ctx) {
			if ( ctx )
				ctx->_ref_count++;
			return ctx;
	}
	static CORBA::Context_ptr 	_nil() { return (CORBA::Context_ptr)NULL; }

	_PMCEXPORT friend NCostream& operator<<(NCostream&, const CORBA::Context_ptr);
	_PMCEXPORT friend NCistream& operator>>(NCistream&, CORBA::Context_ptr&);

	void _write(NCostream& strm, const char *prop1, ...) const;
    private:
	CORBA_Context(const char *name);
	~CORBA_Context();
	CORBA_Context(const CORBA::Context& ctx);
	CORBA::Context& operator=(const CORBA::Context& ctx);

	void _remove_child(CORBA::Context_ptr ctx);


	CORBA::String_var	_name;
	CORBA::Context_ptr	_parent;
	CORBA::Context_ptr	*_children;
	CORBA::Long		_num_children;
	CORBA::Long		_num_allocated;
	CORBA::NVList		_nvlist;
	CORBA::Long		_ref_count;
};

class _PMCEXPORT CORBA_Context_var
{
    public:
        CORBA_Context_var() { _ptr = CORBA::Context::_nil(); }
        CORBA_Context_var(CORBA::Context_ptr ptr) { _ptr = ptr; }
        CORBA_Context_var(const CORBA::Context_var& var) {
                 _ptr = CORBA::Context::_duplicate(var._ptr);
        }
        ~CORBA_Context_var() { CORBA::release(_ptr); }
        CORBA::Context_var& operator=(CORBA::Context_ptr p) {
                 if (p != _ptr)
                        reset(p);
                return *this;
        }
        operator CORBA::Context_ptr() const { return _ptr; }
#if defined(_HPCC_BUG)
	operator CORBA::Context*& () { return _ptr; }
#else
	operator CORBA::Context_ptr& () { return _ptr; }
#endif
        CORBA::Context_ptr operator->() const { return _ptr; }

	_PMCEXPORT inline friend NCistream& operator>>(NCistream& strm, CORBA::Context_var& var) {
		CORBA::Context::_release(var._ptr);
		strm >> var._ptr;
		return strm;
	}
	_PMCEXPORT inline friend NCostream& operator<<(NCostream& strm,
				const CORBA::Context_var& var) {
		if ( var._ptr == NULL ) {
			PMCTHROW(CORBA::BAD_PARAM());
		}
		else
			strm << var._ptr;
		return strm;
	}
    private:
        CORBA::Context_ptr     _ptr;
        void reset(CORBA::Context_ptr p) {
                CORBA::release(_ptr);
                _ptr = p;
        }
        void operator=(const CORBA::Context_var&) {}
};



#endif
   

