#ifndef _dynimpl_h_
#define _dynimpl_h_
/****************************************************************************/
/*                                                                          */
/*  Copyrighted by PostModern Computing Technologies, Inc   		    */
/*                                                                          */
/*  Copyright 1992, 1993, 1994 by PostModern Computing Technologies, Inc.   */
/*                          1897 Landings Drive				    */
/*                          Mountain View, California, USA                  */
/*                          Telephone (415) 967-6169                        */
/*                          Facsimile (415) 967-6212                        */
/*                                                                          */
/*  This code is the sole property of PostModern Computing Technologies,    */
/*  Inc.  and is  protected  by  copyright under the laws of the United     */
/*  States.   This  program is confidential, proprietary, and  a  trade     */
/*  secret,  not  to  be disclosed  without written authorization  from     */
/*  PostModern Computing Technologies, Inc.  Any use,  duplication,  or     */
/*  disclosure  of  this  program  by other than  PostModern  Computing     */
/*  Technologies, Inc. and its assigned licensees is strictly forbidden     */
/*  by law.                                                                 */
/*                                                                          */
/*  All rights reserved.                                                    */
/*                                                                          */
/*  Author: jkw & psm                                                       */
/*                                                                          */
/****************************************************************************/

#include "orbtypes.h"

class PMCDynamicImpl;
class _PMCEXPORT CORBA_DynamicImplementation : public CORBA_Object 
{
	friend PMCDynamicImpl;
    private:
	PMCDynamicImpl		*_impl;
    public:
	virtual void invoke(CORBA::ServerRequest_ptr request) = 0;
  	static CORBA::DynamicImplementation_ptr _duplicate(
			CORBA::DynamicImplementation_ptr req) {
    		if(req) req->_ref_count++;
    			return req;
  	}
  	static CORBA::DynamicImplementation_ptr _nil() {
    			return 0;
  	}
	static void _release(CORBA::DynamicImplementation_ptr ptr) {
		if(ptr && --ptr->_ref_count <= 0) 
      		delete ptr;
  	}

	const CORBA::TypeInfo 	*_type_info() const;
	void			*_safe_narrow(const CORBA::TypeInfo&) const;


	typedef CORBA_StringSequence	RepositoryIdSequence;
	typedef CORBA_StringSequence	InterfaceNameSequence;

    protected:
	// This constructor assumes that the interface has no other
	// derived interfaces. If repository ID is NULL, a default repository
	// id is constructed assuming that there are no pragmas that could
	// define a repository id - Simple case
	// NOTE: If the interface has base interfaces, the second constructor
	//	should be used.
	CORBA_DynamicImplementation(const char *interface_name, 
				const char *object_name=NULL,
				const char *repository_id = NULL);

	// This constructor can be used in cases, where the Dynamic
	// implementation is implementing mulitple interfaces.
	// If RepositoryIdSequence is empty, IDs are generated using
	// default rules.
	CORBA_DynamicImplementation(const InterfaceNameSequence& interfaces,
				const RepositoryIdSequence& ids,
				const char *object_name=NULL);

        virtual ~CORBA_DynamicImplementation();
    private:
	CORBA_DynamicImplementation(const CORBA_DynamicImplementation&) {}
	CORBA_DynamicImplementation& operator=(
		const CORBA_DynamicImplementation&);
  	CORBA::Long _ref_count;
};

class CORBA_DynamicImplementation_var
{
    public:
	CORBA_DynamicImplementation_var() { 
			_ptr = CORBA_DynamicImplementation::_nil(); 
	}
	CORBA_DynamicImplementation_var(CORBA::DynamicImplementation_ptr ptr) {
		 _ptr = ptr; 
	}
	CORBA_DynamicImplementation_var(
			const CORBA_DynamicImplementation_var& var) {
    		_ptr = CORBA_DynamicImplementation::_duplicate(var._ptr);
  	}
	~CORBA_DynamicImplementation_var() { 
		CORBA_DynamicImplementation::_release(_ptr); 
	}
	CORBA_DynamicImplementation_var& operator=(
			CORBA::DynamicImplementation_ptr p) {
		if (p != _ptr)
			reset(p);
		return *this;
	}
	operator CORBA::DynamicImplementation_ptr() const { return _ptr; }
#if defined(_HPCC_BUG)
	operator CORBA::DynamicImplementation*&() { return _ptr; }
#else
	operator CORBA::DynamicImplementation_ptr&() { return _ptr; }
#endif
	CORBA::DynamicImplementation_ptr operator->() const { return _ptr; }
private:
	CORBA::DynamicImplementation_ptr     _ptr;
	void reset(CORBA::DynamicImplementation_ptr p) {
		CORBA_DynamicImplementation::_release(_ptr);
		_ptr = p;
	}
	void operator=(const CORBA_DynamicImplementation_var&) {}
};

#endif
