#ifndef _env_h_
#define _env_h_
/****************************************************************************/
/*                                                                          */
/*  ORBeline (c)   is copyrighted by PostModern Computing Technologies, Inc */
/*                                                                          */
/*  Copyright 1993, 1994 by PostModern Computing Technologies, Inc.         */
/*                          1897 Landings Drive                             */
/*                          Mountain View, California, USA                  */
/*                          Telephone (415) 967-6169                        */
/*                          Facsimile (415) 967-6212                        */
/*                                                                          */
/*  This code is the sole property of PostModern Computing Technologies,    */
/*  Inc.  and is  protected  by  copyright under the laws of the United     */
/*  States.   This  program is confidential, proprietary, and  a  trade     */
/*  secret,  not  to  be disclosed  without written authorization  from     */
/*  PostModern Computing Technologies, Inc.  Any use,  duplication,  or     */
/*  disclosure  of  this  program  by other than  PostModern  Computing     */
/*  Technologies, Inc. and its assigned licensees is strictly forbidden     */
/*  by law.                                                                 */
/*                                                                          */
/*  All rights reserved.                                                    */
/*                                                                          */
/****************************************************************************/

#include "stexcep.h"

class _PMCEXPORT CORBA_Environment
{
    private:
	CORBA::Exception			*_exception;
    public:
	CORBA_Environment() { _exception = (CORBA::Exception *)NULL; }
	~CORBA_Environment() { CORBA::release(_exception); }

	CORBA::Exception *exception() const { return _exception; }
	void  exception(CORBA::Exception *exp) {
		if ( _exception != exp) {
			CORBA::release(_exception);
			_exception = exp;
		}
	}
	void  clear() { 
		CORBA::release(_exception);
		_exception = (CORBA::Exception *)NULL; 
	}

	static CORBA::Environment_ptr _duplicate(CORBA::Environment_ptr env);
	static CORBA::Environment_ptr _nil() { return (CORBA::Environment_ptr)NULL; }

	_PMCEXPORT friend NCostream& operator<<(NCostream& strm, const CORBA::Environment& env);
	_PMCEXPORT friend NCostream& operator<<(NCostream& strm, 
			CORBA::Environment_ptr env)  {
		if (!env) 
			PMCTHROW(CORBA::BAD_PARAM());
		else
			operator<<(strm, *env);
		return strm;
	}
	_PMCEXPORT friend NCistream& operator>>(NCistream& strm, CORBA::Environment& env);
	_PMCEXPORT friend NCistream& operator>>(NCistream& strm, 
			CORBA::Environment_ptr& env) {
		env = new CORBA::Environment;
		return operator>>(strm, *env);
	}
	_PMCEXPORT friend ostream& operator<<(ostream& strm, const CORBA::Environment& env);
};

class _PMCEXPORT CORBA_Environment_var
{
    public:
        CORBA_Environment_var() : _ptr(CORBA::Environment::_nil()) {}
        CORBA_Environment_var(CORBA::Environment_ptr ptr) :_ptr(ptr) {}
        CORBA_Environment_var(const CORBA::Environment_var& var)
                :_ptr(CORBA::Environment::_duplicate((CORBA::Environment_ptr)var)) {}
        ~CORBA_Environment_var() { CORBA::release(_ptr); }
        CORBA::Environment_var& operator=(CORBA::Environment_ptr p) {
                if (_ptr != p ) {
                        CORBA::release(_ptr);
                        _ptr = p;
                }
                return *this;
        }
        operator CORBA::Environment_ptr() const { return _ptr; }
#if defined(_HPCC_BUG)
        operator CORBA::Environment*& () { return _ptr; }
#else
        operator CORBA::Environment_ptr& () { return _ptr; }
#endif
        CORBA::Environment_ptr operator->() const { return _ptr; }
        _PMCEXPORT inline friend NCistream& operator>>(NCistream& strm, 
			CORBA::Environment_var& obj) {
                CORBA::release(obj._ptr);
                strm >> obj._ptr;
                return strm;
        }
	_PMCEXPORT inline friend NCostream& operator<<(NCostream& strm,
			const CORBA::Environment_var& obj) {
		strm << obj._ptr;
		return strm;
	}
#if defined(_HPCC_BUG)
	_PMCEXPORT inline friend ostream& operator<<(ostream& strm,
			const CORBA::Environment_var& obj) {
		strm << *obj._ptr;
		return strm;
	}
	_PMCEXPORT inline friend istream& operator>>(istream& strm,
			CORBA::Environment_var& obj) {
		NCistream istrm(strm);
		istrm >> obj;
		return strm;
	}
#endif
			
    protected:
        CORBA::Environment_ptr     _ptr;
    private:
        void operator=(const CORBA::Environment_var& ) {}
};


#endif
