#ifndef _except_h
#define _except_h
/****************************************************************************/
/*                                                                          */
/*  ORBeline (c)   is copyrighted by PostModern Computing Technologies, Inc */
/*                                                                          */
/*  Copyright 1993, 1994 by PostModern Computing Technologies, Inc.         */
/*                          1897 Landings Drive                             */
/*                          Mountain View, California, USA                  */
/*                          Telephone (415) 967-6169                        */
/*                          Facsimile (415) 967-6212                        */
/*                                                                          */
/*  This code is the sole property of PostModern Computing Technologies,    */
/*  Inc.  and is  protected  by  copyright under the laws of the United     */
/*  States.   This  program is confidential, proprietary, and  a  trade     */
/*  secret,  not  to  be disclosed  without written authorization  from     */
/*  PostModern Computing Technologies, Inc.  Any use,  duplication,  or     */
/*  disclosure  of  this  program  by other than  PostModern  Computing     */
/*  Technologies, Inc. and its assigned licensees is strictly forbidden     */
/*  by law.                                                                 */
/*                                                                          */
/*  All rights reserved.                                                    */
/*                                                                          */
/****************************************************************************/

#include "orbtypes.h"

// SUN bug
#if defined(sun) || defined(__alpha)
#if defined(minor)
#undef minor
#endif
#endif

class _PMCEXPORT CORBA_Exception
{
    public:
	typedef CORBA::Exception *(*ExceptionFactory)();
	class _PMCEXPORT Description
	{
	    private:
		const char 		*_name;
		const char		*_id;
		ExceptionFactory	_factory;
		const Description	*_base;
	    public:
		Description(const char *name, 
			    const char *rep_id,
			    ExceptionFactory fac = 
				(ExceptionFactory)NULL,
			    const Description *base = 
				(const Description *)NULL);
		~Description();

		CORBA::Boolean can_cast(const Description& desc) const;
		const char *name() const { return _name; }
		const char *repository_id() const { return _id; }
		const ExceptionFactory factory() const { return _factory; }
		static const Description *desc(const char *rep_id);
	};

	static	const Description	_description;

	virtual ~CORBA_Exception() {}

	virtual const Description& _desc() const;
	virtual void _write(NCostream& ) const {}
	virtual void _copy(NCistream& ) {}
	virtual void _pretty_print(NCostream& strm) const {
		strm << "Exception: " << _name() <<  endl;
	}
	virtual void _throw() const {}
	virtual CORBA::Exception *_deep_copy() const { return new CORBA::Exception; }
	const char *_name() const { return _desc().name(); }
	const char *_repository_id() const { return _desc().repository_id(); }

	static CORBA::Exception *_narrow(CORBA::Exception *exc) { return exc; }

	_PMCEXPORT friend NCostream& operator<<(NCostream& strm, const CORBA::Exception& exc);
	_PMCEXPORT friend NCistream& operator>>(NCistream& strm, CORBA::Exception *& exc);
#if !defined(_PMC_NOSTDSTREAM)
	_PMCEXPORT friend ostream& operator<<(ostream& strm, const CORBA::Exception& exc);
#endif
    protected:
	CORBA_Exception() {}
};

class _PMCEXPORT CORBA_SystemException: public CORBA_Exception
{
    public:								
	static const Description	_description;

	CORBA_SystemException(CORBA::ULong minor=0, 
			      CORBA::CompletionStatus status=CORBA::COMPLETED_NO) {	
		_minor = minor;						
		_status = status;					
	}								
	virtual ~CORBA_SystemException() {}

	CORBA::ULong minor() const { return _minor;}			
	void minor(CORBA::ULong val) { _minor = val; }			
									
	CORBA::CompletionStatus completed() const { return _status; }		
	void completed(CORBA::CompletionStatus status) { _status = status; }	


	virtual const Description& _desc() const;
	virtual void _write(NCostream& strm) const;
	virtual void _copy(NCistream& strm);
	virtual void _pretty_print(NCostream& strm) const;
	virtual CORBA::Exception *_deep_copy() const {
		return new CORBA::SystemException(*this); 
	}
	virtual void _throw() const;
	static CORBA::SystemException *_narrow(CORBA::Exception *exc);

    protected:
	CORBA::ULong		_minor;					
	CORBA::CompletionStatus _status;				

};

class _PMCEXPORT CORBA_UserException: public CORBA_Exception
{
    public:
	static const Description	_description;

	CORBA_UserException() {}
	virtual ~CORBA_UserException() {}

	virtual const Description& _desc() const;
	static CORBA::UserException *_narrow(CORBA::Exception *exc);
	virtual void _throw() const {} 
	virtual CORBA::Exception *_deep_copy() const { 
		return new CORBA::UserException(*this); 
	}
};


#endif
