#ifndef _impldef_h_
#define _impldef_h_
/****************************************************************************/
/*                                                                          */
/*  Copyrighted by PostModern Computing Technologies, Inc   		    */
/*                                                                          */
/*  Copyright 1992, 1993, 1994 by PostModern Computing Technologies, Inc.   */
/*                          1897 Landings Drive				    */
/*                          Mountain View, California, USA                  */
/*                          Telephone (415) 967-6169                        */
/*                          Facsimile (415) 967-6212                        */
/*                                                                          */
/*  This code is the sole property of PostModern Computing Technologies,    */
/*  Inc.  and is  protected  by  copyright under the laws of the United     */
/*  States.   This  program is confidential, proprietary, and  a  trade     */
/*  secret,  not  to  be disclosed  without written authorization  from     */
/*  PostModern Computing Technologies, Inc.  Any use,  duplication,  or     */
/*  disclosure  of  this  program  by other than  PostModern  Computing     */
/*  Technologies, Inc. and its assigned licensees is strictly forbidden     */
/*  by law.                                                                 */
/*                                                                          */
/*  All rights reserved.                                                    */
/*                                                                          */
/*  Author: psm                                                             */
/*                                                                          */
/****************************************************************************/

#include "stexcep.h"
#include "strvar.h"
#include "oseq.h"

class _PMCEXPORT CORBA_StringSequence
{
    public:
	static char **allocbuf(CORBA::ULong nelems) {
		char **ret= new char *[nelems];
		memset(ret, 0, size_t(nelems) * sizeof(char *));
		return ret;
	}
	static void freebuf(char **data) {
		if (data) delete[] data;
	}
	static void freebuf_elems(char **data, CORBA::ULong nelem) {
		if (data) {
			for (CORBA::ULong i=0; i< nelem; i++)
				CORBA::string_free(data[i]);
			delete[] data;
		}
	}
	class _PMCEXPORT Sequence_string
	{
		friend CORBA_StringSequence;
	    private:
		CORBA::Boolean	_rel_flag;
		char **		_ptr;
		void release() {if (_rel_flag) CORBA::string_free(*_ptr);}
		Sequence_string& operator=(const Sequence_string& ) {
			return *this;
		}
		Sequence_string() :_ptr((char **)NULL), _rel_flag(0) {}
		~Sequence_string() {}
	    public:
		Sequence_string& operator=(char *p) {
			if ( *_ptr != p) {
				release();
				*_ptr = p;
			}
			return *this;
		}
		Sequence_string& operator=(const char *p) {
			if ( *_ptr != p) {
				release();
				*_ptr = CORBA::string_alloc(strlen(p));
				strcpy(*_ptr, p);
			}
			return *this;
		}
		operator const char *() const { return *_ptr; }
		operator char *() { return *_ptr; }
		char& operator[](CORBA::ULong index) {return *_ptr[index];}
		char operator[](CORBA::ULong index) const {return *_ptr[index];}
	};
	CORBA_StringSequence(CORBA::ULong max=0);
	CORBA_StringSequence(CORBA::ULong max,
			CORBA::ULong length,
			char **data,
			CORBA::Boolean release=0);
	CORBA_StringSequence(const CORBA::StringSequence&);
	~CORBA_StringSequence();
	CORBA::StringSequence& operator=(const CORBA::StringSequence&);
	CORBA::ULong maximum() const { return _num_allocated;}
	void length(CORBA::ULong);
	CORBA::ULong length() const { return _count; }
	Sequence_string& operator[](CORBA::ULong index) {
		_seqString._ptr = &_buffer[index];
		return _seqString;
	}
	const char *operator[](CORBA::ULong index) const {
		return _buffer[index];
	}
	_PMCEXPORT friend NCostream& operator<<(NCostream& strm, const CORBA::StringSequence&);
	_PMCEXPORT inline friend NCostream& operator<<(NCostream& strm, 
			const CORBA::StringSequence *obj) {
		if ( obj == (CORBA::StringSequence*)NULL)
			PMCTHROW(CORBA::BAD_PARAM());
		else
			strm << *obj;
		return strm;
	}
	_PMCEXPORT friend NCistream& operator>>(NCistream& strm, CORBA::StringSequence&);
	_PMCEXPORT inline friend NCistream& operator>>(NCistream& strm, 
			CORBA::StringSequence*& obj) {
		obj = new CORBA::StringSequence;
		strm >> *obj;
		return strm;
	}
	_PMCEXPORT friend ostream& operator<<(ostream& strm, const CORBA::StringSequence&);
	_PMCEXPORT inline friend istream& operator>>(istream& strm, CORBA::StringSequence& obj) {
		NCistream istrm(strm);
		istrm >> obj;
		return strm;
	}
	_PMCEXPORT inline friend istream& operator>>(istream& strm, 
			CORBA::StringSequence *& obj) {
		NCistream istrm(strm);
		istrm >> obj;
		return strm;
	}
	_PMCEXPORT friend CORBA::ULong hash(const CORBA::StringSequence&);
	_PMCEXPORT friend CORBA::Long compare(const CORBA::StringSequence&, 
		const CORBA::StringSequence& );
	static CORBA::StringSequence *_duplicate(CORBA::StringSequence* ptr) {
		if (ptr) ptr->_ref_count++;
		return ptr;
	}
	static void _release(CORBA::StringSequence *ptr) {
		if (ptr && ( --ptr->_ref_count == 0) )
			delete ptr;
	}
    private:
	CORBA::ULong		_count;
	char			**_buffer;
	Sequence_string		_seqString;
	CORBA::ULong		_num_allocated;
	CORBA::Long		_ref_count;
	void release_on_copy(CORBA::Boolean val) {_seqString._rel_flag = val;}
	CORBA::Boolean release_on_copy() const {return _seqString._rel_flag;}
};


class _PMCEXPORT CORBA_StringSequence_var
{
    public:
	CORBA_StringSequence_var() { _ptr = (CORBA::StringSequence *)NULL; }
	CORBA_StringSequence_var(CORBA::StringSequence *ptr) {
		_ptr = ptr;
	}
	CORBA_StringSequence_var(const CORBA::StringSequence_var& var) {
		_ptr = CORBA::StringSequence::_duplicate((CORBA::StringSequence *)var);
	}
	~CORBA_StringSequence_var() { CORBA::StringSequence::_release(_ptr); }
	CORBA::StringSequence_var& operator=(CORBA::StringSequence *ptr) {
		if (_ptr != ptr) {
			CORBA::StringSequence::_release(_ptr);
			_ptr = CORBA::StringSequence::_duplicate(ptr);
		}
		return *this;
	}
	CORBA::StringSequence_var& operator=(const CORBA::StringSequence_var& var) {
		CORBA::StringSequence::_release(_ptr);
		_ptr = CORBA::StringSequence::_duplicate((CORBA::StringSequence *)var);
		return *this;
	}
	CORBA::StringSequence *operator->() { return _ptr; }
	CORBA_StringSequence::Sequence_string& operator[](CORBA::ULong index) {
		return _ptr->operator[](index);
	}
	const char * operator[](CORBA::ULong index) const {
		return _ptr->operator[](index);
	}
	operator CORBA::StringSequence *() const { return _ptr; }
	operator const CORBA::StringSequence& () const { return *_ptr; }
	operator CORBA::StringSequence &() { return *_ptr; }
	_PMCEXPORT inline friend NCostream& operator<<(NCostream& strm, 
			const CORBA::StringSequence_var& var) {
		if ( var._ptr == (CORBA::StringSequence *)NULL) {
			PMCTHROW(CORBA::BAD_PARAM());
		}
		else
			strm << *var._ptr;
		return strm;
	}
	_PMCEXPORT inline friend NCistream& operator>>(NCistream& strm,
			CORBA::StringSequence_var& var) {
		if ( var._ptr == (CORBA::StringSequence *)NULL )
			var._ptr = new CORBA::StringSequence;
		strm >> *var._ptr;
		return strm;
	}
    private:
	CORBA::StringSequence *_ptr;
};

class _PMCEXPORT CORBA_ImplementationDef
{
    public:
	CORBA_ImplementationDef(const char *interface_name,
			const char *object_name,
			const CORBA::ReferenceData& id) : 
			_id(id) {
		_interface_name = interface_name;
		_object_name = object_name;
	}
	static CORBA::ImplementationDef_ptr _duplicate(CORBA::ImplementationDef_ptr obj) {
		if (obj)
			return obj->_copy();
		else
			return obj;
	}
	static void  _release(CORBA::ImplementationDef_ptr obj) {
		if (obj) delete obj;
	}
	static CORBA::ImplementationDef_ptr _nil() { 
			return (CORBA::ImplementationDef_ptr)NULL;
	}
	virtual CORBA::ImplementationDef_ptr _copy() { 
		return new CORBA::ImplementationDef(*this);
	}

	const char *interface_name() const { return _interface_name; }
	void interface_name(const char *val) { _interface_name = val; }

	const char *object_name() const { return _object_name; }
	void object_name(const char * val) { _object_name = val; }
	
	CORBA::ReferenceData_ptr id() const { 
		return new CORBA::ReferenceData(_id);
	}
	void id(const CORBA::ReferenceData& data) { 
		_id = data;
	}
	
	_PMCEXPORT friend NCistream& operator>>(NCistream& strm, 
			CORBA::ImplementationDef_ptr& obj);
	_PMCEXPORT friend NCostream& operator<<(NCostream& strm, 
			CORBA::ImplementationDef_ptr obj);
	
	_PMCEXPORT inline friend istream& operator>>(istream& strm, 
			CORBA::ImplementationDef_ptr& obj) {
		NCistream istrm(strm);
		istrm >> obj;
		return strm;
	}
	_PMCEXPORT friend ostream& operator<<(ostream& strm, CORBA::ImplementationDef_ptr obj); 

    private:
	static const char *_class_info;
    public:
	static const char *_desc();
	virtual const char *_type_info() const;
    protected:
	CORBA::String_var		_interface_name;
	CORBA::String_var		_object_name;
	CORBA::ReferenceData		_id;

	CORBA_ImplementationDef() {}
	CORBA_ImplementationDef(const CORBA::ImplementationDef& def) 
		: _interface_name(def._interface_name),
		_object_name(def._object_name),
		_id(def._id) {}
	void operator=(const CORBA::ImplementationDef&) {}
	virtual ~CORBA_ImplementationDef() {}

};

class _PMCEXPORT CORBA_ImplementationDef_var
{
    public:
	CORBA_ImplementationDef_var() : _ptr(CORBA::ImplementationDef::_nil()) {}
	CORBA_ImplementationDef_var(CORBA::ImplementationDef_ptr ptr) :_ptr(ptr) {}
	CORBA_ImplementationDef_var(const CORBA::ImplementationDef_var& var)
		:_ptr(CORBA::ImplementationDef::_duplicate(
			(CORBA::ImplementationDef_ptr)var)) {}
	~CORBA_ImplementationDef_var() { CORBA::release(_ptr); }
	CORBA::ImplementationDef_var& operator=(CORBA::ImplementationDef_ptr p) {
		if (_ptr != p ) {
			CORBA::release(_ptr);
			_ptr = p;
		}
		return *this;
	}
	operator CORBA::ImplementationDef_ptr() const { return _ptr; }
	CORBA::ImplementationDef_ptr operator->() const { return _ptr; }
	_PMCEXPORT inline friend NCistream& operator>>(NCistream& strm, 
				CORBA::ImplementationDef_var& obj) {
		CORBA::release(obj._ptr);
		strm >> obj._ptr;
		return strm;
	}
	_PMCEXPORT inline friend NCostream& operator<<(NCostream& strm,
			const CORBA::ImplementationDef_var& var) {
		if ( var._ptr == (CORBA::ImplementationDef *)NULL) {
			PMCTHROW(CORBA::BAD_PARAM());
		}
		else
			strm << var._ptr;
		return strm;
	}
	_PMCEXPORT inline friend istream& operator>>(istream& strm, 
			CORBA::ImplementationDef_var& obj) {
		CORBA::release(obj._ptr);
		strm >> obj._ptr;
		return strm;
	}
	_PMCEXPORT inline friend ostream& operator<<(ostream& strm,
			const CORBA::ImplementationDef_var& var) {
		if ( var._ptr == (CORBA::ImplementationDef *)NULL) {
			PMCTHROW(CORBA::BAD_PARAM());
		}
		else
			strm << var._ptr;
		return strm;
	}
    protected:
	CORBA::ImplementationDef_ptr	_ptr;
    private:
	void operator=(const CORBA::ImplementationDef_var& ) {}
};
	
_PMCEXPORT inline NCostream& operator<<(NCostream& _strm, CORBA::Policy _enum_type) {
	_strm << (CORBA::ULong)_enum_type;
	return _strm;
}
_PMCEXPORT inline NCistream& operator>>(NCistream& _strm, CORBA::Policy& _enum_type) {
	CORBA::ULong _temp;
	_strm >> _temp;
	_enum_type = CORBA::Policy(_temp);
	return _strm;
}
_PMCEXPORT inline ostream& operator<<(ostream& _strm, CORBA::Policy _enum_type) {
#if !defined(_PMC_NOSTDSTREAM)
	if( &_strm == &cout || &_strm == &cerr || &_strm == &clog) {
		_strm << "Policy:";
		switch(_enum_type) {
			case CORBA::SHARED_SERVER:
				_strm << "SHARED_SERVER" << endl;
				break;
			case CORBA::UNSHARED_SERVER:
				_strm << "UNSHARED_SERVER" << endl;
				break;
			case CORBA::SERVER_PER_METHOD:
				_strm << "SERVER_PER_METHOD" << endl;
				break;
		}
	}
	else 
#endif
		_strm << (CORBA::ULong)_enum_type;
	return _strm;
}
_PMCEXPORT inline istream& operator>>(istream& _strm, CORBA::Policy& _enum_type) {
	CORBA::ULong _temp;
	_strm >> _temp;
	_enum_type = CORBA::Policy(_temp);
	return _strm;
}

class _PMCEXPORT CORBA_CreationImplDef: public CORBA_ImplementationDef
{
    public:
	CORBA_CreationImplDef() {}
	CORBA_CreationImplDef(const char *interface_name,
			const char *object_name,
			const CORBA::ReferenceData& id,
			const char *path_name, 
			const CORBA::StringSequence& args,
			const CORBA::StringSequence& env,
			CORBA::Policy pol=CORBA::SHARED_SERVER) :
			CORBA_ImplementationDef(interface_name, object_name,id),
			_path_name(path_name),
			_args(args),
			_env(env),
			_policy(pol) {}
	~CORBA_CreationImplDef() {}


	static CORBA::CreationImplDef_ptr _duplicate(CORBA::CreationImplDef_ptr obj) {
		if (obj) return new CORBA::CreationImplDef(*obj);
		else return obj;
	}
	static void _release(CORBA::CreationImplDef_ptr obj) {
		if (obj) delete obj;
	}
	virtual CORBA::ImplementationDef_ptr _copy() { 
		return new CORBA::CreationImplDef(*this);
	}

	static CORBA::CreationImplDef_ptr _nil() { return (CORBA::CreationImplDef_ptr)NULL;}
	static CORBA::CreationImplDef_ptr _narrow(CORBA::ImplementationDef_ptr ptr);

	CORBA::Policy activation_policy() const { return _policy; }
	void activation_policy(CORBA::Policy p) { _policy = p; }
	
	const char *path_name() const {
		return _path_name;
	}
	void path_name(const char *val) { 
		_path_name = val;
	}
	
	
	CORBA::StringSequence *args() const {
		return new CORBA::StringSequence(_args);
	}
	void args(const CORBA::StringSequence& val) {
		_args = val;
	}
	
	
	CORBA::StringSequence *env() const {
		return new CORBA::StringSequence(_env);
	}
	void env(const CORBA::StringSequence& val) {
		_env = val;
	}
	
	
	_PMCEXPORT friend NCistream& operator>>(NCistream& strm, 
			CORBA::CreationImplDef_ptr& obj);
	_PMCEXPORT friend NCostream& operator<<(NCostream& strm, 
			CORBA::CreationImplDef_ptr obj);

	_PMCEXPORT inline friend istream& operator>>(istream& strm, 
				CORBA::CreationImplDef_ptr& obj) {
		NCistream istrm(strm);
		istrm >> obj;
		return strm;
	}
	_PMCEXPORT friend ostream& operator<<(ostream& strm, CORBA::CreationImplDef_ptr obj);
    private:
	static const char *_class_info;
    public:
	static const char *_desc();
	virtual const char *_type_info() const;
    protected:

	CORBA::String_var	_path_name;
	CORBA::Policy		_policy;
	CORBA::StringSequence	_args;
	CORBA::StringSequence	_env;

	CORBA_CreationImplDef(const CORBA::CreationImplDef& def) :
		CORBA_ImplementationDef(def),
		_path_name(def._path_name),
		_policy(def._policy),
		_args(def._args),
		_env(def._env) {}

	void operator=(const CORBA::CreationImplDef& ) {}
};

class _PMCEXPORT CORBA_CreationImplDef_var
{
    public:
	CORBA_CreationImplDef_var() : _ptr(CORBA::CreationImplDef::_nil()) {}
	CORBA_CreationImplDef_var(CORBA::CreationImplDef_ptr ptr) :_ptr(ptr) {}
	CORBA_CreationImplDef_var(const CORBA::CreationImplDef_var& var)
		:_ptr(CORBA::CreationImplDef::_duplicate((CORBA::CreationImplDef_ptr)var)) {}
	~CORBA_CreationImplDef_var() { CORBA::release(_ptr); }
	CORBA::CreationImplDef_var& operator=(CORBA::CreationImplDef_ptr p) {
		if (_ptr != p ) {
			CORBA::release(_ptr);
			_ptr = p;
		}
		return *this;
	}
	operator CORBA::CreationImplDef_ptr() const { return _ptr; }
	CORBA::CreationImplDef_ptr operator->() const { return _ptr; }
	_PMCEXPORT inline friend NCistream& operator>>(NCistream& strm, 
			CORBA::CreationImplDef_var& obj) {
		CORBA::release(obj._ptr);
		strm >> obj._ptr;
		return strm;
	}
	_PMCEXPORT inline friend NCostream& operator<<(NCostream& strm,
			const CORBA::CreationImplDef_var& var) {
		if ( var._ptr == (CORBA::CreationImplDef *)NULL) {
			PMCTHROW(CORBA::BAD_PARAM());
		}
		else
			strm << var._ptr;
		return strm;
	}
	_PMCEXPORT inline friend istream& operator>>(istream& strm, 
			CORBA::CreationImplDef_var& obj) {
		CORBA::release(obj._ptr);
		strm >> obj._ptr;
		return strm;
	}
	_PMCEXPORT inline friend ostream& operator<<(ostream& strm,
			const CORBA::CreationImplDef_var& var) {
		if ( var._ptr == (CORBA::CreationImplDef *)NULL) {
			PMCTHROW(CORBA::BAD_PARAM());
		}
		else
			strm << var._ptr;
		return strm;
	}
    protected:
	CORBA::CreationImplDef_ptr	_ptr;
    private:
	void operator=(const CORBA::CreationImplDef_var& ) {}
};

class _PMCEXPORT CORBA_Activator
{
    public:
	CORBA_Activator() {}
	virtual ~CORBA_Activator() {}
	static CORBA::Activator_ptr _duplicate(CORBA::Activator_ptr obj) {
		return obj;
	}
	static void 	     _release(CORBA::Activator_ptr ) {}
	static CORBA::Activator_ptr _nil() { return (CORBA::Activator_ptr)NULL;}

	virtual CORBA::Object_ptr activate(CORBA::ImplementationDef_ptr impl) = 0;
	virtual void deactivate(CORBA::Object_ptr, CORBA::ImplementationDef_ptr) {}
};

class _PMCEXPORT CORBA_ActivationImplDef: public CORBA_ImplementationDef
{
    public:
	CORBA_ActivationImplDef() {}
	CORBA_ActivationImplDef(const char *interface_name, const char *object_name,
			const CORBA::ReferenceData& id, CORBA::Activator_ptr act) :
			CORBA_ImplementationDef(interface_name, object_name, id),
			activator(act) {}

	~CORBA_ActivationImplDef() {}

	static CORBA::ActivationImplDef_ptr _duplicate(CORBA::ActivationImplDef_ptr obj) {
		if (obj ) return new CORBA::ActivationImplDef(*obj);
		else return obj;
	}
	static CORBA::ActivationImplDef_ptr _nil() { 
			return (CORBA::ActivationImplDef_ptr)NULL;
	}
	static CORBA::ActivationImplDef_ptr _narrow(CORBA::ImplementationDef_ptr ptr);

	virtual CORBA::ImplementationDef_ptr _copy() { 
		return new CORBA::ActivationImplDef(*this);
	}

	CORBA::Activator_ptr activator_obj() { return activator; }
	void activator_obj(CORBA::Activator_ptr val) { activator = val; }
    private:
	static const char *_class_info;
    public:
	static const char *_desc();
	virtual const char *_type_info() const;
    protected:

	CORBA::Activator_ptr	activator;

	CORBA_ActivationImplDef(const CORBA::ActivationImplDef& def) :
			CORBA_ImplementationDef(def) {
		activator = def.activator;
	}

	void operator=(const CORBA::ActivationImplDef& ) {}
};

class _PMCEXPORT CORBA_ActivationImplDef_var
{
    public:
	CORBA_ActivationImplDef_var() : _ptr(CORBA::ActivationImplDef::_nil()) {}
	CORBA_ActivationImplDef_var(CORBA::ActivationImplDef_ptr ptr) :_ptr(ptr) {}
	CORBA_ActivationImplDef_var(const CORBA::ActivationImplDef_var& var)
		:_ptr(CORBA::ActivationImplDef::_duplicate(
		(CORBA::ActivationImplDef_ptr)var)) {}
	~CORBA_ActivationImplDef_var() { CORBA::release(_ptr); }
	CORBA::ActivationImplDef_var& operator=(CORBA::ActivationImplDef_ptr p) {
		if (_ptr != p ) {
			CORBA::release(_ptr);
			_ptr = p;
		}
		return *this;
	}
	operator CORBA::ActivationImplDef_ptr() const { return _ptr; }
	CORBA::ActivationImplDef_ptr operator->() const { return _ptr; }
    protected:
	CORBA::ActivationImplDef_ptr	_ptr;
    private:
	void operator=(const CORBA::ActivationImplDef_var& ) {}
};


#endif

