#ifndef _mbuf_h_
#define _mbuf_h_
/****************************************************************************/
/*                                                                          */
/*  Copyrighted by PostModern Computing Technologies, Inc   		    */
/*                                                                          */
/*  Copyright 1992, 1993, 1994 by PostModern Computing Technologies, Inc.   */
/*                          1897 Landings Drive				    */
/*                          Mountain View, California, USA                  */
/*                          Telephone (415) 967-6169                        */
/*                          Facsimile (415) 967-6212                        */
/*                                                                          */
/*  This code is the sole property of PostModern Computing Technologies,    */
/*  Inc.  and is  protected  by  copyright under the laws of the United     */
/*  States.   This  program is confidential, proprietary, and  a  trade     */
/*  secret,  not  to  be disclosed  without written authorization  from     */
/*  PostModern Computing Technologies, Inc.  Any use,  duplication,  or     */
/*  disclosure  of  this  program  by other than  PostModern  Computing     */
/*  Technologies, Inc. and its assigned licensees is strictly forbidden     */
/*  by law.                                                                 */
/*                                                                          */
/*  All rights reserved.                                                    */
/*                                                                          */
/*  Author: psm                                                             */
/*                                                                          */
/****************************************************************************/

#include "stexcep.h"
#include "nctinfo.h"

// A stream buffer which allows IDL types (structures, unions arrays etc)
// to be written to a buffer

class _PMCEXPORT CORBA_MarshalInBuffer: public NCistream
{
    public:
	CORBA_MarshalInBuffer(char *read_buffer, CORBA::ULong length, 
			CORBA::Boolean release_flag=0, 
			CORBA::Boolean byte_order= CORBA::ByteOrder) :
			_buffer(read_buffer),
			_len(length),
			_release_flag(release_flag),
			_cur_off(0),
			_start_offset(0) {
		byteOrder(byte_order);
	}
	~CORBA_MarshalInBuffer() {
		if ( _release_flag && _buffer)
			CORBA::string_free(_buffer);
	}
	void release_flag(CORBA::Boolean val) { _release_flag = val; }
	CORBA::Boolean release_flag() const { return _release_flag; }
	CORBA::ULong seekpos(CORBA::ULong pos) {
		if ( pos > _len )
			PMCTHROW(CORBA::BAD_PARAM());
		else
			_cur_off = pos;
		return _cur_off;
	}
	CORBA::ULong curoff() const { return _cur_off; }

	void rewind() {
		seekpos(0);
	}

	NCistream& operator>>(char*&);
	NCistream& operator>>(char&);
#if !defined(CRAY)
	NCistream& operator>>(unsigned char&);
#endif
	NCistream& operator>>(short&);
	NCistream& operator>>(unsigned short&);
	NCistream& operator>>(int&);
	NCistream& operator>>(unsigned int&);
	NCistream& operator>>(long&);
	NCistream& operator>>(unsigned long&);
	NCistream& operator>>(float&);
	NCistream& operator>>(double&);

#if defined(sun)
	NCistream& operator>>(long long&);
	NCistream& operator>>(unsigned long long&);
	NCistream& operator>>(long double&);
#endif

	int get();
	NCistream& get(char&);
#if !defined(CRAY)
	NCistream& get(unsigned char&);
#endif
	NCistream& get(char*, unsigned size);
#if !defined(CRAY)
	NCistream& get(unsigned char*, unsigned size);
#endif
	NCistream& get(short*, unsigned size);
	NCistream& get(unsigned short*, unsigned size);
	NCistream& get(int*, unsigned size);
	NCistream& get(unsigned int*, unsigned size);
	NCistream& get(long*, unsigned size);
	NCistream& get(unsigned long*, unsigned size);
	NCistream& get(float*, unsigned size);
	NCistream& get(double*, unsigned size);
	NCistream& getCString(char*, unsigned maxlen);

	const char *getString();
#if defined(sun)
	NCistream& get(long long *, unsigned size);
	NCistream& get(unsigned long long *, unsigned size);
	NCistream& get(long double *, unsigned size);
#endif
	void	byteOrder(CORBA::Boolean val) {
			_byte_order = (val == 0) ? 0 : 1;
	}
	CORBA::Boolean byteOrder() const { return _byte_order; }

	void	new_encapsulation() { _start_offset = 0; }
    private:
	CORBA_MarshalInBuffer(const CORBA::MarshalInBuffer& ) {}
	void operator=(const CORBA::MarshalInBuffer& ) {}

	void underflow(CORBA::ULong size);

	char	*_buffer;
	CORBA::ULong	_len;
	CORBA::ULong	_cur_off;
	CORBA::ULong	_start_offset;
	CORBA::Boolean _release_flag;
	CORBA::Boolean	_byte_order;
};

class _PMCEXPORT CORBA_MarshalOutBuffer: public NCostream
{
    public:
	CORBA_MarshalOutBuffer(CORBA::ULong initial_size =255, CORBA::Boolean release_flag=0) 
			: _buffer(CORBA::string_alloc(255)),
			_release_flag(release_flag),
			_len(initial_size),
			_cur_off(0),
			_start_offset(0) {}
	~CORBA_MarshalOutBuffer() {
		if ( _buffer && _release_flag)
			CORBA::string_free(_buffer);
	}
	void release_flag(CORBA::Boolean val) { _release_flag = val; }
	CORBA::Boolean release_flag() const { return _release_flag; }
	char *buffer()  const { return _buffer; }

	CORBA::ULong seekpos(CORBA::ULong pos) {
		if ( pos > _len )
			PMCTHROW(CORBA::BAD_PARAM());
		else
			_cur_off = pos;
		return _cur_off;
	}
	CORBA::ULong curoff() const { return _cur_off; }
	void rewind() {
		seekpos(0);
	}

	NCostream& operator<<(const char*);
	NCostream& operator<<(char);
#if !defined(CRAY)
	NCostream& operator<<(unsigned char);
#endif
	NCostream& operator<<(short);
	NCostream& operator<<(unsigned short);
	NCostream& operator<<(int);
	NCostream& operator<<(unsigned);
	NCostream& operator<<(long);
	NCostream& operator<<(unsigned long);
	NCostream& operator<<(float);
	NCostream& operator<<(double);
        NCostream& operator<<(const NCTransObject* obj) {
                return NCostream::operator<<(obj);
        }
        NCostream& operator<<(const NCTransObject& obj) {
                return NCostream::operator<<(obj);
        }

#if defined(sun)
	NCostream& operator<<(long long);
	NCostream& operator<<(unsigned long long);
	NCostream& operator<<(long double);
#endif

	NCostream& put(char);
	NCostream& put(const char* val, unsigned size);
#if !defined(CRAY)
	NCostream& put(const unsigned char* val, unsigned size);
#endif
	NCostream& put(const short* val, unsigned size);
	NCostream& put(const unsigned short* val, unsigned size);
	NCostream& put(const int* val, unsigned size);
	NCostream& put(const unsigned int* val, unsigned size);
	NCostream& put(const long* val, unsigned size);
	NCostream& put(const unsigned long* val, unsigned size);
	NCostream& put(const float* val, unsigned size);
	NCostream& put(const double* val, unsigned size);
	NCostream& putCString(const char*);

#if defined(sun)
	NCostream& put(const long long* val, unsigned size);
	NCostream& put(const unsigned long long* val, unsigned size);
	NCostream& put(const long double* val, unsigned size);
#endif
	void	new_encapsulation() { _start_offset = 0; }
	void  	write(NCostream& strm, CORBA::TypeCode_ptr tc);
	static 	CORBA::MarshalOutBuffer *_nil() { return (CORBA::MarshalOutBuffer *)NULL; }
    private:

	CORBA_MarshalOutBuffer(const CORBA::MarshalOutBuffer& ) {}
	void operator=(const CORBA::MarshalOutBuffer& ) {}

	char	*_buffer;
	CORBA::ULong	_len;
	CORBA::ULong	_cur_off;
	CORBA::ULong	_start_offset;
	CORBA::Boolean _release_flag;
};

#endif
