#ifndef _nameval_h_
#define _nameval_h_
/****************************************************************************/
/*                                                                          */
/*  Copyrighted by PostModern Computing Technologies, Inc   		    */
/*                                                                          */
/*  Copyright 1992, 1993, 1994 by PostModern Computing Technologies, Inc.   */
/*                          1897 Landings Drive				    */
/*                          Mountain View, California, USA                  */
/*                          Telephone (415) 967-6169                        */
/*                          Facsimile (415) 967-6212                        */
/*                                                                          */
/*  This code is the sole property of PostModern Computing Technologies,    */
/*  Inc.  and is  protected  by  copyright under the laws of the United     */
/*  States.   This  program is confidential, proprietary, and  a  trade     */
/*  secret,  not  to  be disclosed  without written authorization  from     */
/*  PostModern Computing Technologies, Inc.  Any use,  duplication,  or     */
/*  disclosure  of  this  program  by other than  PostModern  Computing     */
/*  Technologies, Inc. and its assigned licensees is strictly forbidden     */
/*  by law.                                                                 */
/*                                                                          */
/*  All rights reserved.                                                    */
/*                                                                          */
/*  Author: psm                                                             */
/*                                                                          */
/****************************************************************************/

// Named Value and Name value list classes conforming to C++ mapping
// as specified in OMG document 94-9-14, Page 99
// However the spec seems contradictory. On page 67 (4.2 5) it is stated that
// psuedo objects should have the same parameters passing rules as
// regular Objects. But the C++ mapping for NamedValue "name" does not
// conform to this. So name is an exception to the rule.

#include "any.h"

class _PMCEXPORT CORBA_NamedValue
{
	friend CORBA_NVList;
	friend CORBA_Request;
    public:
	
	// Exception to rule 4.2.5
	const char *name() const { return _name; }

	// User should release Any (CORBA::release) to conform to the
	// argument passing rules in 4.2.5 (page 67)
	CORBA::Any *value() const { return CORBA::Any::_duplicate((CORBA::Any *)_value); }
	CORBA::Flags	flags() const { return _flags; }

	static CORBA::NamedValue_ptr _duplicate(CORBA::NamedValue_ptr nv) {
		if ( nv)
			nv->_ref_count++;
		return nv;
	}
	static CORBA::NamedValue_ptr _nil() { return (CORBA::NamedValue_ptr)NULL; }

	static void _release(CORBA::NamedValue_ptr ptr) {
		if ( ptr && --ptr->_ref_count <= 0)
			delete ptr;
	}

	_PMCEXPORT friend NCostream& operator<<(NCostream& strm, const CORBA::NamedValue&);
	_PMCEXPORT friend NCistream& operator>>(NCistream& strm, CORBA::NamedValue&);
	_PMCEXPORT inline friend NCistream& operator>>(NCistream& strm, CORBA::NamedValue *&nv) {
		nv = new CORBA::NamedValue;
		strm >> *nv;
		return strm;
	}
	_PMCEXPORT friend ostream& operator<<(ostream&, const CORBA::NamedValue&);
	_PMCEXPORT inline friend istream& operator>>(istream& strm, CORBA::NamedValue& nv) {
		NCistream istrm(strm);
		istrm >> nv;
		return strm;
	}
	_PMCEXPORT inline friend istream& operator>>(istream& strm, CORBA::NamedValue *& nv) {
		NCistream istrm(strm);
		istrm >> nv;
		return strm;
	}
    private:
	CORBA_NamedValue();
	~CORBA_NamedValue();
	CORBA_NamedValue(const CORBA_NamedValue& ) {}
	CORBA::NamedValue& operator=(const CORBA::NamedValue&);

	CORBA::String_var	_name;
	CORBA::Any_var		_value;
	CORBA::Flags		_flags;
	CORBA::Long		_ref_count;
};

class _PMCEXPORT CORBA_NamedValue_var
{
    public:
        CORBA_NamedValue_var() { _ptr = CORBA::NamedValue::_nil(); }
        CORBA_NamedValue_var(CORBA::NamedValue_ptr ptr) { _ptr = ptr; }
        CORBA_NamedValue_var(const CORBA::NamedValue_var& var) {
                 _ptr = CORBA::NamedValue::_duplicate(var._ptr);
        }
        ~CORBA_NamedValue_var() { CORBA::NamedValue::_release(_ptr); }
        CORBA::NamedValue_var& operator=(CORBA::NamedValue_ptr p) {
                 if (p != _ptr)
                        reset(p);
                return *this;
        }
        operator CORBA::NamedValue_ptr() const { return _ptr; }
#if defined(_HPCC_BUG)
	operator CORBA::NamedValue*& () { return _ptr; }
#else
	operator CORBA::NamedValue_ptr& () { return _ptr; }
#endif
        CORBA::NamedValue_ptr operator->() const { return _ptr; }
    private:
        CORBA::NamedValue_ptr     _ptr;
        void reset(CORBA::NamedValue_ptr p) {
                CORBA::NamedValue::_release(_ptr);
                _ptr = p;
        }
        void operator=(const CORBA::NamedValue_var&) {}
};


class _PMCEXPORT CORBA_NVList
{
	friend CORBA_Request;
    public:
	class _PMCEXPORT Bounds: public CORBA_UserException
	{
	    public:
		static const Description	_description;

		Bounds() {} 
		~Bounds() {}
		static CORBA::Exception *_factory() { return new Bounds; }
		virtual const Description& _desc() const;
		static Bounds *_narrow(CORBA::Exception *exc);
		CORBA::Exception *_deep_copy() const { return new Bounds(*this); }
		void _throw() const;
	};
	CORBA::Long count() const { return _count; }

	// User should release CORBA::NamedValue_ptr return arguments to conform
	// to section 4.2.5 (page 67)
	CORBA::NamedValue_ptr add(CORBA::Flags);
	CORBA::NamedValue_ptr add_item(const char *name, CORBA::Flags flags);
	CORBA::NamedValue_ptr add_value(const char *name, const CORBA::Any& any, CORBA::Flags flags);
	CORBA::NamedValue_ptr item(CORBA::Long index ) const PMCTHROW_SPEC((Bounds));
	CORBA::Status remove(CORBA::Long index) PMCTHROW_SPEC((Bounds));
	CORBA::Status free_out_memory();

	static CORBA::NVList_ptr _duplicate(CORBA::NVList_ptr ptr) {
		if ( ptr)
			ptr->_ref_count++;
		return ptr;
	}
	static CORBA::NVList_ptr _nil() { return (CORBA::NVList_ptr)NULL; }
	static void _release(CORBA::NVList_ptr ptr) {
		if ( ptr && --ptr->_ref_count <= 0)
			delete ptr;
	}

	CORBA_NVList(CORBA::ULong initial_size=16);
	~CORBA_NVList();

	_PMCEXPORT friend NCostream& operator<<(NCostream& strm, const CORBA::NVList&);
	_PMCEXPORT friend NCistream& operator>>(NCistream& strm, CORBA::NVList&);
	_PMCEXPORT inline friend NCistream& operator>>(NCistream& strm, CORBA::NVList *&nv) {
		nv = new CORBA::NVList;
		strm >> *nv;
		return strm;
	}
	_PMCEXPORT friend ostream& operator<<(ostream&, const CORBA::NVList&);
	_PMCEXPORT inline friend istream& operator>>(istream& strm, CORBA::NVList& nv) {
		NCistream istrm(strm);
		istrm >> nv;
		return strm;
	}
	_PMCEXPORT inline friend istream& operator>>(istream& strm, CORBA::NVList *& nv) {
		NCistream istrm(strm);
		istrm >> nv;
		return strm;
	}

    private:
	CORBA_NVList(const CORBA::NVList& );
	CORBA::NVList& operator=(const CORBA::NVList& );


	void resize();

	CORBA::NamedValue_ptr	*_contents;
	CORBA::ULong		_count;
	CORBA::ULong		_capacity;
	CORBA::Long		_ref_count;
};

class _PMCEXPORT CORBA_NVList_var
{
    public:
        CORBA_NVList_var() { _ptr = CORBA::NVList::_nil(); }
        CORBA_NVList_var(CORBA::NVList_ptr ptr) { _ptr = ptr; }
        CORBA_NVList_var(const CORBA::NVList_var& var) {
                 _ptr = CORBA::NVList::_duplicate(var._ptr);
        }
        ~CORBA_NVList_var() { CORBA::NVList::_release(_ptr); }
        CORBA::NVList_var& operator=(CORBA::NVList_ptr p) {
                 if (p != _ptr)
                        reset(p);
                return *this;
        }
        operator CORBA::NVList_ptr() const { return _ptr; }
#if defined(_HPCC_BUG)
	operator CORBA::NVList*& () { return _ptr; }
#else
	operator CORBA::NVList_ptr& () { return _ptr; }
#endif
        CORBA::NVList_ptr operator->() const { return _ptr; }
    private:
        CORBA::NVList_ptr     _ptr;
        void reset(CORBA::NVList_ptr p) {
                CORBA::NVList::_release(_ptr);
                _ptr = p;
        }
        void operator=(const CORBA::NVList_var&) {}
};



#endif
