// "@(#)Module Name: ncobject.h Version:2.2 Date: 94/06/19"
#ifndef _ncobject_h
#define _ncobject_h
/****************************************************************************/
/*                                                                          */
/*  ORBeline (c)   is copyrighted by PostModern Computing Technologies, Inc */
/*                                                                          */
/*  Copyright 1993, 1994 by PostModern Computing Technologies, Inc.         */
/*                          1897 Landings Drive                             */
/*                          Mountain View, California, USA                  */
/*                          Telephone (415) 967-6169                        */
/*                          Facsimile (415) 967-6212                        */
/*                                                                          */
/*  This code is the sole property of PostModern Computing Technologies,    */
/*  Inc.  and is  protected  by  copyright under the laws of the United     */
/*  States.   This  program is confidential, proprietary, and  a  trade     */
/*  secret,  not  to  be disclosed  without written authorization  from     */
/*  PostModern Computing Technologies, Inc.  Any use,  duplication,  or     */
/*  disclosure  of  this  program  by other than  PostModern  Computing     */
/*  Technologies, Inc. and its assigned licensees is strictly forbidden     */
/*  by law.                                                                 */
/*                                                                          */
/*  All rights reserved.                                                    */
/*                                                                          */
/****************************************************************************/
#include <nctranso.h>


// -------------------------------------------------------------------------
// Base class for all collection classes. Classes derived from NCObject
// class can be transported (written or constructed from Netclasses I/O
// streams) or inserted into container classes.
// -------------------------------------------------------------------------

class _PMCEXPORT NCObject: public NCTransObject
{
    private:
#ifdef PSOS
	static	NCTypeInfo		class_info;
#else
	static	const NCTypeInfo		class_info;
#endif
    protected:
	NCObject();
    public:
	virtual ~NCObject() {}
	static const NCTypeInfo *desc();
	// The following functions are used for Object I/O
	NCObject(NCistream& strm);
	inline friend NCistream& operator>>(NCistream& strm, NCObject*& obj) {
			obj = (NCObject *)strm.readTransObj();
			return strm;
	}
	static NCObject *readFrom(NCistream& strm) {
		return (NCObject *)strm.readTransObj();
	}
	virtual const NCTypeInfo *classInfo() const;

	// The following functions are used by container classes
	virtual unsigned hash() const = 0;
	virtual int compare(const NCObject& ) const =0;


	// Functions used by containers, but may be specialized by
	// derived classes.
	virtual NCbool isEqual(const NCObject& p) const {
		return ( (classInfo() == p.classInfo()) && compare(p) == 0 );
	}
	virtual NCbool isSame(const NCObject& p) const {
		return ( this == &p );
	}
	const char *className() const { 
		return classInfo()->className();
	}
	NCbool isMemberOf(const NCTypeInfo& info) const {
		return (classInfo() == &info);
	}
	NCbool isMemberOf(const NCObject& p) const {
		return (classInfo() == p.classInfo() );
	}
	NCbool isKindOf(const NCTypeInfo& p) const {
		return ( classInfo()->hasBase(p));
	}

	NCbool isKindOf(const NCTypeInfo *p) const {
		return ( classInfo()->hasBase(*p));
	}
	virtual NCbool operator==(const NCObject& p) const {
		return isEqual(p);
	}
	virtual NCbool operator!=(const NCObject& p) const {
		return (!isEqual(p) );
	}
};

#include <ncomacro.h>
#endif
