#ifndef _object_h_
#define _object_h_
/****************************************************************************/
/*                                                                          */
/*  Copyrighted by PostModern Computing Technologies, Inc   		    */
/*                                                                          */
/*  Copyright 1992, 1993, 1994 by PostModern Computing Technologies, Inc.   */
/*                          1897 Landings Drive				    */
/*                          Mountain View, California, USA                  */
/*                          Telephone (415) 967-6169                        */
/*                          Facsimile (415) 967-6212                        */
/*                                                                          */
/*  This code is the sole property of PostModern Computing Technologies,    */
/*  Inc.  and is  protected  by  copyright under the laws of the United     */
/*  States.   This  program is confidential, proprietary, and  a  trade     */
/*  secret,  not  to  be disclosed  without written authorization  from     */
/*  PostModern Computing Technologies, Inc.  Any use,  duplication,  or     */
/*  disclosure  of  this  program  by other than  PostModern  Computing     */
/*  Technologies, Inc. and its assigned licensees is strictly forbidden     */
/*  by law.                                                                 */
/*                                                                          */
/*  All rights reserved.                                                    */
/*                                                                          */
/*  Author: psm                                                             */
/*                                                                          */
/****************************************************************************/

#include "bopt.h"
#include "typeinfo.h"

class _PMCEXPORT CORBA_Object
{
	friend CORBA_ORB;
	friend CORBA_Request;
    public:
	// The following functions conform to the C++ mapping as 
	// specfied in OMG document 94-9-14, Page 78
	static CORBA::Object_ptr	_duplicate(CORBA::Object_ptr obj);
	static CORBA::Object_ptr	_nil() { return (CORBA::Object_ptr)NULL;}

	CORBA::ImplementationDef_ptr	_get_implementation();
	CORBA::Request_ptr	_request(const char* operation);
	CORBA::Status		_create_request(
					CORBA::Context_ptr ctx,
					const char *operation,
					CORBA::NVList_ptr arg_list,
					CORBA::NamedValue_ptr result,
					CORBA::Request_ptr& request,
					CORBA::Flags req_flags);
#if 0
	CORBA::InterfaceDef_ptr	_get_interface();
#endif
	// Extensions  specified by Document 94.9.32, page 100
	// NOTE: There are no underscores in the document. (_is_a, _hash ..)
	// 	The underscores are added just like other methods have
	//	underscores as per C++ mapping spec (Doc 94-9-14)
	CORBA::Boolean		_is_a(const char *logical_type_id) ;
	CORBA::ULong		_hash(CORBA::ULong maximum) ;
	CORBA::Boolean		_is_equivalent(CORBA::Object_ptr other_object);
	CORBA::Boolean		_non_existent();

	// PostModern extensions 

	void			_release();
	CORBA::Long		_ref_count() const;

	const char		*_object_name() const;
	const char		*_interface_name() const;
	
	CORBA::BOA_ptr		_boa() const;

	CORBA::Boolean		_is_local() const;
	CORBA::Boolean		_is_remote() const { return !_is_local(); }
	CORBA::Boolean		_is_bound() const;
	CORBA::Boolean		_is_persistent() const;


	const CORBA::Principal_ptr _principal() const;
	void			_principal(const CORBA::Principal& );

	static const CORBA::Principal_ptr _default_principal();
	static void		_default_principal(const CORBA::Principal& );

        const CORBA::BindOptions* _bind_options() const;
	void			_bind_options(const CORBA::BindOptions& opt);
        static const CORBA::BindOptions *_default_bind_options();
        static void             _default_bind_options(const CORBA::BindOptions& );

	PMCObjectImpl		*_object_impl() { return _impl; }
	const PMCObjectImpl	*_object_impl() const { return _impl; }

	
	// Functions to support narrowing and transporting
	static const CORBA::TypeInfo *_desc();
	virtual const CORBA::TypeInfo *_type_info() const {
			return _desc();
	}
	const char 	*_repository_id() const;

	virtual void *_safe_narrow(const CORBA::TypeInfo& desc) const;

	virtual void		_prepare_reply(void *priv_data);

	static CORBA::Object_ptr _read(NCistream& strm, 
					const CORBA::TypeInfo *expected_type);
	static CORBA::Object_ptr _clone(CORBA::Object_ptr obj);
    private:
	static const 	CORBA::TypeInfo _class_info;
	PMCObjectImpl		*_impl;
	static CORBA::Object *_factory();
    protected:
	CORBA_Object(const CORBA::Object& ) {}
	CORBA_Object(NCistream& strm);
	void operator=(const CORBA::Object& ) {}
	virtual	~CORBA_Object();

#if defined(__GNUG__) && defined(__GCCBUG__)	// Fix GCC bug
    public:
#endif

	CORBA_Object(const char *object_name = (const char *)NULL, 
				CORBA::Boolean is_stub=0);

	void			_object_name(const char *name);
	void			_ref();

	// For Database Adapter
	virtual void		_service(const char *service_name, 
					const CORBA::ReferenceData& id);


	//	Function used by STUBS
	void			_bind(const char *interface_name,
					const char *object_name,
					const char *host_name,
					const CORBA::BindOptions *options); 

	virtual CORBA::MarshalStream	*_create_request(
					const char *operation_name,
					CORBA::Boolean response_expected,
					unsigned hval=0);


	virtual void		_send();

	virtual CORBA::MarshalStream	*_invoke();

	static CORBA::Object_ptr	_implementation(
					const char *interface_name,
					const char *object_name,
					const char *host_name);
	static CORBA::Object_ptr	__clone(CORBA::Object_ptr);

    public:
	// Useful operator/ functions
	_PMCEXPORT friend NCostream& operator<<(NCostream&, const CORBA::Object_ptr);
	_PMCEXPORT friend NCistream& operator>>(NCistream&, CORBA::Object_ptr& );
	_PMCEXPORT friend ostream& operator<<(ostream&, const CORBA::Object_ptr);
	_PMCEXPORT friend CORBA::ULong hash(const CORBA::Object_ptr);
	_PMCEXPORT friend CORBA::Long compare(const CORBA::Object_ptr, const CORBA::Object_ptr);
	_PMCEXPORT friend void operator<<=(CORBA::Any&, const CORBA::Object_ptr);
	_PMCEXPORT friend CORBA::Boolean operator>>=(const CORBA::Any&, CORBA::Object_ptr& );
};

class _PMCEXPORT CORBA_Object_var
{
    public:
        CORBA_Object_var() : _ptr(CORBA::Object::_nil()) {}
        CORBA_Object_var(CORBA::Object_ptr ptr) :_ptr(ptr) {}
        CORBA_Object_var(const CORBA::Object_var& var)
                :_ptr(CORBA::Object::_duplicate((CORBA::Object_ptr)var)) {}
        ~CORBA_Object_var() { CORBA::release(_ptr); }
        CORBA::Object_var& operator=(CORBA::Object_ptr p) {
                if (_ptr != p ) {
                        CORBA::release(_ptr);
                        _ptr = p;
                }
                return *this;
        }
        operator CORBA::Object_ptr() const { return _ptr; }
#if defined(_HPCC_BUG)
        operator CORBA::Object*& () { return _ptr; }
#else
        operator CORBA::Object_ptr& () { return _ptr; }
#endif
        CORBA::Object_ptr operator->() const { return _ptr; }
        _PMCEXPORT inline friend NCistream& operator>>(NCistream& strm, 
			CORBA::Object_var& obj) {
                CORBA::release(obj._ptr);
                strm >> obj._ptr;
                return strm;
        }
#if !defined(_HPCC_BUG)
	_PMCEXPORT inline friend NCostream& operator<<(NCostream& strm,
			const CORBA::Object_var& obj) {
		strm << obj._ptr;
		return strm;
	}
	_PMCEXPORT inline friend ostream& operator<<(ostream& strm,
			const CORBA::Object_var& obj) {
		strm << obj._ptr;
		return strm;
	}
	_PMCEXPORT inline friend istream& operator>>(istream& strm,
			CORBA::Object_var& obj) {
		NCistream istrm(strm);
		istrm >> obj;
		return strm;
	}
#endif
			
    protected:
        CORBA::Object_ptr      _ptr;
    private:
        void operator=(const CORBA::Object_var& ) {}
};

#endif
	
