#ifndef _orb_h_
#define _orb_h_
/****************************************************************************/
/*                                                                          */
/*  Copyrighted by PostModern Computing Technologies, Inc   		    */
/*                                                                          */
/*  Copyright 1992, 1993, 1994 by PostModern Computing Technologies, Inc.   */
/*                          1897 Landings Drive				    */
/*                          Mountain View, California, USA                  */
/*                          Telephone (415) 967-6169                        */
/*                          Facsimile (415) 967-6212                        */
/*                                                                          */
/*  This code is the sole property of PostModern Computing Technologies,    */
/*  Inc.  and is  protected  by  copyright under the laws of the United     */
/*  States.   This  program is confidential, proprietary, and  a  trade     */
/*  secret,  not  to  be disclosed  without written authorization  from     */
/*  PostModern Computing Technologies, Inc.  Any use,  duplication,  or     */
/*  disclosure  of  this  program  by other than  PostModern  Computing     */
/*  Technologies, Inc. and its assigned licensees is strictly forbidden     */
/*  by law.                                                                 */
/*                                                                          */
/*  All rights reserved.                                                    */
/*                                                                          */
/*  Author: psm                                                             */
/*                                                                          */
/****************************************************************************/

#include "typecode.h"

// ORB class conforming to C++ language mapping as specified in
// OMG Document 94-9-14, Page 102

class _PMCEXPORT CORBA_ORB
{
    public:

	// Initialization routines for BOA and ORB. Conforms to OMG doc 94-10-24
	CORBA::BOA_ptr BOA_init(int& argc, char *const *argv,
			const char *boa_identifier= (char *)NULL);
	typedef char *ObjectId;
	class _PMCEXPORT ObjectIdList
	{
	    public:
		static char **allocbuf(CORBA::ULong nelems) {
			char **ret= new char *[nelems];
			memset(ret, 0, size_t(nelems) * sizeof(char *));
			return ret;
		}
		static void freebuf(char **data) {
			if (data) delete[] data;
		}
		static void freebuf_elems(char **data, CORBA::ULong nelem) {
			if (data) {
				for (CORBA::ULong i=0; i< nelem; i++)
					CORBA::string_free(data[i]);
				delete[] data;
			}
		}
		class _PMCEXPORT Sequence_string
		{
			friend ObjectIdList;
		    private:
			CORBA::Boolean	_rel_flag;
			char **		_ptr;
			void release() {
				if (_rel_flag) 
					CORBA::string_free(*_ptr);
			}
			Sequence_string& operator=(const Sequence_string& ) {
				return *this;
			}
			Sequence_string() :_ptr((char **)NULL), _rel_flag(0) {}
			~Sequence_string() {}
		    public:
			Sequence_string& operator=(char *p) {
				if ( *_ptr != p) {
					release();
					*_ptr = p;
				}
				return *this;
			}
			Sequence_string& operator=(const char *p) {
				if ( *_ptr != p) {
					release();
					*_ptr = CORBA::string_alloc(strlen(p));
					strcpy(*_ptr, p);
				}
				return *this;
			}
			operator const char *() const { return *_ptr; }
			operator char *() { return *_ptr; }
			char& operator[](CORBA::ULong index) {
				return *_ptr[index];
			}
			char operator[](CORBA::ULong index) const {
				return *_ptr[index];
			}
		};
		ObjectIdList(CORBA::ULong max=0);
		ObjectIdList(CORBA::ULong max,
				CORBA::ULong length,
				char **data,
				CORBA::Boolean release=0);
		ObjectIdList(const ObjectIdList&);
		~ObjectIdList();
		ObjectIdList& operator=(const ObjectIdList&);
		CORBA::ULong maximum() const { return _num_allocated;}
		void length(CORBA::ULong);
		CORBA::ULong length() const { return _count; }
		Sequence_string& operator[](CORBA::ULong index) {
			_seqString._ptr = &_buffer[index];
			return _seqString;
		}
		const char *operator[](CORBA::ULong index) const {
			return _buffer[index];
		}
		friend NCostream& operator<<(NCostream& strm, 
				const ObjectIdList&);
		inline friend NCostream& operator<<(NCostream& strm, 
				const ObjectIdList *obj) {
			if ( obj == (ObjectIdList*)NULL)
				PMCTHROW(CORBA::BAD_PARAM());
			else
				strm << *obj;
			return strm;
		}
		friend NCistream& operator>>(NCistream& strm, ObjectIdList&);
		inline friend NCistream& operator>>(NCistream& strm, 
				ObjectIdList*& obj) {
			obj = new ObjectIdList;
			strm >> *obj;
			return strm;
		}
		friend ostream& operator<<(ostream& strm, const ObjectIdList&);
		inline friend istream& operator>>(istream& strm, 
				ObjectIdList& obj) {
			NCistream istrm(strm);
			istrm >> obj;
			return strm;
		}
		inline friend istream& operator>>(istream& strm, 
				ObjectIdList *& obj) {
			NCistream istrm(strm);
			istrm >> obj;
			return strm;
		}
		static ObjectIdList *_duplicate(ObjectIdList* ptr) {
			if (ptr) ptr->_ref_count++;
			return ptr;
		}
		static void _release(ObjectIdList *ptr) {
			if (ptr && ( --ptr->_ref_count == 0) )
				delete ptr;
		}
	    private:
		CORBA::ULong		_count;
		char			**_buffer;
		Sequence_string		_seqString;
		CORBA::ULong		_num_allocated;
		CORBA::Long		_ref_count;
		void release_on_copy(CORBA::Boolean val) {
			_seqString._rel_flag = val;
		}
		CORBA::Boolean release_on_copy() const {
			return _seqString._rel_flag;
		}
	};
	
	class _PMCEXPORT ObjectIdList_var
	{
	    public:
		ObjectIdList_var() { _ptr = (ObjectIdList *)NULL; }
		ObjectIdList_var(ObjectIdList *ptr) {
			_ptr = ptr;
		}
		ObjectIdList_var(const ObjectIdList_var& var) {
			_ptr = ObjectIdList::_duplicate((ObjectIdList *)var);
		}
		~ObjectIdList_var() { ObjectIdList::_release(_ptr); }
		ObjectIdList_var& operator=(ObjectIdList *ptr) {
			if (_ptr != ptr) {
				ObjectIdList::_release(_ptr);
				_ptr = ptr;
			}
			return *this;
		}
		ObjectIdList_var& operator=(const ObjectIdList_var& var) {
			ObjectIdList::_release(_ptr);
			_ptr = ObjectIdList::_duplicate((ObjectIdList *)var);
			return *this;
		}
		ObjectIdList *operator->() { return _ptr; }
		ObjectIdList::Sequence_string& operator[](CORBA::ULong index) {
			return _ptr->operator[](index);
		}
		const char * operator[](CORBA::ULong index) const {
			return _ptr->operator[](index);
		}
		operator ObjectIdList *() const { return _ptr; }
		operator const ObjectIdList& () const { return *_ptr; }
		operator ObjectIdList &() { return *_ptr; }
		inline friend NCostream& operator<<(NCostream& strm, 
				const ObjectIdList_var& var) {
			if ( var._ptr == (ObjectIdList *)NULL) {
				PMCTHROW(CORBA::BAD_PARAM());
			}
			else
				strm << *var._ptr;
			return strm;
		}
		inline friend NCistream& operator>>(NCistream& strm,
				ObjectIdList_var& var) {
			if ( var._ptr == (ObjectIdList *)NULL )
				var._ptr = new ObjectIdList;
			strm >> *var._ptr;
			return strm;
		}
	    private:
		ObjectIdList *_ptr;
	};

	class _PMCEXPORT InvalidName { };		// Exception class
	ObjectIdList *list_initial_services();
	CORBA::Object_ptr resolve_initial_references(const char *identifier)
			PMCTHROW_SPEC((InvalidName,
				       CORBA::SystemException));



	char			*object_to_string(CORBA::Object_ptr);
	CORBA::Object_ptr 	string_to_object(const char *);
	CORBA::Object_ptr	bind(const char *interface_name,
					const char *object_name =NULL,
					const char *host_name = NULL,
					const CORBA::BindOptions *opt=NULL);


	CORBA::Status		create_environment(CORBA::Environment_ptr&);

	// DII routines
	CORBA::Status		create_list(CORBA::Long, CORBA::NVList_ptr&);
	CORBA::Status		get_default_context(CORBA::Context_ptr&);
	CORBA::Status		send_multiple_requests_oneway(const CORBA::RequestSeq& );
	CORBA::Status		send_multiple_requests_deferred(const CORBA::RequestSeq&);
	CORBA::Boolean		poll_next_response();
	CORBA::Status		get_next_response(CORBA::Request*&);
#if 0	// Unimplemented DII/IR routine
	CORBA::Status		create_operation_list(CORBA::OperationDef_ptr, CORBA::NVList&);
#endif

	
	static CORBA::ORB_ptr	_duplicate(CORBA::ORB_ptr ptr) { return ptr; }
	static CORBA::ORB_ptr	_nil() { return (CORBA::ORB_ptr)NULL; }


	// Support for generating TypeCodes
	// Compliant with Interface Repository Document (OMG doc 94-11-7)
	static CORBA::TypeCode_ptr   	create_struct_tc(
				const char *repository_id,
				const char *type_name,
				const CORBA::StructMemberSeq& members) {
			return new CORBA::TypeCode(
				CORBA::tk_struct,
				repository_id,
				type_name,
				members, 0);

	}

	static CORBA::TypeCode_ptr	create_union_tc(
				const char *repository_id,
				const char *type_name,
				CORBA::TypeCode_ptr discriminator_type,
				const CORBA::UnionMemberSeq& members) { 
			return new CORBA::TypeCode(
				repository_id,
				type_name,
				discriminator_type,
				members, 0);
	}

	static CORBA::TypeCode_ptr	create_enum_tc(
				const char *repository_id,
				const char *type_name,
				const CORBA::EnumMemberSeq& members) {
			return new CORBA::TypeCode(
				repository_id,
				type_name,
				members, 0);
	}

	static CORBA::TypeCode_ptr	create_alias_tc(
				const char *repository_id,
				const char *type_name,
				CORBA::TypeCode_ptr original_type) {
			return new CORBA::TypeCode(
				repository_id,
				type_name,
				original_type, 0);
	}

	static CORBA::TypeCode_ptr	create_exception_tc(
				const char *repository_id,
				const char *type_name,
				const CORBA::StructMemberSeq& members) {
			return new CORBA::TypeCode(
				CORBA::tk_except,
				repository_id,
				type_name,
				members, 0);
	}

	static CORBA::TypeCode_ptr	create_interface_tc(
				const char *repository_id,
				const char *type_name) {
			return new CORBA::TypeCode(
				repository_id,
				type_name, 0);
	}
				
	static CORBA::TypeCode_ptr	create_string_tc(
				CORBA::ULong bound) {
			return new CORBA::TypeCode(bound, 0);
	}
		
			
	static CORBA::TypeCode_ptr	create_sequence_tc(
				CORBA::ULong bound,
				CORBA::TypeCode_ptr element_type) {
			return new CORBA::TypeCode(
				CORBA::tk_sequence,
				bound,
				element_type, 0);
	}
			
	static CORBA::TypeCode_ptr	create_recursive_sequence_tc(
				CORBA::ULong bound,
				CORBA::ULong offset) {
			return new CORBA::TypeCode(
				bound,
				offset, 0);
	}
			
	static CORBA::TypeCode_ptr	create_array_tc(
				CORBA::ULong length,
				CORBA::TypeCode_ptr element_type) {
			return new CORBA::TypeCode(
				CORBA::tk_array,
				length,
				element_type, 0);
	}
    protected:
	CORBA_ORB();
	~CORBA_ORB() {}
	CORBA_ORB(const CORBA::ORB&);
	CORBA::ORB& operator=(const CORBA::ORB&);
};

class _PMCEXPORT CORBA_ORB_var
{
    public:
	CORBA_ORB_var() : _ptr(CORBA::ORB::_nil()) {}
	CORBA_ORB_var(CORBA::ORB_ptr ptr) : _ptr(ptr) {}
	CORBA_ORB_var(const CORBA::ORB_var& var) : _ptr((CORBA::ORB_ptr)var) {}
	~CORBA_ORB_var() {}
	CORBA::ORB_var& operator=(CORBA::ORB_ptr p) { _ptr = p; return *this; }
	CORBA::ORB_ptr operator->() const { return _ptr; }
	operator CORBA::ORB_ptr() const { return _ptr; }
    private:
	CORBA::ORB_ptr  _ptr;
	void operator=(const CORBA::ORB_var&) {}
};
	
#endif
