#ifndef _pmcext_h
#define _pmcext_h
/****************************************************************************/
/*                                                                          */
/*  Copyrighted by PostModern Computing Technologies, Inc   		    */
/*                                                                          */
/*  Copyright 1992, 1993, 1994 by PostModern Computing Technologies, Inc.   */
/*                          1897 Landings Drive				    */
/*                          Mountain View, California, USA                  */
/*                          Telephone (415) 967-6169                        */
/*                          Facsimile (415) 967-6212                        */
/*                                                                          */
/*  This code is the sole property of PostModern Computing Technologies,    */
/*  Inc.  and is  protected  by  copyright under the laws of the United     */
/*  States.   This  program is confidential, proprietary, and  a  trade     */
/*  secret,  not  to  be disclosed  without written authorization  from     */
/*  PostModern Computing Technologies, Inc.  Any use,  duplication,  or     */
/*  disclosure  of  this  program  by other than  PostModern  Computing     */
/*  Technologies, Inc. and its assigned licensees is strictly forbidden     */
/*  by law.                                                                 */
/*                                                                          */
/*  All rights reserved.                                                    */
/*                                                                          */
/*  Author: psm                                                             */
/*                                                                          */
/****************************************************************************/

#include <except.h>
#include <strvar.h>
#include <object.h>

// PostModern's extensions for Event Management. 
// Corresponds to the IDL definitions in pmcext.idl


class _PMCEXPORT PMC_EXT {
    public:
	struct ConnectionInfo {
		CORBA::String_var	hostname;
		CORBA::UShort		port;
		CORBA::Long		fd;
		ConnectionInfo& operator=(const ConnectionInfo& s) {
			hostname = s.hostname;
			port = s.port;
			fd = s.fd;
			return *this;
		}
	};
	inline friend ostream& operator<<(ostream& strm, 
			const ConnectionInfo& s) {
		strm << "struct PMC_EXT::ConnectionInfo {" << endl;
		strm << "\thostname: " << (const char *)s.hostname << endl;
		strm << "\tport: " << s.port << endl;
		strm << "\tfd: " << s.fd << endl;
		strm << "}" << endl;
		return strm;
	}
	inline friend CORBA::ULong hash(const ConnectionInfo& s) {
		CORBA::ULong h = hash(s.hostname);
		h ^= (CORBA::ULong)s.port;
		h ^= (CORBA::ULong)s.fd;
		return h;
	}
	inline friend CORBA::Long compare(const ConnectionInfo& s1, 
				const ConnectionInfo& s2) {
		return compare(s1.hostname, s2.hostname) || 
		       (CORBA::Long) (s1.port - s2.port) || 
		       (CORBA::Long) (s1.fd - s2.fd);
	}
		
	class _PMCEXPORT ConnectionInfo_var
	{
	    public:
		ConnectionInfo_var() { _ptr = (ConnectionInfo*)NULL;}
		ConnectionInfo_var(ConnectionInfo *ptr) {
			_ptr = ptr;
		}
		ConnectionInfo_var(const ConnectionInfo_var& var) {
			if (var._ptr)
				_ptr = new ConnectionInfo(*var._ptr);
			else
				_ptr = (ConnectionInfo *)NULL;
		}
		~ConnectionInfo_var() {
			if (_ptr != (ConnectionInfo *)NULL) delete _ptr;
		}
		ConnectionInfo_var& operator=(ConnectionInfo *ptr) {
			if (_ptr != (ConnectionInfo *)NULL) delete _ptr;
			_ptr = ptr;
			return *this;
		}
		ConnectionInfo_var& operator=(const ConnectionInfo_var& var) {
			if (_ptr != (ConnectionInfo *)NULL) delete _ptr;
			if (var._ptr)
				_ptr = new ConnectionInfo(*var._ptr);
			else
				_ptr = (ConnectionInfo *)NULL;
			return *this;
		}
		ConnectionInfo *operator->() { return _ptr; }
		operator ConnectionInfo *() { return _ptr; }
		operator ConnectionInfo& () { return *_ptr; }
	    private:
		ConnectionInfo *_ptr;
	};

	class _PMCEXPORT ClientEventHandler;
	typedef ClientEventHandler *ClientEventHandler_ptr;
	class _PMCEXPORT ClientEventHandler
	{
	    public:
		// _duplicate and _release are no-ops but provided
		// for compatibility reasons
		static ClientEventHandler_ptr _duplicate(
				ClientEventHandler_ptr obj) {
			return obj;
		}
		static void _release(ClientEventHandler_ptr) {}
		static ClientEventHandler_ptr _nil() { 
			return (ClientEventHandler_ptr)NULL;}

		virtual void bind_succeeded(CORBA::Object_ptr, 
				const ConnectionInfo&  ) {}
		virtual void bind_failed(CORBA::Object_ptr ) {}
		virtual void server_aborted(CORBA::Object_ptr ) {}
		virtual void rebind_succeeded(CORBA::Object_ptr,
				const ConnectionInfo& ) {}
		virtual void rebind_failed(CORBA::Object_ptr ) {}
				
	};

	class _PMCEXPORT BindEventHandler;
	typedef BindEventHandler *BindEventHandler_ptr;
	class _PMCEXPORT BindEventHandler
	{
	    public:
		// _duplicate and _release are no-ops but provided
		// for compatibility reasons
		static BindEventHandler_ptr _duplicate(
				BindEventHandler_ptr obj) {
			return obj;
		}
		static void _release(BindEventHandler_ptr) {}
		static BindEventHandler_ptr _nil() { 
			return (BindEventHandler_ptr)NULL;}

		virtual CORBA::Object_ptr pre_bind(
				const char * /* interface_name */,
				const char * /* object_name */,
				const char * /* host_name */,
				const CORBA::BindOptions& ) {
				return CORBA::Object::_nil();
		}
		virtual CORBA::Object_ptr post_bind(CORBA::Object_ptr obj,
				const char * /* interface_name */,
				const char * /* object_name */,
				const char * /* host_name */,
				const CORBA::BindOptions& ) {
				return CORBA::Object::_duplicate(obj);
		} 
		
		virtual CORBA::Object_ptr pre_rebind(
				const char * /* interface_name */,
				const char * /* object_name */,
				const char * /* host_name */,
				const CORBA::BindOptions& ) {
				return CORBA::Object::_nil();
		}
		virtual CORBA::Object_ptr post_rebind(CORBA::Object_ptr obj,
				const char * /* interface_name */,
				const char * /* object_name */,
				const char * /* host_name */,
				const CORBA::BindOptions& ) {
				return CORBA::Object::_duplicate(obj);
		} 
				
	};

		
	
	class _PMCEXPORT ImplEventHandler;
	typedef ImplEventHandler *ImplEventHandler_ptr;
	class _PMCEXPORT ImplEventHandler
	{
	    public:
		// _duplicate and _release are no-ops but provided
		// for compatibility reasons
		static ImplEventHandler_ptr _duplicate(
				ImplEventHandler_ptr obj) {
			return obj;
		}
		static void _release(ImplEventHandler_ptr) {}
		
		static ImplEventHandler_ptr _nil() { 
				return (ImplEventHandler_ptr)NULL;
		}

		virtual void bind(const ConnectionInfo&, 
				CORBA::Principal_ptr,
				CORBA::Object_ptr ) {}
		virtual void unbind(const ConnectionInfo&, 
				CORBA::Object_ptr ) {}
		virtual void client_aborted(const ConnectionInfo& info,
				CORBA::Object_ptr obj) {
				unbind(info, obj);
		}

		virtual void pre_method(const ConnectionInfo&, 
				CORBA::Principal_ptr ,
				const char * /* operation name*/,
				CORBA::Object_ptr ) {}
		virtual void post_method(const ConnectionInfo&,
				CORBA::Principal_ptr,
				const char * /* operation name */,
				CORBA::Object_ptr ) {}

		ConnectionInfo *get_client_info();

	};
		
	class _PMCEXPORT HandlerExists: public CORBA_UserException
	{
	    public:
		static const Description	_description;
	
		HandlerExists() {}
		static CORBA::Exception *_factory() { 
				return new HandlerExists(); 
		}
		~HandlerExists() {}
		virtual const Description& _desc() const;
		static HandlerExists *_narrow(CORBA::Exception *exc);
		CORBA::Exception *_deep_copy() const { 
				return new HandlerExists(*this); 
		}
		void _throw() const {
#if defined(_PMC_NOEXCEPTIONS)
			CORBA::current_environment().exception(_deep_copy());
#else
			throw *this;
#endif
		}
	};
	
		
	class _PMCEXPORT InvalidObject: public CORBA_UserException
	{
	    public:
		static const Description	_description;

		InvalidObject() {}
		static CORBA::Exception *_factory() { 
				return new InvalidObject(); 
		}
		~InvalidObject() {}
		virtual const Description& _desc() const;
		static InvalidObject *_narrow(CORBA::Exception *exc);
		CORBA::Exception *_deep_copy() const { 
				return new InvalidObject(*this); 
		}
		void _throw() const {
#if defined(_PMC_NOEXCEPTIONS)
			CORBA::current_environment().exception(_deep_copy());
#else
			throw *this;
#endif
		}
	};
	
		
	class _PMCEXPORT NoHandler: public CORBA_UserException
	{
	    public:
		static const Description	_description;
	
		NoHandler() {}
		static CORBA::Exception *_factory() { return new NoHandler(); }
		~NoHandler() {}
		virtual const Description& _desc() const;
		static NoHandler *_narrow(CORBA::Exception *exc);
		CORBA::Exception *_deep_copy() const { 
			return new NoHandler(*this); 
		}
		void _throw() const {
#if defined(_PMC_NOEXCEPTIONS)
			CORBA::current_environment().exception(_deep_copy());
#else
			throw *this;
#endif
		}
	};
	

	class _PMCEXPORT HandlerRegistry;
	typedef HandlerRegistry *HandlerRegistry_ptr;
	typedef HandlerRegistry_ptr HandlerRegistryRef;
	class _PMCEXPORT HandlerRegistry
	{
 	    private:
		HandlerRegistry(const HandlerRegistry&) {}
		void operator=(const HandlerRegistry&){}
		HandlerRegistry() {}
#if defined(_MSC_BUG) || defined(__alpha) || defined(_AIX) || defined(LINUX)
	    public:
		~HandlerRegistry() {}
#else
		~HandlerRegistry() {}
#endif
	    public:
		// _duplicate and _release are no-ops, but provided
		// for compatibility reasons
		static HandlerRegistry_ptr _duplicate(HandlerRegistry_ptr obj) {
			return obj;
		}
		static void _release(HandlerRegistry_ptr) {}
		static HandlerRegistry_ptr _nil() { 
			return (HandlerRegistry_ptr)NULL;
		}

		// Static member function to return the HandlerRegistry
		// Object
		static HandlerRegistry_ptr instance();
	
		void reg_obj_client_handler(CORBA::Object_ptr obj,
				ClientEventHandler_ptr handler)
				PMCTHROW_SPEC((
					HandlerExists,
					InvalidObject));
		void reg_glob_client_handler(
				ClientEventHandler_ptr handler)
				PMCTHROW_SPEC((
					HandlerExists));
		void unreg_obj_client_handler(CORBA::Object_ptr obj)
				PMCTHROW_SPEC( (
					NoHandler,
					InvalidObject));
		void unreg_glob_client_handler()
				PMCTHROW_SPEC( (
					NoHandler));
		void reg_obj_impl_handler(CORBA::Object_ptr obj,
				ImplEventHandler_ptr handler)
				PMCTHROW_SPEC( (
					HandlerExists,
					InvalidObject));
		void reg_glob_impl_handler(
				ImplEventHandler_ptr handler)
				PMCTHROW_SPEC( (
					HandlerExists));
		void unreg_obj_impl_handler(CORBA::Object_ptr obj)
				PMCTHROW_SPEC( (
					NoHandler,
					InvalidObject));
		void unreg_glob_impl_handler()
				PMCTHROW_SPEC( (
					NoHandler));

		void reg_bind_event_handler(
				BindEventHandler_ptr handler)
				PMCTHROW_SPEC((
					HandlerExists));
		void unreg_bind_event_handler()
				PMCTHROW_SPEC( (
					NoHandler));
	};

	static  ConnectionInfo  *get_client_info(CORBA::Object_ptr obj);
	static  CORBA::Object_ptr get_current_implementation();
};

#endif

