#ifndef _REQSTRM_HPP
#define _REQSTRM_HPP

/*
 * Stream buffer and stream classes for use with
 * IIOP request object.
 * 
 * Copyright 1996 Netscape Communications Corporation
 *
 * Robin J. Maxwell 09-26-1996
 */

#include "netsite.h"
#include <iostream.h>
#include "ONESrvPI.hpp"

#ifdef _MSC_VER
#pragma warning( disable : 4275)
#endif

class NSAPI_PUBLIC reqStreamBuf: public streambuf
{
public:
	reqStreamBuf(WAIServerRequest& req);
	virtual ~reqStreamBuf();
	int overflow(int ch);
	int underflow();
	int sync();
	int doallocate();
	size_t getTotalPutCount(){return (_total_put_cnt+out_waiting());}
	size_t getTotalGetCount(){return _total_get_cnt;}
	void setContentLengthLimit();


private:
	WAIServerRequest& _req;
	size_t _total_put_cnt;
	size_t _total_get_cnt;
	size_t _content_length;
	int _input_limited;
	int _allocated;

};

class NSAPI_PUBLIC oreqstream: public ostream
{
public:
	oreqstream(WAIServerRequest& req);
	~oreqstream();
	reqStreamBuf *rdbuf() { return (reqStreamBuf*) ios::rdbuf(); }
#ifdef IRIX
	oreqstream& flush();
#endif
};

#ifdef IRIX
//
// This seems to be completely broken on IRIX
// so we need to override these functions.
inline oreqstream& oreqstream::flush()
{
	bp->sync();
	return *this;
}

/*
 * Manipulators
 */
oreqstream& endl(oreqstream&);	// insert newline and flush
oreqstream& ends(oreqstream&);	// insert null to terminate string
oreqstream& flush(oreqstream&);	// flush the ostream

#endif

class NSAPI_PUBLIC ireqstream: public istream
{
public:
	ireqstream(WAIServerRequest& req);
	~ireqstream();
	reqStreamBuf *rdbuf() { return (reqStreamBuf*) ios::rdbuf(); }

};

#ifdef NEEDIOSTREAM
class NSAPI_PUBLIC reqstream: public iostream
{
public:
	reqstream(WAIServerRequest& req);
	~reqstream();
	reqStreamBuf *rdbuf() { return (reqStreamBuf*) ios::rdbuf(); }

};
#endif

#endif /* _REQSTRM_HPP */
