#ifndef _request_h_
#define _request_h_
/****************************************************************************/
/*                                                                          */
/*  Copyrighted by PostModern Computing Technologies, Inc   		    */
/*                                                                          */
/*  Copyright 1992, 1993, 1994 by PostModern Computing Technologies, Inc.   */
/*                          1897 Landings Drive				    */
/*                          Mountain View, California, USA                  */
/*                          Telephone (415) 967-6169                        */
/*                          Facsimile (415) 967-6212                        */
/*                                                                          */
/*  This code is the sole property of PostModern Computing Technologies,    */
/*  Inc.  and is  protected  by  copyright under the laws of the United     */
/*  States.   This  program is confidential, proprietary, and  a  trade     */
/*  secret,  not  to  be disclosed  without written authorization  from     */
/*  PostModern Computing Technologies, Inc.  Any use,  duplication,  or     */
/*  disclosure  of  this  program  by other than  PostModern  Computing     */
/*  Technologies, Inc. and its assigned licensees is strictly forbidden     */
/*  by law.                                                                 */
/*                                                                          */
/*  All rights reserved.                                                    */
/*                                                                          */
/*  Author: jkw                                                             */
/*                                                                          */
/****************************************************************************/

#include "ctx.h"
#include "env.h"
#include "object.h"

class _PMCEXPORT CORBA_Request {
  friend CORBA_Object;
public:

  CORBA::Object_ptr target() const {
    return CORBA::Object::_duplicate(_target);
  }
  const char* operation() const {
    return CORBA::strdup(_operation);
  }
  CORBA::NVList_ptr arguments() {
    return CORBA::NVList::_duplicate(_arguments);
  }
  CORBA::NamedValue_ptr result() {
    return CORBA::NamedValue::_duplicate(_result);
  }
  CORBA::Environment_ptr env() {
    return CORBA::Environment::_duplicate(_env);
  }
  void ctx(CORBA::Context_ptr ctx) {
    _ctx = CORBA::Context::_duplicate(ctx);
  }
  CORBA::Context_ptr ctx() const {
    return CORBA::Context::_duplicate(_ctx);
  }
  CORBA::Status invoke() {
    _invoke(1);
  }
  CORBA::Status send_oneway() {
    _invoke(0);
  }

  virtual CORBA::Status send_deferred();
  virtual CORBA::Status get_response();
  virtual CORBA::Boolean poll_response();

  static CORBA::Request_ptr _duplicate(CORBA::Request_ptr req) {
    if(req)
      req->_ref_count++;
    return req;
  }
  static CORBA::Request_ptr _nil() {
    return 0;
  }
  static void _release(CORBA::Request_ptr ptr) {
    if ( ptr && --ptr->_ref_count <= 0)
      delete ptr;
  }

protected:
  CORBA_Request(CORBA::Object_ptr target, 
		const char* operation);
  CORBA_Request(CORBA::Object_ptr target, 
	        CORBA::Context_ptr ctx, 
		const char* operation,
		CORBA::NVList_ptr arguments,
		CORBA::NamedValue_ptr result,
		CORBA::Flags flags);
  virtual ~CORBA_Request();
  CORBA_Request(const CORBA_Request&) {}
  CORBA::Request& operator=(const CORBA::Request&);
  virtual CORBA::Status _invoke(CORBA::Boolean response_expected);
  virtual CORBA::MarshalStream *_marshal_out(CORBA::Boolean response_expected);
  virtual CORBA::Status _marshal_in(CORBA::MarshalStream *stream);

  CORBA::Object_var _target;
  CORBA::String_var _operation;
  CORBA::NVList_var _arguments;
  CORBA::NamedValue_var _result;
  CORBA::Environment_var _env;
  CORBA::Context_var _ctx;
  CORBA::Flags _flags;
  CORBA::Long _ref_count;
  CORBA::Boolean _out_args;
};

class _PMCEXPORT CORBA_Request_var
{
public:
  CORBA_Request_var() { _ptr = CORBA::Request::_nil(); }
  CORBA_Request_var(CORBA::Request_ptr ptr) { _ptr = ptr; }
  CORBA_Request_var(const CORBA::Request_var& var) {
    _ptr = CORBA::Request::_duplicate(var._ptr);
  }
  ~CORBA_Request_var() { CORBA::Request::_release(_ptr); }
  CORBA::Request_var& operator=(CORBA::Request_ptr p) {
    if (p != _ptr)
      reset(p);
    return *this;
  }
  operator CORBA::Request_ptr() const { return _ptr; }
#if defined(_HPCC_BUG)
  operator CORBA::Request*&() { return _ptr; }
#else
  operator CORBA::Request_ptr&() { return _ptr; }
#endif
  CORBA::Request_ptr operator->() const { return _ptr; }
private:
  CORBA::Request_ptr     _ptr;
  void reset(CORBA::Request_ptr p) {
    CORBA::Request::_release(_ptr);
    _ptr = p;
  }
  void operator=(const CORBA::Request_var&) {}
};
  
class _PMCEXPORT CORBA_RequestSeq
{
    public:
	static CORBA::Request_ptr *allocbuf(CORBA::ULong nelems);
	static void freebuf(CORBA::Request_ptr *data);
	static void freebuf_elems(CORBA::Request_ptr *data, CORBA::ULong nelems);
	class _PMCEXPORT Sequence_RequestSeq
	{
		friend CORBA_RequestSeq;
	    private:
		CORBA::Boolean	_rel_flag;
		CORBA::Request_ptr	*_ptr;
		void release();
		Sequence_RequestSeq& operator=(const Sequence_RequestSeq& ) {
			return *this;
		}
		Sequence_RequestSeq() :_rel_flag(0) {}
		~Sequence_RequestSeq() {}
	    public:
		Sequence_RequestSeq& operator=(CORBA::Request_ptr p) {
			if ( *_ptr != p) {
				release();
				*_ptr = p;
			}
			return *this;
		}
		operator CORBA::Request_ptr() const { return *_ptr; }
		CORBA::Request_ptr operator->() const { return *_ptr; }
	};
	CORBA_RequestSeq(CORBA::ULong max=0);
	CORBA_RequestSeq(CORBA::ULong max,
			CORBA::ULong length,
			CORBA::Request_ptr *data,
			CORBA::Boolean release=0);
	CORBA_RequestSeq(const CORBA::RequestSeq&);
	~CORBA_RequestSeq();
	CORBA::RequestSeq& operator=(const CORBA::RequestSeq&);
	CORBA::ULong maximum() const { return _num_allocated;}
	void length(CORBA::ULong);
	CORBA::ULong length() const { return _count; }
	Sequence_RequestSeq& operator[](CORBA::ULong index) {
		if (index >= _count)
			throw CORBA::BAD_PARAM();
		_seqType._ptr = &_buffer[index];
		return _seqType;
	}
	CORBA::Request_ptr operator[](CORBA::ULong index) const {
		if (index >= _count)
			throw CORBA::BAD_PARAM();
		return _buffer[index];
	}
	static CORBA::RequestSeq *_duplicate(CORBA::RequestSeq *ptr) {
		if (ptr) ptr->_ref_count++;
		return ptr;
	}
	static void _release(CORBA::RequestSeq *ptr) {
		if (ptr && (--ptr->_ref_count == 0) )
			delete ptr;
	}
    private:
	CORBA::ULong		_count;
	CORBA::Request_ptr	*_buffer;
	CORBA::ULong		_num_allocated;
	Sequence_RequestSeq	_seqType;
	CORBA::ULong		_ref_count;
	void release_on_copy(CORBA::Boolean val) {_seqType._rel_flag = val;}
	CORBA::Boolean release_on_copy() const {return _seqType._rel_flag;}
};

class _PMCEXPORT CORBA_RequestSeq_var
{
    public:
	CORBA_RequestSeq_var() { _ptr = (CORBA::RequestSeq *)NULL; }
	CORBA_RequestSeq_var(CORBA::RequestSeq *ptr) {
		_ptr = ptr;
	}
	CORBA_RequestSeq_var(const CORBA::RequestSeq_var& var) {
		_ptr = CORBA::RequestSeq::_duplicate((CORBA::RequestSeq*)var);
	}
	~CORBA_RequestSeq_var() {CORBA::RequestSeq::_release(_ptr);}
	CORBA::RequestSeq_var& operator=(CORBA::RequestSeq *ptr) {
		if (_ptr != ptr) {
			CORBA::RequestSeq::_release(_ptr);
			_ptr = ptr;
		}
		return *this;
	}
	CORBA::RequestSeq_var& operator=(const CORBA::RequestSeq_var& var) {
		CORBA::RequestSeq::_release(_ptr);
		_ptr = CORBA::RequestSeq::_duplicate((CORBA::RequestSeq *)var);
		return *this;
	}
	CORBA::RequestSeq *operator->() { return _ptr; }
	CORBA_RequestSeq::Sequence_RequestSeq& operator[](CORBA::ULong index) {
		return _ptr->operator[](index);
	}
	CORBA::Request_ptr operator[](CORBA::ULong index) const {
		return _ptr->operator[](index);
	}
	operator CORBA::RequestSeq *() const { return _ptr; }
#if defined(_HPCC_BUG)
	operator CORBA::RequestSeq* &() { return _ptr; }
#else
	operator CORBA::RequestSeq_ptr& () { return _ptr; }
#endif
	operator const CORBA::RequestSeq& () const { return *_ptr; }
	operator CORBA::RequestSeq &() { return *_ptr; }
    private:
	CORBA::RequestSeq *_ptr;
};

#endif
